@@ -30,6 +30,7 @@
 #	include <config.h>
 #endif
 
+#include <glibmm.h>
 #include "groupactionmanager.h"
 #include "trees/layergrouptree.h"
 #include <synfigapp/action_param.h>
@@ -60,15 +61,14 @@ static const guint no_prev_popup((guint)-1);
 /* === M E T H O D S ======================================================= */
 
 GroupActionManager::GroupActionManager():
+	group_tree_(),
 	action_group_(Gtk::ActionGroup::create("action_group_group_action_manager")),
 	popup_id_(no_prev_popup),
 	queued(false)
-{
-}
+{ }
 
 GroupActionManager::~GroupActionManager()
-{
-}
+{ }
 
 void
 GroupActionManager::set_ui_manager(const Glib::RefPtr<Gtk::UIManager> &x)
@@ -229,8 +229,11 @@ GroupActionManager::refresh()
 
 	if(true)
 	{
-		ui_info="<ui><popup action='menu-main'><menu action='menu-group'>"+ui_info+"</menu></popup></ui>";
-		popup_id_=get_ui_manager()->add_ui_from_string(ui_info);
+		String full_ui_info;
+		full_ui_info="<ui><popup action='menu-main'><menu action='menu-group'>"+ui_info+"</menu></popup></ui>";
+		popup_id_=get_ui_manager()->add_ui_from_string(full_ui_info);
+		full_ui_info="<ui><menubar action='menubar-main'><menu action='menu-group'>"+ui_info+"</menu></menubar></ui>";
+		popup_id_=get_ui_manager()->add_ui_from_string(full_ui_info);
 	}
 	else
 	{
@@ -263,7 +266,7 @@ GroupActionManager::on_action_add()
 			group_name=(Glib::ustring)(*selected_iter->parent())[model.group_name]+'.';
 	}
 
-	group_name+=_("UnnamedSet");
+	group_name+=_("Unnamed Set");
 
 	Gtk::TreePath path(group_tree_->get_model()->on_group_added(group_name));
 
