@@ -29,6 +29,8 @@
 
 /* === H E A D E R S ======================================================= */
 
+#include <glibmm/dispatcher.h>
+
 #include <gtkmm/window.h>
 #include <gtkmm/image.h>
 #include <gtkmm/tooltip.h>
@@ -44,10 +46,18 @@
 #include <gdkmm/device.h>
 #include <gtkmm/spinbutton.h>
 #include <gtkmm/alignment.h>
+#include <gtkmm/toolbar.h>
+#include <gtkmm/toolitem.h>
+#include <gtkmm/toolbutton.h>
+#include <gtkmm/toggletoolbutton.h>
+#include <gtkmm/separatortoolitem.h>
+
 
 #include <synfigapp/canvasinterface.h>
 #include <synfigapp/selectionmanager.h>
 
+#include <ETL/clock>
+
 #include <synfig/canvas.h>
 #include <synfig/context.h>
 #include <synfig/string.h>
@@ -70,6 +80,7 @@
 #include "dialogs/dialog_waypoint.h"
 #include "dialogs/dialog_keyframe.h"
 #include "dials/framedial.h"
+#include "dials/jackdial.h"
 #include "dials/toggleducksdial.h"
 #include "dials/resolutiondial.h"
 #include "widgets/widget_keyframe_list.h"
@@ -91,6 +102,22 @@
 #include "adjust_window.h"
 
 #include <synfig/transform.h>
+#include <synfig/soundprocessor.h>
+
+#include "docks/dockable.h"
+
+#ifdef WITH_JACK
+#include <jack/jack.h>
+#include <jack/transport.h>
+#endif
+
+#ifndef ONION_SKIN_PAST
+	#define ONION_SKIN_PAST 10
+#endif
+
+#ifndef ONION_SKIN_FUTURE
+	#define ONION_SKIN_FUTURE 10
+#endif
 
 /* === M A C R O S ========================================================= */
 
@@ -122,6 +149,8 @@ class WorkArea;
 
 class Duckmatic;
 
+class Widget_Enum;
+
 class Preview;
 struct PreviewInfo;
 class AudioContainer;
@@ -142,7 +171,7 @@ class Dock_Keyframes;
 **
 **	\writeme
 */
-class CanvasView : public Gtk::Window, public etl::shared_object
+class CanvasView : public Dockable, public etl::shared_object
 {
 	friend class UniversalScrubber;
 	friend class Dock_Layers;
@@ -184,6 +213,29 @@ public:
 	};
 	friend class IsWorking;
 
+	class ActivationIndex {
+	private:
+		static ActivationIndex last__;
+	public:
+		long long int activation_index;
+		long long int creation_index;
+
+		void create() { creation_index = ++last__.creation_index; }
+		void activate() { activation_index = ++last__.activation_index; }
+
+		explicit ActivationIndex(bool create = false): activation_index(0), creation_index(0)
+		{
+			if (create) this->create();
+		}
+
+		bool operator < (const ActivationIndex &other) const
+		{
+			if (activation_index < other.activation_index) return true;
+			if (other.activation_index < activation_index) return false;
+			return creation_index < other.creation_index;
+		}
+	};
+
 	typedef synfigapp::CanvasInterface::Mode Mode;
 
 	void set_grid_snap_toggle(bool flag) { grid_snap_toggle->set_active(flag); }
@@ -198,7 +250,11 @@ public:
 	std::auto_ptr<WorkArea> work_area;
 
 	WorkArea* get_work_area() { return work_area.get(); }
+
 private:
+	synfig::SoundProcessor soundProcessor;
+
+	ActivationIndex activation_index_;
 
 	synfig::Rect bbox;
 
@@ -245,11 +301,11 @@ private:
 	std::map<synfig::String,Gtk::Widget*> ext_widget_book_;
 
 	//! The time adjustment's scope is defined by the time_window adjustment
-	Gtk::Adjustment time_adjustment_;
+	Glib::RefPtr<Gtk::Adjustment> time_adjustment_;
 
 	//! The time_window adjustment governs the position of the time window on the whole time line
-	//Gtk::Adjustment time_window_adjustment_;
-	studio::Adjust_Window time_window_adjustment_;
+	//Glib::RefPtr<Gtk::Adjustment> time_window_adjustment_;
+	Glib::RefPtr<studio::Adjust_Window> time_window_adjustment_;
 
 	LayerTree *layer_tree;
 
@@ -265,33 +321,42 @@ private:
 	Gtk::TreeRow children_canvas_row;
 	Gtk::TreeRow children_valuenode_row;
 
+	Gtk::Button *closebutton;
 	Gtk::Button *stopbutton;
-	Gtk::Button *refreshbutton;
+	Gtk::ToolButton *refreshbutton;
 	Gtk::Button *treetogglebutton;  // not used
 	Gtk::Notebook *notebook; // not used
 	Gtk::Table *timebar;
-	Gtk::Table *displaybar;
+	Gtk::Toolbar *displaybar;
+	Widget_Enum *widget_interpolation;
+	Gtk::ScrolledWindow *widget_interpolation_scroll;
 	Gtk::ToggleButton *animatebutton;
+	Gtk::ToggleButton *timetrackbutton;
+	Gtk::VBox *timetrack;
 	Gtk::Button *keyframebutton;
 	Gtk::ToggleButton *pastkeyframebutton;
 	Gtk::ToggleButton *futurekeyframebutton;
+	bool toggling_animate_mode_;
 	FrameDial *framedial;
-	ToggleDucksDial *toggleducksdial;
+	JackDial *jackdial;
+	Gtk::ToggleButton *jackbutton;
+	Widget_Time *offset_widget;
+	ToggleDucksDial toggleducksdial;
 	bool toggling_ducks_;
-	ResolutionDial *resolutiondial;
+	ResolutionDial resolutiondial;
 	bool changing_resolution_;
-	Gtk::Adjustment quality_adjustment_;
+	Glib::RefPtr<Gtk::Adjustment> quality_adjustment_;
 	Gtk::SpinButton *quality_spin;
-	Gtk::Adjustment future_onion_adjustment_;
-	Gtk::Adjustment past_onion_adjustment_;
+	Glib::RefPtr<Gtk::Adjustment> future_onion_adjustment_;
+	Glib::RefPtr<Gtk::Adjustment> past_onion_adjustment_;
 	Gtk::SpinButton *past_onion_spin;
 	Gtk::SpinButton *future_onion_spin;
 	bool updating_quality_;
-	Gtk::ToggleButton *show_grid;
-	Gtk::ToggleButton *snap_grid;
-	Gtk::ToggleButton *onion_skin;
-	Gtk::Button *render_options_button;
-	Gtk::Button *preview_options_button;
+	Gtk::ToggleToolButton *show_grid;
+	Gtk::ToggleToolButton *snap_grid;
+	Gtk::ToggleToolButton *onion_skin;
+	Gtk::ToolButton *render_options_button;
+	Gtk::ToolButton *preview_options_button;
 	bool toggling_show_grid;
 	bool toggling_snap_grid;
 	bool toggling_onion_skin;
@@ -346,6 +411,9 @@ private:
 	//! Menu members
 	Gtk::Menu parammenu;
 
+	Gtk::UIManager::ui_merge_id merge_id_popup_;
+	Gtk::UIManager::ui_merge_id merge_id_toolbar_;
+
 	Glib::RefPtr<Gtk::ToggleAction> grid_snap_toggle;
 	Glib::RefPtr<Gtk::ToggleAction> grid_show_toggle;
 	Glib::RefPtr<Gtk::ToggleAction> onion_skin_toggle;
@@ -359,12 +427,28 @@ private:
 	etl::handle<synfigapp::SelectionManager> selection_manager_;
 
 	bool is_playing_;
+	sigc::connection playing_connection;
+	etl::clock playing_timer;
+	synfig::Time playing_time;
 
 	sigc::signal<void> signal_deleted_;
 
 	bool rebuild_ducks_queued;
 	sigc::connection queue_rebuild_ducks_connection;
 
+	bool jack_enabled;
+	bool jack_actual_enabled;
+	int jack_locks;
+	bool jack_enabled_in_preview;
+#ifdef WITH_JACK
+	Glib::Dispatcher jack_dispatcher;
+	jack_client_t *jack_client;
+	bool jack_synchronizing;
+	bool jack_is_playing;
+	synfig::Time jack_time;
+	bool toggling_jack;
+#endif
+
 	Glib::RefPtr<Gtk::ToggleAction> action_mask_bone_setup_ducks, action_mask_bone_recursive_ducks;
 
 	/*
@@ -419,9 +503,6 @@ private:
 	//! Constructor Helper
 	// Gtk::Widget* create_keyframe_tree();
 
-	//! Constructor Helper
-	Gtk::Widget* create_status_bar();
-
 	//! Constructor Helper - Initializes all of the menus
 	void init_menus();
 
@@ -441,7 +522,9 @@ private:
 
 	Gtk::Widget *create_time_bar();
 
-	Gtk::Widget *create_display_bar();
+	Gtk::ToolButton* create_action_toolbutton(const Glib::RefPtr<Gtk::Action> &action);
+	Gtk::SeparatorToolItem* create_tool_separator();
+	Gtk::Widget* create_display_bar();
 
 	//! Pop up menu for the bezier (bline, draw) tool (?)
 	void popup_param_menu_bezier(float location, synfigapp::ValueDesc value_desc)
@@ -469,13 +552,38 @@ private:
 	void toggle_onion_skin();
 
 	void toggle_animatebutton();
+	void toggle_timetrackbutton();
 
+	void on_play_timeout();
+	
+	void interpolation_refresh();
+	void on_interpolation_changed();
+	void on_interpolation_event(GdkEvent *event);
+	
+	static void save_all();
 
 	/*
  -- ** -- P U B L I C   M E T H O D S -----------------------------------------
 	*/
 
 public:
+	ActivationIndex get_activation_index() { return activation_index_; }
+
+	void activate();
+	void deactivate();
+	void present();
+
+	bool jack_is_locked() const { return jack_locks > 0; }
+	void jack_lock();
+	void jack_unlock();
+	bool get_jack_enabled_in_preview() const { return jack_enabled_in_preview; }
+	void set_jack_enabled_in_preview(bool x) { jack_enabled_in_preview = x; }
+#ifdef WITH_JACK
+	bool get_jack_enabled() const { return jack_enabled; }
+	bool get_jack_actual_enabled() const { return jack_actual_enabled; }
+	void set_jack_enabled(bool value);
+#endif
+
 	synfig::Rect& get_bbox() { return bbox; }
 
 	Glib::RefPtr<Glib::ObjectBase> get_ref_obj(const synfig::String& x);
@@ -489,6 +597,11 @@ public:
 	Gtk::Widget* get_ext_widget(const synfig::String& x);
 	void set_ext_widget(const synfig::String& x, Gtk::Widget* y);
 
+	Gtk::UIManager::ui_merge_id get_popup_id();
+	void set_popup_id(Gtk::UIManager::ui_merge_id popup_id);
+	Gtk::UIManager::ui_merge_id get_toolbar_id();
+	void set_toolbar_id(Gtk::UIManager::ui_merge_id toolbar_id);
+
 	//std::map<synfig::String,Gtk::Widget*>& tree_view_book() { return tree_view_book_; }
 	//std::map<synfig::String,Gtk::Widget*>& ext_widget_book() { return tree_view_book_; }
 
@@ -515,13 +628,11 @@ public:
 
 	Mode get_mode()const { return canvas_interface()->get_mode(); }
 
-	Gtk::Adjustment &time_adjustment() { return time_adjustment_; }
+	Glib::RefPtr<Gtk::Adjustment> time_adjustment() { return time_adjustment_; }
+	Glib::RefPtr<const Gtk::Adjustment> time_adjustment()const { return time_adjustment_; }
 
-	const Gtk::Adjustment &time_adjustment()const { return time_adjustment_; }
-
-	studio::Adjust_Window &time_window_adjustment() { return time_window_adjustment_; }
-
-	const studio::Adjust_Window &time_window_adjustment()const { return time_window_adjustment_; }
+	Glib::RefPtr<studio::Adjust_Window> time_window_adjustment() { return time_window_adjustment_; }
+	Glib::RefPtr<const studio::Adjust_Window> time_window_adjustment()const { return time_window_adjustment_; }
 
 	etl::handle<synfigapp::UIInterface> get_ui_interface() { return ui_interface_;}
 
@@ -605,6 +716,9 @@ public:
 	//! Starts "playing" the animation in real-time
 	void play();
 
+	void play_async();
+	void stop_async();
+
 	//! Shows the tables (Layer/Children)
 	void show_tables();
 
@@ -632,6 +746,8 @@ public:
 	void add_layer(synfig::String x);
 
 	void show_keyframe_dialog();
+	void on_keyframe_toggle();
+	void on_keyframe_description_set();
 
 	void play_audio(float t);
 	void stop_audio();
@@ -642,14 +758,14 @@ public:
 
 	void preview_option() {on_preview_option();}
 
-	void present();
-
 	bool is_playing() { return is_playing_; }
 
 	void update_quality();
 
 	void toggle_duck_mask(Duckmatic::Type type);
 
+	bool is_time_equal_to_current_frame(const synfig::Time &time, const synfig::Time &range = synfig::Time(0.0));
+
 	/*
  -- ** -- S I G N A L   T E R M I N A L S -------------------------------------
 	*/
@@ -661,10 +777,11 @@ private:
 
 	void on_input_device_changed(GdkDevice*);
 
-	virtual void on_hide();
+	void on_hide();
 
-	virtual bool on_focus_in_event(GdkEventFocus*);
-	virtual bool on_focus_out_event(GdkEventFocus*);
+	Gtk::Widget* create_tab_label();
+
+	bool on_button_press_event(GdkEventButton *event);
 
 	//bool on_children_tree_event(GdkEvent *event);
 
@@ -736,6 +853,14 @@ private:
 
 	void on_play_pause_pressed();
 
+#ifdef WITH_JACK
+	void on_jack_offset_changed();
+	void toggle_jack_button();
+
+	synfig::Time get_jack_offset()const;
+	void set_jack_offset(const synfig::Time &value);
+#endif
+
 	void on_meta_data_changed();
 
 	//! Keyboard event dispatcher following window priority
@@ -756,6 +881,12 @@ public:
 	static etl::handle<studio::CanvasView> create(etl::loose_handle<Instance> instance,etl::handle<synfig::Canvas> canvas);
 	static std::list<int>& get_pixel_sizes();
 
+private:
+#ifdef WITH_JACK
+	void on_jack_sync();
+	static int jack_sync_callback(jack_transport_state_t state, jack_position_t *pos, void *arg);
+#endif
+
 }; // END of class CanvasView
 
 }; // END of namespace studio
