@@ -51,7 +51,7 @@ using namespace studio;
 
 /* === M E T H O D S ======================================================= */
 
-FrameDial::FrameDial(): Gtk::Table(7, 1, false)
+FrameDial::FrameDial(): Gtk::Table(8, 1, false)
 {
 	seek_begin =  create_icon(Gtk::ICON_SIZE_BUTTON, "synfig-animate_seek_begin",_("Seek to begin"));
 	seek_prev_keyframe =  create_icon(Gtk::ICON_SIZE_BUTTON, "synfig-animate_seek_prev_keyframe",_("Seek to previous keyframe"));
@@ -62,14 +62,14 @@ FrameDial::FrameDial(): Gtk::Table(7, 1, false)
 	seek_next_keyframe =  create_icon(Gtk::ICON_SIZE_BUTTON, "synfig-animate_seek_next_keyframe",_("Seek to next keyframe"));
 	seek_end =  create_icon(Gtk::ICON_SIZE_BUTTON, "synfig-animate_seek_end",_("Seek to end"));
 
-	attach(*seek_begin, 0, 1, 0, 1, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
+	attach(*seek_begin,			0, 1, 0, 1, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
 	attach(*seek_prev_keyframe, 1, 2, 0, 1, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
-	attach(*seek_prev_frame, 2, 3, 0, 1, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
-	attach(*play, 3, 4, 0, 1, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
-	attach(*pause, 3, 4, 0, 1, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
-	attach(*seek_next_frame, 4, 5, 0, 1, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
-	attach(*seek_next_keyframe, 5, 6, 0, 1, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
-	attach(*seek_end, 6, 7, 0, 1, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
+	attach(*seek_prev_frame,	2, 3, 0, 1, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
+	attach(*play,				3, 4, 0, 1, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
+	attach(*pause,				3, 4, 0, 1, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
+	attach(*seek_next_frame,	4, 5, 0, 1, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
+	attach(*seek_next_keyframe,	5, 6, 0, 1, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
+	attach(*seek_end,			6, 7, 0, 1, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
 	pause->hide();
 }
 
@@ -92,14 +92,14 @@ FrameDial::create_icon(Gtk::IconSize iconsize, const char * stockid, const char
 void
 FrameDial::toggle_play_pause_button(bool is_playing)
 {
-	if(!is_playing)
-	{
-		play->hide();
-		pause->show();
-	}
-	else
+	if(is_playing)
 	{
 		pause->hide();
 		play->show();
 	}
+	else
+	{
+		play->hide();
+		pause->show();
+	}
 }
