@@ -71,6 +71,13 @@ Dock_Keyframes::Dock_Keyframes():
 	keyframe_action_manager->signal_show_keyframe_properties().connect(
 		sigc::mem_fun(*this,&Dock_Keyframes::show_keyframe_properties)
 	);
+	keyframe_action_manager->signal_keyframe_toggle().connect(
+		sigc::mem_fun(*this,&Dock_Keyframes::keyframe_toggle)
+	);
+	keyframe_action_manager->signal_keyframe_description_set().connect(
+		sigc::mem_fun(*this,&Dock_Keyframes::keyframe_description_set)
+	);
+
 
     Glib::ustring ui_info =
 	"<ui>"
@@ -99,6 +106,21 @@ Dock_Keyframes::show_keyframe_properties()
 		get_canvas_view()->show_keyframe_dialog();
 }
 
+void
+Dock_Keyframes::keyframe_toggle()
+{
+	if(get_canvas_view())
+		get_canvas_view()->on_keyframe_toggle();
+}
+
+void
+Dock_Keyframes::keyframe_description_set()
+{
+	if(get_canvas_view())
+		get_canvas_view()->on_keyframe_description_set();
+}
+
+
 /*! \fn Dock_Keyframes::refresh_rend_desc()
 **	\brief Signal handler for animation render description change
 */
@@ -143,10 +165,13 @@ Dock_Keyframes::changed_canvas_view_vfunc(etl::loose_handle<CanvasView> canvas_v
 	}
 	else
 	{
-		clear_previous();
+		if(keyframe_action_manager)
+		{
+			keyframe_action_manager->clear();
+			keyframe_action_manager->set_keyframe_tree(0);
+			keyframe_action_manager->set_canvas_interface(0);
+		}
 
-		keyframe_action_manager->set_keyframe_tree(0);
-		keyframe_action_manager->set_canvas_interface(0);
-		keyframe_action_manager->refresh();
+		clear_previous();
 	}
 }
