@@ -97,14 +97,15 @@ public:
 
 		{	// --- T I M E   T R A C K --------------------------------------------
 			Gtk::TreeView::Column* column = Gtk::manage( new Gtk::TreeView::Column(_("Time Track")) );
+			Gtk::TreeView::Column* column2 = Gtk::manage( new Gtk::TreeView::Column("Align") );
 
 			// Set up the value-node cell-renderer
 			cellrenderer_time_track=LayerParamTreeStore::add_cell_renderer_value_node(column);
 			cellrenderer_time_track->property_mode()=Gtk::CELL_RENDERER_MODE_ACTIVATABLE;
 			cellrenderer_time_track->signal_waypoint_clicked_cellrenderer().connect(sigc::mem_fun(*this, &TimeTrackView::on_waypoint_clicked_timetrackview));
 			cellrenderer_time_track->signal_waypoint_changed().connect(sigc::mem_fun(*this, &TimeTrackView::on_waypoint_changed) );
-			column->add_attribute(cellrenderer_time_track->property_value_desc(), model.value_desc);
-			column->add_attribute(cellrenderer_time_track->property_canvas(), model.canvas);
+			//column->add_attribute(cellrenderer_time_track->property_value_desc(), model.value_desc);
+			//column->add_attribute(cellrenderer_time_track->property_canvas(), model.canvas);
 			//column->add_attribute(cellrenderer_time_track->property_visible(), model.is_value_node);
 
 			//column->pack_start(*cellrenderer_time_track);
@@ -113,27 +114,32 @@ public:
 			// to align the rows with params dock when the text is taller than value_type icons height
 			Gtk::CellRendererText* text_cellrenderer = Gtk::manage( new Gtk::CellRendererText() );
 			text_cellrenderer->property_attributes()=attr_list;
-			column->pack_end(*text_cellrenderer,false);
-			text_cellrenderer->set_fixed_size (0,-1);
+			column2->pack_end(*text_cellrenderer,false);
+			text_cellrenderer->set_fixed_size (1,-1);
 
 			// Add a fixed size (1pixel widht, same height than value_type icon) empty (alpha) icon
 			// to align the rows with params dock when the text is smaller than value_type icons height
 			Gtk::CellRendererPixbuf* icon_cellrenderer = Gtk::manage( new Gtk::CellRendererPixbuf() );
-			column->pack_end(*icon_cellrenderer,false);
 			Glib::RefPtr<Gdk::Pixbuf> pixbuf;
-			pixbuf=Gtk::Button().render_icon(Gtk::StockID("synfig-utils_timetrack_align"),Gtk::ICON_SIZE_SMALL_TOOLBAR);
+			pixbuf=Gtk::Button().render_icon_pixbuf(Gtk::StockID("synfig-utils_timetrack_align"),Gtk::ICON_SIZE_SMALL_TOOLBAR);
 			icon_cellrenderer->property_pixbuf() = pixbuf;
-			icon_cellrenderer->set_fixed_size (0,-1);
+			column2->pack_end(*icon_cellrenderer,false);
+			icon_cellrenderer->set_fixed_size(1,-1);
 
-			// Finish setting up the column
+			// Finish setting up the columns
 			column->set_reorderable();
 			column->set_sizing(Gtk::TREE_VIEW_COLUMN_AUTOSIZE);
 			column->set_resizable();
+			column->set_expand(true);
 // Commented during Align rows fixing
 // http://www.synfig.org/issues/thebuggenie/synfig/issues/161
 // 			column->set_min_width(200);
+			
+			column2->set_resizable();
+			column2->set_fixed_width(1);
 
 			append_column(*column);
+			append_column(*column2);
 		}
 		set_rules_hint();
 
@@ -190,7 +196,7 @@ public:
 				) break;
 				const Gtk::TreeRow row = *(get_model()->get_iter(path));
 
-				if(column && column->get_first_cell_renderer()==cellrenderer_time_track)
+				if(column && column->get_first_cell()==cellrenderer_time_track)
 				{
 					Gdk::Rectangle rect;
 					get_cell_area(path,*column,rect);
@@ -222,9 +228,9 @@ public:
 
 				Gtk::TreeRow row = *(get_model()->get_iter(path));
 
-				if ((event->motion.state&GDK_BUTTON1_MASK || event->motion.state&GDK_BUTTON3_MASK) &&
+				if (((event->motion.state&GDK_BUTTON1_MASK) || (event->motion.state&GDK_BUTTON3_MASK)) &&
 					column &&
-					cellrenderer_time_track == column->get_first_cell_renderer())
+					cellrenderer_time_track == column->get_first_cell())
 				{
 					Gdk::Rectangle rect;
 					get_cell_area(path,*column,rect);
@@ -269,7 +275,7 @@ public:
 
 				Gtk::TreeRow row = *(get_model()->get_iter(path));
 
-				if(column && cellrenderer_time_track==column->get_first_cell_renderer())
+				if(column && cellrenderer_time_track==column->get_first_cell())
 				{
 					Gdk::Rectangle rect;
 					get_cell_area(path,*column,rect);
@@ -350,11 +356,11 @@ public:
 	{
 		if(mimic_tree_view)
 		{
-			Gtk::Adjustment &adjustment(*mimic_tree_view->get_vadjustment());
+			Glib::RefPtr<Gtk::Adjustment> adjustment(mimic_tree_view->get_vadjustment());
 			set_vadjustment(adjustment);
 
-			if(adjustment.get_page_size()>get_height())
-				adjustment.set_page_size(get_height());
+			if(adjustment->get_page_size()>get_height())
+				adjustment->set_page_size(get_height());
 /* Commented during Align rows fixing
 // http://www.synfig.org/issues/thebuggenie/synfig/issues/161
 			int row_height = 0;
@@ -372,6 +378,7 @@ public:
 	on_waypoint_clicked_timetrackview(const etl::handle<synfig::Node>& node,
 									  const synfig::Time& time,
 									  const synfig::Time& time_offset __attribute__ ((unused)),
+									  const synfig::Time& time_dilation __attribute__ ((unused)),
 									  int button)
 	{
 		std::set<synfig::Waypoint, std::less<UniqueID> > waypoint_set;
@@ -406,18 +413,8 @@ Dock_Timetrack::Dock_Timetrack():
 	table_=0;
 	widget_timeslider_= new Widget_Timeslider();
 	widget_kf_list_= new Widget_Keyframe_List();
-
-	int header_height = 0;
-/* Commented during Align rows fixing
-// http://www.synfig.org/issues/thebuggenie/synfig/issues/161
-	if(getenv("SYNFIG_TIMETRACK_HEADER_HEIGHT"))
-		header_height = atoi(getenv("SYNFIG_TIMETRACK_HEADER_HEIGHT"));
-	if (header_height < 3)
-*/
-		header_height = 24;
-
-	widget_timeslider_->set_size_request(-1,header_height-header_height/3+1);
-	widget_kf_list_->set_size_request(-1,header_height/3+1);
+	
+	set_use_scrolled(false);
 
 	hscrollbar_=new Gtk::HScrollbar();
 	vscrollbar_=new Gtk::VScrollbar();
@@ -448,6 +445,7 @@ Dock_Timetrack::init_canvas_view_vfunc(etl::loose_handle<CanvasView> canvas_view
 	tree_view->set_model(tree_store);
 	Gtk::TreeView* param_tree_view(dynamic_cast<Gtk::TreeView*>(canvas_view->get_ext_widget("params")));
 	tree_view->mimic(param_tree_view);
+	mimic_tree_view=param_tree_view;
 
 	tree_view->signal_waypoint_clicked_timetrackview.connect(sigc::mem_fun(*canvas_view, &studio::CanvasView::on_waypoint_clicked_canvasview));
 
@@ -458,8 +456,8 @@ Dock_Timetrack::init_canvas_view_vfunc(etl::loose_handle<CanvasView> canvas_view
 	*/
 	tree_layer->signal_param_tree_header_height_changed().connect(sigc::mem_fun(*this, &studio::Dock_Timetrack::on_update_header_height));
 
-	canvas_view->time_adjustment().signal_value_changed().connect(sigc::mem_fun(*tree_view,&Gtk::TreeView::queue_draw));
-	canvas_view->time_adjustment().signal_changed().connect(sigc::mem_fun(*tree_view,&Gtk::TreeView::queue_draw));
+	canvas_view->time_adjustment()->signal_value_changed().connect(sigc::mem_fun(*tree_view,&Gtk::TreeView::queue_draw));
+	canvas_view->time_adjustment()->signal_changed().connect(sigc::mem_fun(*tree_view,&Gtk::TreeView::queue_draw));
 
 	canvas_view->set_ext_widget(get_name(),tree_view);
 	// widget_timeslider fps connection to animation render description change
@@ -506,6 +504,8 @@ Dock_Timetrack::changed_canvas_view_vfunc(etl::loose_handle<CanvasView> canvas_v
 	if(table_)
 	{
 		table_->hide();
+		remove(*table_);
+		clear_previous();
 		delete table_;
 		hscrollbar_->unset_adjustment();
 		vscrollbar_->unset_adjustment();
@@ -517,25 +517,34 @@ Dock_Timetrack::changed_canvas_view_vfunc(etl::loose_handle<CanvasView> canvas_v
 	{
 		TimeTrackView* tree_view(dynamic_cast<TimeTrackView*>(canvas_view->get_ext_widget(get_name())));
 		Gtk::TreeView* param_tree_view(dynamic_cast<Gtk::TreeView*>(canvas_view->get_ext_widget("params")));
-		tree_view->set_vadjustment(*param_tree_view->get_vadjustment());
+		Gtk::ScrolledWindow* scrolled = Gtk::manage(new Gtk::ScrolledWindow);
+		scrolled->get_vscrollbar()->hide();
+		scrolled->add(*tree_view);
+		scrolled->set_policy(Gtk::POLICY_NEVER,Gtk::POLICY_AUTOMATIC);
+		scrolled->set_vadjustment(param_tree_view->get_vadjustment());
+		scrolled->show_all();
 
 		assert(tree_view);
 		// Fixed size drawing areas to align the widget_timeslider and tree_view time cursors
 		// TODO ?: one align_drawingArea.(0, 1, 0, 1) modify_bg KF's color another (0, 1, 1, 2) modify_bg TS's color
 		Gtk::DrawingArea* align_drawingArea1 = Gtk::manage(new Gtk::DrawingArea);
-		align_drawingArea1->set_size_request(2,-1);
 		// TODO ?: one align_drawingArea.(2, 3, 0, 1) modify_bg KF's color another (2, 3, 1, 2) modify_bg TS's color
 		Gtk::DrawingArea* align_drawingArea2 = Gtk::manage(new Gtk::DrawingArea);
-		align_drawingArea2->set_size_request(6,-1);
-
-		widget_timeslider_->set_time_adjustment(&canvas_view->time_adjustment());
-		widget_timeslider_->set_bounds_adjustment(&canvas_view->time_window_adjustment());
+#if (GTKMM_MAJOR_VERSION == 3 && GTKMM_MINOR_VERSION >= 14)
+		align_drawingArea1->set_size_request(2,-1);
+		align_drawingArea2->set_size_request(4,-1);
+#else
+		align_drawingArea1->set_size_request(4,-1);
+		align_drawingArea2->set_size_request(9,-1);
+#endif
+		widget_timeslider_->set_time_adjustment(canvas_view->time_adjustment());
+		widget_timeslider_->set_bounds_adjustment(canvas_view->time_window_adjustment());
 		widget_timeslider_->set_global_fps(canvas_view->get_canvas()->rend_desc().get_frame_rate());
 
-		widget_kf_list_->set_time_adjustment(&canvas_view->time_adjustment());
+		widget_kf_list_->set_time_adjustment(canvas_view->time_adjustment());
 		widget_kf_list_->set_canvas_interface(canvas_view->canvas_interface());
 
-		vscrollbar_->set_adjustment(*tree_view->get_vadjustment());
+		vscrollbar_->set_adjustment(tree_view->get_vadjustment());
 		hscrollbar_->set_adjustment(canvas_view->time_window_adjustment());
 
 /*
@@ -560,12 +569,15 @@ ALIGN2 = align_drawingArea2
 		table_=new Gtk::Table(3,4);
 		table_->attach(*align_drawingArea1, 0, 1, 0, 2, Gtk::SHRINK, Gtk::FILL);
 		table_->attach(*widget_kf_list_, 1, 2, 0, 1, Gtk::FILL|Gtk::EXPAND, Gtk::FILL|Gtk::SHRINK);
-		table_->attach(*widget_timeslider_, 1, 2, 1, 2, Gtk::FILL|Gtk::SHRINK, Gtk::FILL|Gtk::SHRINK);
+		table_->attach(*widget_timeslider_, 1, 2, 1, 2, Gtk::FILL|Gtk::EXPAND, Gtk::FILL|Gtk::SHRINK);
 		table_->attach(*align_drawingArea2, 2, 3, 0, 2, Gtk::SHRINK, Gtk::FILL);
-		table_->attach(*tree_view, 0, 3, 2, 3, Gtk::FILL|Gtk::EXPAND, Gtk::FILL|Gtk::EXPAND);
+		table_->attach(*scrolled, 0, 3, 2, 3, Gtk::FILL|Gtk::EXPAND, Gtk::FILL|Gtk::EXPAND);
 		table_->attach(*hscrollbar_, 0, 3, 3, 4, Gtk::FILL|Gtk::EXPAND, Gtk::FILL|Gtk::SHRINK);
 		table_->attach(*vscrollbar_, 3, 4, 0, 3, Gtk::FILL|Gtk::SHRINK, Gtk::FILL|Gtk::EXPAND);
 		add(*table_);
+		
+		// Should be here, after the widget was attached to table
+		tree_view->add_events(Gdk::SCROLL_MASK);
 
 		//add(*last_widget_curves_);
 		table_->show_all();
@@ -580,17 +592,10 @@ ALIGN2 = align_drawingArea2
 void
 Dock_Timetrack::on_update_header_height( int header_height)
 {
-	// FIXME very bad hack (curves dock also contains this)
-	//! Adapt the border size "according" to different windows manager rendering
-#ifdef WIN32
-	header_height-=2;
-#elif defined(__APPLE__)
-	header_height+=6;
-#else
-// *nux and others
-	header_height+=2;
-#endif
-
-	widget_timeslider_->set_size_request(-1,header_height-header_height/3+1);
-	widget_kf_list_->set_size_request(-1,header_height/3+1);
+	int width=0;
+	int height=0;
+	int kf_list_height=10;
+	mimic_tree_view->convert_bin_window_to_widget_coords(0, 0, width, height);
+	widget_timeslider_->set_size_request(-1,height-kf_list_height);
+	widget_kf_list_->set_size_request(-1,kf_list_height);
 }
