@@ -79,10 +79,9 @@ Dockable::Dockable(const synfig::String& name,const synfig::String& local_name,G
 	name_(name),
 	local_name_(local_name),
 //	dialog_settings(this,name),
-	title_label_(local_name,Gtk::ALIGN_LEFT),
+	title_label_(local_name,Gtk::ALIGN_START),
 	stock_id_(stock_id_)
 {
-	parent_=0;
 	scrolled_=0;
 
 	use_scrolled_=true;
@@ -114,7 +113,8 @@ Dockable::Dockable(const synfig::String& name,const synfig::String& local_name,G
 		header_box_.pack_end(*bttn_close,false,false);
 		bttn_close->show();
 		bttn_close->set_relief(Gtk::RELIEF_NONE);
-		bttn_close->signal_clicked().connect(sigc::mem_fun(*this,&Dockable::detach));
+		bttn_close->signal_clicked().connect(
+				sigc::bind(sigc::ptr_fun(&DockManager::remove_widget_by_pointer_recursive), this));
 		bttn_close->set_border_width(0);
 		dynamic_cast<Gtk::Misc*>(bttn_close->get_child())->set_padding(0,0);
 	}
@@ -145,14 +145,15 @@ Dockable::~Dockable()
 void
 Dockable::attach_dnd_to(Gtk::Widget& widget)
 {
-	std::list<Gtk::TargetEntry> listTargets;
-	listTargets.push_back( Gtk::TargetEntry("DOCK") );
+	std::vector<Gtk::TargetEntry> listTargets;
+	listTargets.push_back( Gtk::TargetEntry("SYNFIG_DOCK") );
+	Gtk::StockItem item;
 
 	widget.drag_source_set(listTargets);
-	widget.drag_source_set_icon(get_stock_id());
+	if(Gtk::Stock::lookup(get_stock_id(),item))
+		widget.drag_source_set_icon(get_stock_id());
 	widget.drag_dest_set(listTargets);
 
-
 	widget.signal_drag_data_get().connect(sigc::mem_fun(*this,&Dockable::on_drag_data_get));
 	widget.signal_drag_end().connect(sigc::mem_fun(*this,&Dockable::on_drag_end));
 	widget.signal_drag_begin().connect(sigc::mem_fun(*this,&Dockable::on_drag_begin));
@@ -162,17 +163,26 @@ Dockable::attach_dnd_to(Gtk::Widget& widget)
 void
 Dockable::on_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& context, int, int, const Gtk::SelectionData& selection_data, guint, guint time)
 {
-	if ((selection_data.get_length() >= 0) && (selection_data.get_format() == 8))
+	if (selection_data.get_length() >= 0
+	 && selection_data.get_format() == 8
+	 && selection_data.get_data_type() == "SYNFIG_DOCK")
 	{
 		Dockable& dockable(**reinterpret_cast<Dockable**>(const_cast<guint8*>(selection_data.get_data())));
 
-		if(dockable.parent_ != parent_)
-			parent_->add(dockable,parent_->page_num(*this));
-		else
-			parent_->reorder_child(dockable,parent_->page_num(*this));
-		dockable.present();
-		context->drag_finish(true, false, time);
-		return;
+		DockBook *parent = dynamic_cast<DockBook*>(get_parent());
+		DockBook *dockable_parent = dynamic_cast<DockBook*>(dockable.get_parent());
+
+		if (parent)
+		{
+			if (dockable_parent != parent)
+				 parent->add(dockable,parent->page_num(*this));
+			else
+				parent->reorder_child(dockable,parent->page_num(*this));
+			dockable.present();
+			context->drag_finish(true, false, time);
+			App::dock_manager->update_window_titles();
+			return;
+		}
 	}
 
 	context->drag_finish(false, false, time);
@@ -183,7 +193,7 @@ Dockable::on_drag_end(const Glib::RefPtr<Gdk::DragContext>&/*context*/)
 {
 	if(!dnd_success_)
 	{
-		detach();
+		DockManager::remove_widget_recursive(*this);
 		present();
 	}
 }
@@ -207,7 +217,9 @@ void
 Dockable::set_local_name(const synfig::String& local_name)
 {
 	//set_title(local_name);
+	local_name_ = local_name;
 	title_label_.set_text(local_name);
+	signal_stock_id_changed()();
 }
 
 void
@@ -304,31 +316,30 @@ Dockable::add_button(const Gtk::StockID& stock_id, const synfig::String& tooltip
 }
 
 
-void
-Dockable::detach()
-{
-	if(parent_)
-		parent_->remove(*this);
-}
-
 void
 Dockable::present()
 {
-	if(parent_)
+	DockBook *parent = dynamic_cast<DockBook*>(get_parent());
+	if(parent)
 	{
-		parent_->set_current_page(parent_->page_num(*this));
-		parent_->present();
+		parent->set_current_page(parent->page_num(*this));
+		parent->present();
 	}
 	else
 	{
+		show();
+		DockBook* book = manage(new DockBook());
+		book->show();
+		book->add(*this);
 		DockDialog* dock_dialog(new DockDialog());
-		dock_dialog->get_dock_book().add(*this);
+		dock_dialog->add(*book);
 /*		//hack: always display composition selector on top of canvas browser
 		if(get_name()=="canvases")
 			dock_dialog->set_composition_selector(true);
 */
 		dock_dialog->present();
 	}
+	App::dock_manager->update_window_titles();
 }
 
 Gtk::Widget*
@@ -345,7 +356,8 @@ Dockable::create_tab_label()
 		// Check to make sure the icon is valid
 		if(Gtk::Stock::lookup(stock_id,item))
 		{
-			Gtk::Image* icon(manage(new Gtk::Image(stock_id,Gtk::IconSize(4))));
+			Gtk::IconSize iconsize = Gtk::IconSize::from_name("synfig-small_icon_16x16");
+			Gtk::Image* icon(manage(new Gtk::Image(stock_id,iconsize)));
 			event_box->add(*icon);
 			event_box->set_tooltip_text(get_local_name());
 			icon->show();
