@@ -106,6 +106,7 @@ class DuckDrag_Translate : public DuckDrag_Base
 	synfig::Vector drag_offset_;
 	synfig::Vector snap;
 	std::vector<synfig::Vector> positions;
+	bool is_moving;
 
 public:
 	void begin_duck_drag(Duckmatic* duckmatic, const synfig::Vector& begin);
@@ -130,8 +131,10 @@ class BezierDrag_Default : public BezierDrag_Base
 	synfig::Vector c2_initial;
 	float c1_ratio;
 	float c2_ratio;
-	bool c1_selected;
-	bool c2_selected;
+	//bool c1_selected;
+	//bool c2_selected;
+	//Warning: unused variables c1_selected c2_selected
+	bool is_moving;
 
 public:
 	void begin_bezier_drag(Duckmatic* duckmatic, const synfig::Vector& begin, float bezier_click_pos);
@@ -227,6 +230,9 @@ private:
 	bool curr_transform_stack_set;
 	std::list<sigc::connection> duck_changed_connections;
 
+	bool alternative_mode_;
+	bool lock_animation_mode_;
+
 	/*
  -- ** -- P R O T E C T E D   D A T A -----------------------------------------
 	*/
@@ -247,6 +253,10 @@ protected:
 	//! This vector describes the grid size.
 	/*! \see grid_snap, show_grid */
 	synfig::Vector grid_size;
+	//! Hold the grid color.
+	synfig::Color grid_color;
+	//! Hold the guides color.
+	synfig::Color guides_color;
 
 	float zoom;					//!< Zoom factor
 	float prev_zoom;			//!< Previous Zoom factor
@@ -266,6 +276,7 @@ private:
 
 	//etl::handle<Duck> selected_duck;
 
+	void connect_signals(const Duck::Handle &duck, const synfigapp::ValueDesc& value_desc, CanvasView &canvas_view);
 
 	/*
  -- ** -- P U B L I C   M E T H O D S -----------------------------------------
@@ -276,6 +287,12 @@ public:
 	Duckmatic(etl::loose_handle<synfigapp::CanvasInterface> canvas_interface);
 	virtual ~Duckmatic();
 
+	void set_alternative_mode(bool x) { alternative_mode_=x; }
+	bool get_alternative_mode()const { return alternative_mode_; }
+
+	void set_lock_animation_mode(bool x) { lock_animation_mode_=x; }
+	bool get_lock_animation_mode()const { return lock_animation_mode_; }
+
 	sigc::signal<void>& signal_duck_selection_changed() { return signal_duck_selection_changed_; }
 	sigc::signal<void>& signal_strokes_changed() { return signal_strokes_changed_; }
 	sigc::signal<void>& signal_grid_changed() { return signal_grid_changed_; }
@@ -289,6 +306,10 @@ public:
 	void set_guide_snap(bool x=true);
 	bool get_guide_snap()const { return guide_snap; }
 	void toggle_guide_snap() { set_guide_snap(!get_guide_snap()); }
+	//! Sets the color of the guides
+	void set_guides_color(const synfig::Color &c);
+	//! Returns the color of the guides
+	const synfig::Color &get_guides_color()const { return guides_color;}
 
 	//! Sets the state of the grid snap flag
 	void set_grid_snap(bool x=true);
@@ -309,10 +330,13 @@ public:
 
 	//! Sets the size of the grid
 	void set_grid_size(const synfig::Vector &s);
+	//! Sets the color of the grid
+	void set_grid_color(const synfig::Color &c);
 
 	//! Returns the size of the grid
 	const synfig::Vector &get_grid_size()const { return grid_size; }
-
+	//! Returns the color of the grid
+	const synfig::Color &get_grid_color()const { return grid_color;}
 
 	const synfig::Time &get_time()const { return cur_time; }
 
@@ -334,30 +358,71 @@ public:
 
 	std::list<etl::handle<Stroke> >& persistent_stroke_list() { return persistent_stroke_list_; }
 
-	//! \todo We should modify this to support multiple selections
+    /*
+ -- ** -- D U C K  S E L E C T I O N  M E T H O D S----------------------------
+    */
+
+    //! Return first selected duck (handle) has const Duck etl::handle
 	etl::handle<Duck> get_selected_duck()const;
-
+	//! Return list of selected ducks (handles)
+	/*!
+     ** \return ducks (handles) has const DuckList
+     ** \sa get_selected_duck, clear_selected_ducks, count_selected_ducks
+    */
 	DuckList get_selected_ducks()const;
-
-	//! Returns \a true if the given duck is currently selected
-	bool duck_is_selected(const etl::handle<Duck> &duck)const;
-
+    //! Return list of box contained ducks (handles). The box is defined by a vector's pair
+    /*!
+     ** \param tl The top left canvas coordinate has const synfig::Vector
+     ** \param br The bottom right canvas coordinate has const synfig::Vector
+     ** \return ducks (handles) has const DuckList
+     ** \sa toggle_select_ducks_in_box, select_ducks_in_box, find_duck
+    */
+	DuckList get_ducks_in_box(const synfig::Vector& tl,const synfig::Vector& br)const;
 
 	void refresh_selected_ducks();
-
+    //! Clear all selected ducks
 	void clear_selected_ducks();
-
+	//! Return the number of selected ducks
+    /*!
+     ** \return the number of selected ducks (handles) has int
+     */
 	int count_selected_ducks()const;
-
+    //! Give the selection status of a duck
+    /*!
+     ** \return \a true if the given duck (handle) is currently selected
+     */
+    bool duck_is_selected(const etl::handle<Duck> &duck)const;
+	//! Toggle the duck (handle)
+    /*!
+     ** \param duck The duck (handle) to toggle has etl::handle parameter
+     */
 	void toggle_select_duck(const etl::handle<Duck> &duck);
-
+    //! Select the duck (handle)
+    /*!
+     ** \param duck The duck (handle) to select has etl::handle parameter
+     */
 	void select_duck(const etl::handle<Duck> &duck);
+    //! Unselect the duck (handle)
+    /*!
+     ** \param duck The duck (handle) to unselect has etl::handle parameter
+     */
+	void unselect_duck(const etl::handle<Duck> &duck);
 
+    //! Toggle the ducks (handles) contained in the box defined by a pair of vectors
+    /*!
+     ** \param tl The top left canvas coordinate has const synfig::Vector
+     ** \param br The bottom right canvas coordinate has const synfig::Vector
+     ** \sa toggle_select_duck, select_ducks_in_box, get_ducks_in_box
+    */
 	void toggle_select_ducks_in_box(const synfig::Vector& tl,const synfig::Vector& br);
-
+	//! Select the ducks (handles) contained in the box defined by a pair of vectors
+    /*!
+     ** \param tl The top left canvas coordinate has const synfig::Vector
+     ** \param br The bottom right canvas coordinate has const synfig::Vector
+     ** \sa toggle_select_ducks_in_box, select_ducks_in_box, clear_selected_ducks
+    */
 	void select_ducks_in_box(const synfig::Vector& tl,const synfig::Vector& br);
 
-	void unselect_duck(const etl::handle<Duck> &duck);
 
 	const synfig::TransformStack& get_curr_transform_stack()const { return curr_transform_stack; }
 
@@ -367,13 +432,16 @@ public:
 	etl::handle<Bezier> get_selected_bezier()const;
 
 	//! Begin dragging ducks
-	/*! \param offset Canvas coordinates of the mouse when the drag began */
+	/*!
+	 ** \param offset Canvas coordinates of the mouse when the drag began
+	*/
 	void start_duck_drag(const synfig::Vector& offset);
 
 	//! Continue dragging the selected ducks
 	/*! The overall vector of the drag is vector-offset
-	 *  (where offset was given in start_duck_drag)
-	 *  \param vector Canvas coordinates of the mouse at this moment */
+	 ** (where offset was given in start_duck_drag)
+	 ** \param vector Canvas coordinates of the mouse at this moment
+	*/
 	void translate_selected_ducks(const synfig::Vector& vector);
 
 	//! Update the coordinates of tangents and linked-to-bline ducks
@@ -396,11 +464,11 @@ public:
 
 	//! Calls a single duck's edited signal
 	/*! Updates the corresponding valuenodes after a drag */
-	void signal_edited_duck(const etl::handle<Duck> &duck);
+	void signal_edited_duck(const etl::handle<Duck> &duck, bool moving = false);
 
 	//! Calls all of the ducks' edited signals
 	/*! Updates corresponding valuenodes after a drag */
-	void signal_edited_selected_ducks();
+	void signal_edited_selected_ducks(bool moving = false);
 
 	bool on_duck_changed(const studio::Duck &duck,const synfigapp::ValueDesc& value_desc);
 
@@ -447,7 +515,7 @@ public:
 
 	void add_ducks_layers(synfig::Canvas::Handle canvas, std::set<synfig::Layer::Handle>& selected_layer_set, etl::handle<CanvasView> canvas_view, synfig::TransformStack& transform_stack);
 
-	bool add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<CanvasView> canvas_view, const synfig::TransformStack& transform_stack_, synfig::ParamDesc *param_desc=0, int multiple=0);
+	bool add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<CanvasView> canvas_view, const synfig::TransformStack& transform_stack_, synfig::ParamDesc *param_desc=0);
 
 	//! Set the type mask, which determines what types of ducks are shown
 	void set_type_mask(Type x) { type_mask=x; }
