@@ -42,7 +42,7 @@
 
 namespace synfig { class ValueNode; class Layer; }
 
-namespace synfigapp { namespace Action { class BookEntry; };};
+namespace synfigapp { namespace Action { struct BookEntry; };};
 
 namespace studio {
 
@@ -54,17 +54,18 @@ public:
 	IconController(const synfig::String& basepath);
 	~IconController();
 
-	static Gdk::Cursor get_normal_cursor();
-	static Gdk::Cursor get_tool_cursor(const Glib::ustring& name,const Glib::RefPtr<Gdk::Window>& window);
+	void init_icons(const synfig::String& path_to_icons);
+	static Glib::RefPtr<Gdk::Cursor> get_normal_cursor();
+	static Glib::RefPtr<Gdk::Cursor> get_tool_cursor(const Glib::ustring& name,const Glib::RefPtr<Gdk::Window>& window);
 };
 
 Gtk::StockID layer_icon(const synfig::String &layer);
 Glib::RefPtr<Gdk::Pixbuf> get_tree_pixbuf_layer(const synfig::String &layer);
 
-Gtk::StockID value_icon(synfig::ValueBase::Type type);
+Gtk::StockID value_icon(synfig::Type &type);
 Gtk::StockID interpolation_icon(synfig::Interpolation type);
 Gtk::StockID valuenode_icon(etl::handle<synfig::ValueNode> value_node);
-Glib::RefPtr<Gdk::Pixbuf> get_tree_pixbuf(synfig::ValueBase::Type type);
+Glib::RefPtr<Gdk::Pixbuf> get_tree_pixbuf(synfig::Type &type);
 Glib::RefPtr<Gdk::Pixbuf> get_interpolation_pixbuf(synfig::Interpolation itype);
 Gtk::StockID get_action_stock_id(const synfigapp::Action::BookEntry& action);
 
