@@ -136,7 +136,7 @@ private:
 
 protected:
 
-	Instance(synfig::Canvas::Handle);
+	Instance(synfig::Canvas::Handle, etl::handle< synfig::FileContainerTemporary >);
 
 public:
 
@@ -219,7 +219,7 @@ public:
 
 	void make_param_menu(Gtk::Menu *menu,synfig::Canvas::Handle canvas, synfigapp::ValueDesc value_desc, float location=0.5f, bool bezier=false);
 
-	void make_param_menu(Gtk::Menu *menu,synfig::Canvas::Handle canvas,const std::list<synfigapp::ValueDesc>& value_desc_list);
+	void make_param_menu(Gtk::Menu *menu,synfig::Canvas::Handle canvas,const std::list<synfigapp::ValueDesc>& value_desc_list, const synfigapp::ValueDesc &value_desc = synfigapp::ValueDesc());
 
 
 	static void edit_waypoint(synfigapp::ValueDesc value_desc,synfig::Waypoint waypoint);
@@ -228,7 +228,7 @@ private:
 	void insert_canvas(Gtk::TreeRow row,synfig::Canvas::Handle canvas);
 
 public:
-	static etl::handle<Instance> create(synfig::Canvas::Handle canvas);
+	static etl::handle<Instance> create(synfig::Canvas::Handle canvas, etl::handle< synfig::FileContainerTemporary > container);
 }; // END class Instance
 
 }; // END namespace studio
