@@ -197,12 +197,18 @@ public:
 	}
 };
 
-studio::Preview::Preview(const studio::CanvasView::LooseHandle &h, float zoom, float f)
-:canvasview(h),zoom(zoom),fps(f)
-{
-	overbegin = false;
-	overend = false;
-}
+studio::Preview::Preview(const studio::CanvasView::LooseHandle &h, float zoom, float f):
+	canvasview(h),
+	zoom(zoom),
+	fps(f),
+	begintime(),
+	endtime(),
+	overbegin(false),
+	overend(false),
+	use_cairo(),
+	quality(),
+	global_fps()
+{ }
 
 void studio::Preview::set_canvasview(const studio::CanvasView::LooseHandle &h)
 {
@@ -367,15 +373,26 @@ void studio::Preview::frame_finish(const Preview_Target *targ)
 
 Widget_Preview::Widget_Preview():
 	Gtk::Table(1, 5),
-	adj_time_scrub(0, 0, 1000, 0, 10, 0),
+	adj_time_scrub(Gtk::Adjustment::create(0, 0, 1000, 0, 10, 0)),
 	scr_time_scrub(adj_time_scrub),
 	b_loop(/*_("Loop")*/),
 	current_surface(NULL),
 	currentindex(-100000),//TODO get the value from canvas setting or preview option
 	audiotime(0),
-	adj_sound(0, 0, 4),
+	adj_sound(Gtk::Adjustment::create(0, 0, 4)),
 	l_lasttime("0s"),
-	playing(false)
+	playing(false),
+	jackdial(NULL),
+	jack_enabled(false),
+	jack_is_playing(false),
+	jack_time(0),
+	jack_initial_time(0),
+	jack_offset(0),
+#ifdef WITH_JACK
+	jack_client(NULL),
+	jack_synchronizing(false),
+#endif
+	zoom_preview(true)
 {
 	//catch key press event for shortcut keys
 	signal_key_press_event().connect(sigc::mem_fun(*this, &Widget_Preview::on_key_pressed));
@@ -391,27 +408,21 @@ Widget_Preview::Widget_Preview():
 	preview_window.add(draw_area);
 
 	//preview window background color
-	Gdk::Color bg_color;
+	Gdk::RGBA bg_color;
 	bg_color.set_red(54*256);
 	bg_color.set_blue(59*256);
 	bg_color.set_green(59*256);
-	draw_area.modify_bg(Gtk::STATE_NORMAL, bg_color);
+	draw_area.override_background_color(bg_color);
 
 
-	adj_time_scrub.signal_value_changed().connect(sigc::mem_fun(*this,&Widget_Preview::slider_move));
+	adj_time_scrub->signal_value_changed().connect(sigc::mem_fun(*this,&Widget_Preview::slider_move));
 	scr_time_scrub.signal_event().connect(sigc::mem_fun(*this,&Widget_Preview::scroll_move_event));
-	draw_area.signal_expose_event().connect(sigc::mem_fun(*this,&Widget_Preview::redraw));
+	draw_area.signal_draw().connect(sigc::mem_fun(*this,&Widget_Preview::redraw));
 	
 	scr_time_scrub.set_draw_value(0);
 
-	disp_sound.set_time_adjustment(&adj_sound);
 	timedisp = -1;
 
-	//Set up signals to modify time value as it should be...
-	disp_sound.signal_start_scrubbing().connect(sigc::mem_fun(*this,&Widget_Preview::scrub_updated));
-	disp_sound.signal_scrub().connect(sigc::mem_fun(*this,&Widget_Preview::scrub_updated));
-
-
 	Gtk::Button *button = 0;
 	Gtk::Image *icon = 0;
 
@@ -434,18 +445,31 @@ Widget_Preview::Widget_Preview():
 
 	toolbar->pack_start(*prev_framebutton, Gtk::PACK_SHRINK, 0);
 
-	//play pause
-	Gtk::Image *icon1 = manage(new Gtk::Image(Gtk::StockID("synfig-animate_play"), Gtk::ICON_SIZE_BUTTON));
-	play_pausebutton = manage(new class Gtk::Button());
-	play_pausebutton->set_tooltip_text(_("Play"));
-	icon1->set_padding(0,0);
-	icon1->show();
-	play_pausebutton->add(*icon1);
-	play_pausebutton->set_relief(Gtk::RELIEF_NONE);
-	play_pausebutton->show();
-	play_pausebutton->signal_clicked().connect(sigc::mem_fun(*this,&Widget_Preview::on_play_pause_pressed));
+	{ //play
+		Gtk::Image *icon = manage(new Gtk::Image(Gtk::StockID("synfig-animate_play"), Gtk::ICON_SIZE_BUTTON));
+		play_button = manage(new class Gtk::Button());
+		play_button->set_tooltip_text(_("Play"));
+		icon->set_padding(0,0);
+		icon->show();
+		play_button->add(*icon);
+		play_button->set_relief(Gtk::RELIEF_NONE);
+		play_button->show();
+		play_button->signal_clicked().connect(sigc::mem_fun(*this,&Widget_Preview::on_play_pause_pressed));
+		toolbar->pack_start(*play_button, Gtk::PACK_SHRINK, 0);
+	}
+
+	{ //pause
+		Gtk::Image *icon = manage(new Gtk::Image(Gtk::StockID("synfig-animate_pause"), Gtk::ICON_SIZE_BUTTON));
+		pause_button = manage(new class Gtk::Button());
+		pause_button->set_tooltip_text(_("Pause"));
+		icon->set_padding(0,0);
+		icon->show();
+		pause_button->add(*icon);
+		pause_button->set_relief(Gtk::RELIEF_NONE);
+		pause_button->signal_clicked().connect(sigc::mem_fun(*this,&Widget_Preview::on_play_pause_pressed));
+		toolbar->pack_start(*pause_button, Gtk::PACK_SHRINK, 0);
+	}
 
-	toolbar->pack_start(*play_pausebutton, Gtk::PACK_SHRINK, 0);
 
 	//next rendered frame
 	Gtk::Button *next_framebutton;
@@ -474,8 +498,8 @@ Widget_Preview::Widget_Preview():
 
 	//spacing
 	Gtk::Alignment *space1 = Gtk::manage(new Gtk::Alignment());
-        space1->set_size_request(24);
-        toolbar->pack_start(*space1, false, true);
+	space1->set_size_request(24);
+	toolbar->pack_start(*space1, false, true);
 
 
 	//halt render
@@ -499,6 +523,28 @@ Widget_Preview::Widget_Preview():
 
 	toolbar->pack_start(*button, Gtk::PACK_SHRINK, 0);
 
+	//spacing
+	Gtk::Alignment *space2 = Gtk::manage(new Gtk::Alignment());
+	space1->set_size_request(24);
+	toolbar->pack_start(*space2, false, true);
+
+	//jack
+	jackdial = Gtk::manage(new JackDial());
+#ifdef WITH_JACK
+	jack_dispatcher.connect(sigc::mem_fun(*this, &Widget_Preview::on_jack_sync));
+	jack_dispatcher.connect(sigc::mem_fun(*this, &Widget_Preview::on_jack_sync));
+
+	jackbutton = jackdial->get_toggle_jackbutton();
+	jackdial->signal_toggle_jack().connect(sigc::mem_fun(*this, &studio::Widget_Preview::toggle_jack_button));
+	jackdial->signal_offset_changed().connect(sigc::mem_fun(*this, &studio::Widget_Preview::on_jack_offset_changed));
+#endif
+	//FIXME: Hardcoded FPS!
+	jackdial->set_fps(24.f);
+	jackdial->set_offset(jack_offset);
+	if ( !getenv("SYNFIG_DISABLE_JACK") )
+		jackdial->show();
+	toolbar->pack_start(*jackdial, false, true);
+
 	//zoom preview
 	factor_refTreeModel = Gtk::ListStore::create(factors);
 	zoom_preview.set_model(factor_refTreeModel);
@@ -524,7 +570,7 @@ Widget_Preview::Widget_Preview():
 	row = *(factor_refTreeModel->append());
 	row[factors.factor_id] = "5";
 	row[factors.factor_value] = _("Fit");
-	zoom_preview.set_text_column(factors.factor_value);
+	zoom_preview.set_entry_text_column(factors.factor_value);
 
 	Gtk::Entry* entry = zoom_preview.get_entry();
 	entry->set_text("100%"); //default zoom level
@@ -533,6 +579,7 @@ Widget_Preview::Widget_Preview():
 
 	//set the zoom widget width
 	zoom_preview.set_size_request(100, -1);
+	zoom_preview.show();
 
 	toolbar->pack_end(zoom_preview, Gtk::PACK_SHRINK, 0);
 
@@ -547,16 +594,13 @@ Widget_Preview::Widget_Preview():
 
 	status->show_all();
 
-	//5th row: sound track
-	disp_sound.set_size_request(-1,32);
-
 	// attach all widgets	
 	attach(preview_window, 0, 1, 0, 1, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0);
 	attach(scr_time_scrub, 0, 1, 1, 2, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK);
 	attach(*toolbar, 0, 1, 2, 3, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL);
 	attach(*status, 0, 1, 3, 4, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK);
-//	attach(disp_sound,0,1,4,5,Gtk::EXPAND|Gtk::FILL,Gtk::SHRINK);
-	show_all();
+	preview_window.show_all();
+	scr_time_scrub.show_all();
 
 	//if(draw_area.get_window()) gc_area = Gdk::GC::create(draw_area.get_window());
 	#endif
@@ -564,16 +608,29 @@ Widget_Preview::Widget_Preview():
 
 studio::Widget_Preview::~Widget_Preview()
 {
+	clear();
 }
 
 void studio::Widget_Preview::update()
 {
 	//the meat goes in this locker...
-	double time = adj_time_scrub.get_value();
+	double time = adj_time_scrub->get_value();
 
 	//find the frame and display it...
 	if(preview)
 	{
+		#ifdef WITH_JACK
+		if (jack_enabled && !jack_synchronizing && !is_time_equal_to_current_frame(jack_time - jack_offset))
+		{
+			jack_nframes_t sr = jack_get_sample_rate(jack_client);
+			jack_nframes_t nframes = ((double)sr * (time + jack_offset));
+			jack_transport_locate(jack_client, nframes);
+		}
+		#endif
+
+		if (fabs(soundProcessor.get_position() - time) > 0.5)
+			soundProcessor.set_position(time);
+
 		//synfig::warning("Updating at %.3f s",time);
 
 		//use time to find closest frame...
@@ -653,16 +710,6 @@ void studio::Widget_Preview::update()
 		}
 	}
 
-	if(disp_sound.get_profile() && adj_sound.get_value() != time)
-	{
-		//timeupdate = time;
-
-		//Set the position of the sound (short circuited for sound modifying the time)
-
-		disp_sound.set_position(time);
-		disp_sound.queue_draw();
-	}
-
 	//current frame in previewing
 	Glib::ustring timecode(Time((double)timedisp).round(preview->get_global_fps())
                 .get_string(preview->get_global_fps(), App::get_time_format()));
@@ -674,7 +721,7 @@ void studio::Widget_Preview::preview_draw()
 	draw_area.queue_draw();//on_expose_event();
 }
 
-bool studio::Widget_Preview::redraw(GdkEventExpose */*heh*/)
+bool studio::Widget_Preview::redraw(const Cairo::RefPtr<Cairo::Context> &cr)
 {
 	//And render the drawing area
 	Glib::RefPtr<Gdk::Pixbuf> pxnew, px = currentbuf;
@@ -720,7 +767,6 @@ bool studio::Widget_Preview::redraw(GdkEventExpose */*heh*/)
 	Gtk::Entry* entry = zoom_preview.get_entry();
 	String str(entry->get_text());
 	Glib::ustring text = str;
-	locale_from_utf8 (text);
 	const char *c = text.c_str();
 
 	if (text == _("Fit") || text == "fit")
@@ -770,9 +816,7 @@ bool studio::Widget_Preview::redraw(GdkEventExpose */*heh*/)
 
 	//synfig::info("Now to draw to the window...");
 	//copy to window
-	Glib::RefPtr<Gdk::Window>	wind = draw_area.get_window();
-	Cairo::RefPtr<Cairo::Context> cr = wind->create_cairo_context();
-
+	Glib::RefPtr<Gdk::Window> wind = draw_area.get_window();
 	if(!wind) synfig::warning("The destination window is broken...");
 
 	if(!use_cairo)
@@ -823,32 +867,43 @@ bool studio::Widget_Preview::play_update()
 	if(playing)
 	{
 		//we go to the next one...
-		double time = adj_time_scrub.get_value() + diff;
+		double time = adj_time_scrub->get_value() + diff;
+#ifdef WITH_JACK
+		bool stop_on_end = true;
+#endif
 
-		//adjust it to be synced with the audio if it can...
+		if (jack_enabled)
 		{
-			double newtime = audiotime;
-			if(audio && audio->is_playing()) audio->get_current_time(newtime);
-
-			if(newtime != audiotime)
-			{
-				//synfig::info("Adjusted time from %.3lf to %.3lf", time,newtime);
-				time = audiotime = newtime;
-			}
+#ifdef WITH_JACK
+			jack_position_t pos;
+			jack_transport_state_t state = jack_transport_query(jack_client, &pos);
+			if (state != JackTransportRolling && state != JackTransportStarting)
+				{ on_jack_sync(); return true; }
+			jack_time = Time((Time::value_type)pos.frame/(Time::value_type)pos.frame_rate);
+			time = jack_time - jack_offset;
+			stop_on_end = false;
+#endif
+		}
+		else
+		{
+			//time = soundProcessor.get_position();
 		}
 
+		if (fabs(soundProcessor.get_position() - time) > 0.5)
+			soundProcessor.set_position(time);
+
 		//Looping conditions...
-		if(time >= adj_time_scrub.get_upper())
+		if(time >= adj_time_scrub->get_upper())
 		{
 			if(get_loop_flag())
 			{
-				time = adj_time_scrub.get_lower();// + time-adj_time_scrub.get_upper();
+				time = adj_time_scrub->get_lower();// + time-adj_time_scrub.get_upper();
 				currentindex = 0;
 			}else
 			{
-				time = adj_time_scrub.get_upper();
-				adj_time_scrub.set_value(time);
-				play_pause();
+				time = adj_time_scrub->get_upper();
+				adj_time_scrub->set_value(time);
+				pause();
 				update();
 
 				//synfig::info("Play Stopped: time set to %f",adj_time_scrub.get_value());
@@ -857,8 +912,8 @@ bool studio::Widget_Preview::play_update()
 		}
 
 		//set the new time...
-		adj_time_scrub.set_value(time);
-		adj_time_scrub.value_changed();
+		adj_time_scrub->set_value(time);
+		adj_time_scrub->value_changed();
 
 		//update the window to the correct image we might want to do this later...
 		//update();
@@ -879,24 +934,14 @@ void studio::Widget_Preview::slider_move()
 //for other things updating the value changed signal...
 void studio::Widget_Preview::scrub_updated(double t)
 {
-	pause();
-
-	//Attempt at being more accurate... the time is adjusted to be exactly where the sound says it is
-	//double oldt = t;
-	if(audio)
-	{
-		if(!audio->isPaused())
-		{
-			audio->get_current_time(t);
-		}
-	}
+	if (playing) on_play_pause_pressed();
 
 	//synfig::info("Scrubbing to %.3f, setting adj to %.3f",oldt,t);
 
-	if(adj_time_scrub.get_value() != t)
+	if(adj_time_scrub->get_value() != t)
 	{
-		adj_time_scrub.set_value(t);
-		adj_time_scrub.value_changed();
+		adj_time_scrub->set_value(t);
+		adj_time_scrub->value_changed();
 	}
 }
 
@@ -906,11 +951,14 @@ void studio::Widget_Preview::disconnect_preview(Preview *prev)
 	{
 		preview = 0;
 		prevchanged.disconnect();
+		soundProcessor.clear();
 	}
 }
 
 void studio::Widget_Preview::set_preview(etl::handle<Preview>	prev)
 {
+	disconnect_preview(preview.get());
+
 	preview = prev;
 
 	synfig::info("Setting preview");
@@ -922,6 +970,8 @@ void studio::Widget_Preview::set_preview(etl::handle<Preview>	prev)
 	{
 		//set the internal values
 		float rate = preview->get_fps();
+		jackdial->set_fps(rate);
+		jackdial->set_offset(preview->get_jack_offset());
 		synfig::info("	FPS = %f",rate);
 		if(rate)
 		{
@@ -930,24 +980,27 @@ void studio::Widget_Preview::set_preview(etl::handle<Preview>	prev)
 
 			rate = 1/rate;
 
-			adj_time_scrub.set_lower(start);
-			adj_time_scrub.set_upper(end);
-			adj_time_scrub.set_value(start);
-			adj_time_scrub.set_step_increment(rate);
-			adj_time_scrub.set_page_increment(10*rate);
+			adj_time_scrub->set_lower(start);
+			adj_time_scrub->set_upper(end);
+			adj_time_scrub->set_value(start);
+			adj_time_scrub->set_step_increment(rate);
+			adj_time_scrub->set_page_increment(10*rate);
 
 			//if the begin time and the end time are the same there is only a single frame
 			singleframe = end==start;
 		}else
 		{
-			adj_time_scrub.set_lower(0);
-			adj_time_scrub.set_upper(0);
-			adj_time_scrub.set_value(0);
-			adj_time_scrub.set_step_increment(0);
-			adj_time_scrub.set_page_increment(0);
+			adj_time_scrub->set_lower(0);
+			adj_time_scrub->set_upper(0);
+			adj_time_scrub->set_value(0);
+			adj_time_scrub->set_step_increment(0);
+			adj_time_scrub->set_page_increment(0);
 			singleframe = true;
 		}
 
+		preview->get_canvas()->fill_sound_processor(soundProcessor);
+		set_jack_enabled( preview && preview->get_canvasview()->get_jack_enabled_in_preview() );
+
 		//connect so future information will be found...
 		prevchanged = prev->signal_changed().connect(sigc::mem_fun(*this,&Widget_Preview::whenupdated));
 		prev->signal_destroyed().connect(sigc::mem_fun(*this,&Widget_Preview::disconnect_preview));
@@ -967,86 +1020,75 @@ void studio::Widget_Preview::whenupdated()
 
 void studio::Widget_Preview::clear()
 {
-	preview = 0;
-	prevchanged.disconnect();
+	disconnect_preview(preview.get());
+	set_jack_enabled(false);
 }
 
 void studio::Widget_Preview::play()
 {
+	if (playing) return;
 	if(preview)
 	{
-		//synfig::info("Playing at %lf",adj_time_scrub.get_value());
-		//audiotime = adj_time_scrub.get_value();
+		if (!jack_enabled && get_position() == get_time_end()) seek(get_time_start());
+		soundProcessor.set_position(get_position());
+		soundProcessor.set_playing(true);
+
+		//synfig::info("Playing at %lf",adj_time_scrub->get_value());
+		//audiotime = adj_time_scrub->get_value();
 		playing = true;
 
-		//adj_time_scrub.set_value(adj_time_scrub.get_lower());
+		play_button->hide();
+		pause_button->show();
+
+		//adj_time_scrub->set_value(adj_time_scrub->get_lower());
 		update(); //we don't want to call play update because that will try to advance the timer
-		//synfig::warning("Did update p");
 
 		//approximate length of time in seconds, right?
-		double rate = /*std::min(*/adj_time_scrub.get_step_increment()/*,1/30.0)*/;
+		double rate = /*std::min(*/adj_time_scrub->get_step_increment()/*,1/30.0)*/;
 		int timeout = (int)floor(1000*rate);
 
 		//synfig::info("	rate = %.3lfs = %d ms",rate,timeout);
 
-		signal_play_(adj_time_scrub.get_value());
-
-		//play the audio...
-		if(audio) audio->play(adj_time_scrub.get_value());
+		//signal_play_(adj_time_scrub->get_value());
 
 		timecon = Glib::signal_timeout().connect(sigc::mem_fun(*this,&Widget_Preview::play_update),timeout);
 		timer.reset();
 	}
 }
 
-void studio::Widget_Preview::play_pause()
-{
-	playing = false;
-	signal_pause()();
-	if(audio) audio->stop(); //!< stop the audio
-	//synfig::info("Stopping...");
-
-	Gtk::Image *icon;
-	icon = manage(new Gtk::Image(Gtk::StockID("synfig-animate_play"), Gtk::ICON_SIZE_BUTTON));
-	play_pausebutton->remove();
-	play_pausebutton->add(*icon);
-	play_pausebutton->set_tooltip_text(_("Play"));
-	icon->set_padding(0,0);
-	icon->show();
-	
-}
-
 void studio::Widget_Preview::pause()
 {
 	//synfig::warning("stopping");
-	play_pause();
 	timecon.disconnect();
+	playing = false;
+	pause_button->hide();
+	play_button->show();
+	soundProcessor.set_playing(false);
 }
 
 void studio::Widget_Preview::on_play_pause_pressed()
 {
 	bool play_flag;
-	float begin = preview->get_begintime();
-	float end = preview->get_endtime();
-	float current = adj_time_scrub.get_value();
-	Gtk::Image *icon;
+	//! Commented out , build warnings
+//	float begin = preview->get_begintime();
+//	float end = preview->get_endtime();
+//	float current = adj_time_scrub->get_value();
+//	Gtk::Image *icon;
 
-	if(!playing)
+	play_flag = !playing;
+	
+#ifdef WITH_JACK
+	if (jack_enabled)
 	{
-		play_pausebutton->remove();
-		if(current == end) adj_time_scrub.set_value(begin);
-		icon = manage(new Gtk::Image(Gtk::StockID("synfig-animate_pause"), Gtk::ICON_SIZE_BUTTON));
-		play_pausebutton->set_tooltip_text(_("Pause"));
-		play_pausebutton->add(*icon);
-		icon->set_padding(0,0);
-		icon->show();
+		if (jack_is_playing) {
+			jack_transport_stop(jack_client);
+			on_jack_sync();
+		} else
+			jack_transport_start(jack_client);
+		return;
+	}
+#endif
 
-		play_flag=true;
-	}
-	else
-	{
-		play_flag=false;
-	}
 	if(play_flag) play(); else pause();
 }
 
@@ -1054,14 +1096,15 @@ void studio::Widget_Preview::seek_frame(int frames)
 {
 //	if(!frames)	return;
 
-	if(playing) pause();	//pause playing when seek frame called
+	if(playing) on_play_pause_pressed();	//pause playing when seek frame called
 
 	double fps = preview->get_fps();
-	double currenttime = adj_time_scrub.get_value();
+
+	double currenttime = adj_time_scrub->get_value();
 	int currentframe = (int)floor(currenttime * fps);
 	Time newtime(double((currentframe + frames + 0.5) / fps));
 	
-	adj_time_scrub.set_value(newtime);
+	adj_time_scrub->set_value(newtime);
 }
 
 bool studio::Widget_Preview::scroll_move_event(GdkEvent *event)
@@ -1074,6 +1117,7 @@ bool studio::Widget_Preview::scroll_move_event(GdkEvent *event)
 			{
 				pause();
 			}
+			break;
 		}
 
 		default: break;
@@ -1082,28 +1126,17 @@ bool studio::Widget_Preview::scroll_move_event(GdkEvent *event)
 	return false;
 }
 
-void studio::Widget_Preview::set_audioprofile(etl::handle<AudioProfile> p)
-{
-	disp_sound.set_profile(p);
-}
+synfig::Time studio::Widget_Preview::get_position() const
+	{ return adj_time_scrub->get_value(); }
+synfig::Time studio::Widget_Preview::get_time_start() const
+	{ return adj_time_scrub->get_lower(); }
+synfig::Time studio::Widget_Preview::get_time_end() const
+	{ return adj_time_scrub->get_upper(); }
 
-void studio::Widget_Preview::set_audio(etl::handle<AudioContainer> a)
-{
-	audio = a;
-
-	//disconnect any previous signals
-	scrstartcon.disconnect(); scrstopcon.disconnect(); scrubcon.disconnect();
-
-	//connect the new signals
-	scrstartcon = disp_sound.signal_start_scrubbing().connect(sigc::mem_fun(*a,&AudioContainer::start_scrubbing));
-	scrstopcon = disp_sound.signal_stop_scrubbing().connect(sigc::mem_fun(*a,&AudioContainer::stop_scrubbing));
-	scrubcon = disp_sound.signal_scrub().connect(sigc::mem_fun(*a,&AudioContainer::scrub));
-}
-
-void studio::Widget_Preview::seek(float t)
+void studio::Widget_Preview::seek(const synfig::Time &t)
 {
 	pause();
-	adj_time_scrub.set_value(t);
+	adj_time_scrub->set_value(t);
 }
 
 void studio::Widget_Preview::repreview()
@@ -1200,7 +1233,6 @@ void Widget_Preview::show_toolbar()
 {
 	toolbar->show();
 	toolbarisshown = 1;
-
 	toolbar->grab_focus();
 }
 
@@ -1298,3 +1330,160 @@ bool studio::Widget_Preview::on_key_pressed(GdkEventKey *ev)
 
 	return false;
 }
+
+bool
+Widget_Preview::is_time_equal_to_current_frame(const synfig::Time &time)
+{
+	float fps = preview ? preview->get_fps() : 25.f;
+	Time starttime = get_time_start();
+	Time endtime = get_time_end();
+
+	synfig::Time t0 = get_position();
+	synfig::Time t1 = time;
+
+	if (fps != 0.f) {
+		t0 = t0.round(fps);
+		t1 = t1.round(fps);
+	}
+
+	t0 = std::max(starttime, std::min(endtime, t0));
+	t1 = std::max(starttime, std::min(endtime, t1));
+
+	return t0.is_equal(t1);
+}
+
+void Widget_Preview::on_show()
+{
+	Table::on_show();
+	set_jack_enabled( preview && preview->get_canvasview()->get_jack_enabled_in_preview() );
+}
+
+void Widget_Preview::on_hide()
+{
+	Table::on_hide();
+	if (preview)
+	{
+		bool enabled = get_jack_enabled();
+		set_jack_enabled(false);
+		preview->get_canvasview()->set_jack_enabled_in_preview(enabled);
+	}
+	pause();
+	stoprender();
+}
+
+void Widget_Preview::set_jack_enabled(bool value) {
+	if (jack_enabled == value) return;
+
+#ifdef WITH_JACK
+	if (playing) pause();
+	jack_enabled = value;
+	if (jack_enabled)
+	{
+		// lock jack in canvas views
+		App::jack_lock();
+
+		// initialize jack
+		jack_client = jack_client_open("synfigstudiopreview", JackNullOption, 0);
+		jack_set_sync_callback(jack_client, jack_sync_callback, this);
+		if (jack_activate(jack_client) != 0)
+		{
+			jack_client_close(jack_client);
+			jack_client = NULL;
+			jack_enabled = false;
+			App::jack_unlock();
+		} else {
+			// remember time
+			on_jack_sync();
+			jack_initial_time = jack_time;
+		}
+	}
+	else
+	{
+		// restore time
+		jack_nframes_t sr = jack_get_sample_rate(jack_client);
+		jack_nframes_t nframes = ((double)sr * (jack_initial_time));
+		jack_transport_locate(jack_client, nframes);
+
+		// deinitialize jack
+		jack_deactivate(jack_client);
+		jack_client_close(jack_client);
+		jack_client = NULL;
+
+		// unlock jack in canvas views
+		App::jack_unlock();
+	}
+
+	//jackdial->toggle_enable_jack(jack_enabled);
+
+	Gtk::IconSize iconsize=Gtk::IconSize::from_name("synfig-small_icon_16x16");
+	Gtk::Image *icon;
+	offset_widget = jackdial->get_offsetwidget();
+
+	if (jackbutton->get_active())
+	{
+		icon = manage(new Gtk::Image(Gtk::StockID("synfig-jack"),iconsize));
+		jackbutton->remove();
+		jackbutton->add(*icon);
+		jackbutton->set_tooltip_text(_("Disable JACK"));
+		icon->set_padding(0,0);
+		icon->show();
+
+		offset_widget->show();
+	}
+	else
+	{
+		icon = manage(new Gtk::Image(Gtk::StockID("synfig-jack"),iconsize));
+		jackbutton->remove();
+		jackbutton->add(*icon);
+		jackbutton->set_tooltip_text(_("Enable JACK"));
+		icon->set_padding(0,0);
+		icon->show();
+
+		offset_widget->hide();
+	}
+#endif
+
+	if (preview) preview->get_canvasview()->set_jack_enabled_in_preview( get_jack_enabled() );
+}
+
+
+#ifdef WITH_JACK
+void Widget_Preview::toggle_jack_button()
+{
+	set_jack_enabled(!get_jack_enabled());
+}
+
+void Widget_Preview::on_jack_offset_changed() {
+	jack_offset = jackdial->get_offset();
+	if (get_jack_enabled()) on_jack_sync();
+}
+
+void Widget_Preview::on_jack_sync() {
+	jack_position_t pos;
+	jack_transport_state_t state = jack_transport_query(jack_client, &pos);
+
+	jack_is_playing = state == JackTransportRolling || state == JackTransportStarting;
+	jack_time = Time((Time::value_type)pos.frame/(Time::value_type)pos.frame_rate);
+
+	if (playing != jack_is_playing)
+	{
+		if (jack_is_playing)
+			play();
+		else
+			pause();
+	}
+
+	if (!is_time_equal_to_current_frame(jack_time - jack_offset))
+	{
+		jack_synchronizing = true;
+		seek(jack_time - jack_offset);
+		jack_synchronizing = false;
+	}
+}
+
+int Widget_Preview::jack_sync_callback(jack_transport_state_t /* state */, jack_position_t * /* pos */, void *arg) {
+	Widget_Preview *widget_preview = static_cast<Widget_Preview*>(arg);
+	widget_preview->jack_dispatcher.emit();
+	return 1;
+}
+#endif
