@@ -40,7 +40,7 @@
 #include <gui/canvasview.h>
 #include <gtkmm/tooltip.h>
 #include <gtkmm/alignment.h>
-#include <gtkmm/comboboxentrytext.h>
+#include <gtkmm/comboboxtext.h>
 
 #include <synfig/time.h>
 #include <synfig/vector.h>
@@ -49,9 +49,17 @@
 #include <synfig/canvas.h>
 
 #include "widgets/widget_sound.h"
+#include "dials/jackdial.h"
 
 #include <vector>
 
+#ifdef WITH_JACK
+#include <jack/jack.h>
+#include <jack/transport.h>
+#endif
+
+#include <synfig/soundprocessor.h>
+
 /* === M A C R O S ========================================================= */
 
 /* === T Y P E D E F S ===================================================== */
@@ -70,10 +78,7 @@ public:
 		float t;
 		Glib::RefPtr<Gdk::Pixbuf> buf; //at whatever resolution they are rendered at (resized at run time)
 		cairo_surface_t* surface;
-		FlipbookElem()
-		{
-			surface=NULL;
-		}
+		FlipbookElem(): t(), surface(NULL) { }
 		//Copy constructor
 		FlipbookElem(const FlipbookElem& other): t(other.t) ,buf(other.buf), surface(cairo_surface_reference(other.surface))
 		{
@@ -99,6 +104,7 @@ private:
 	//synfig::RendDesc		description; //for rendering the preview...
 	float	zoom,fps;
 	float	begintime,endtime;
+	float	jack_offset;
 	bool 	overbegin,overend;
 	bool	use_cairo;
 	int		quality;
@@ -127,6 +133,9 @@ public:
 	float 	get_global_fps() const {return global_fps;}
 	void	set_global_fps(float f){global_fps = f;}
 
+	float   get_jack_offset() const {return jack_offset;}
+	void	set_jack_offset(float t){jack_offset = t;}
+
 	float	get_begintime() const
 	{
 		if(overbegin)
@@ -190,30 +199,25 @@ public:
 class Widget_Preview : public Gtk::Table
 {
 	Gtk::DrawingArea	draw_area;
-	Gtk::Adjustment 	adj_time_scrub; //the adjustment for the managed scrollbar
+	Glib::RefPtr<Gtk::Adjustment> adj_time_scrub; //the adjustment for the managed scrollbar
 	Gtk::HScale		scr_time_scrub;
 	Gtk::ToggleButton	b_loop;
 	Gtk::ScrolledWindow	preview_window;
 	//Glib::RefPtr<Gdk::GC>		gc_area;
 	Glib::RefPtr<Gdk::Pixbuf>	currentbuf;
-	cairo_surface_t* current_surface;
-	int				currentindex;
+	cairo_surface_t* 	current_surface;
+	int					currentindex;
 	//double			timeupdate;
 	double				timedisp;
 	double				audiotime;
 
-	//sound stuff
-	etl::handle<AudioContainer>	audio;
-	sigc::connection	scrstartcon;
-	sigc::connection	scrstopcon;
-	sigc::connection	scrubcon;
-
 	//preview encapsulation
 	etl::handle<Preview>	preview;
 	sigc::connection	prevchanged;
 
-	Widget_Sound		disp_sound;
-	Gtk::Adjustment		adj_sound;
+	Gtk::ToggleButton *jackbutton;
+	Widget_Time *offset_widget;
+	Glib::RefPtr<Gtk::Adjustment> adj_sound;
 
 	Gtk::Label		l_lasttime;
 	Gtk::Label		l_currenttime;
@@ -229,9 +233,11 @@ class Widget_Preview : public Gtk::Table
 	//int		curindex; //for later
 	sigc::connection	timecon;
 
+	synfig::SoundProcessor soundProcessor;
+
 	void slider_move(); //later to be a time_slider that's cooler
 	bool play_update();
-	void play_pause();
+
 	//bool play_frameupdate();
 	void update();
 
@@ -246,16 +252,12 @@ class Widget_Preview : public Gtk::Table
 	bool scroll_move_event(GdkEvent *);
 	void disconnect_preview(Preview *);
 
-	bool redraw(GdkEventExpose *heh = 0);
+	bool redraw(const Cairo::RefPtr<Cairo::Context> &cr);
 	void preview_draw();
 
 	void hide_toolbar();
 	void show_toolbar();
 
-	sigc::signal<void,float>	signal_play_;
-	sigc::signal<void>		signal_pause_;
-	sigc::signal<void,float>	signal_seek_;
-
 public:
 
 	Widget_Preview();
@@ -263,14 +265,16 @@ public:
 
 	//sets a signal to identify disconnection (so we don't hold onto it)...
 	void set_preview(etl::handle<Preview> prev);
-	void set_audioprofile(etl::handle<AudioProfile> p);
-	void set_audio(etl::handle<AudioContainer> a);
 
 	void clear();
 
 	void play();
 	void pause();
-	void seek(float t);
+	void seek(const synfig::Time &t);
+	synfig::Time get_position() const;
+	synfig::Time get_time_start() const;
+	synfig::Time get_time_end() const;
+
 
 	void on_play_pause_pressed();
 
@@ -278,13 +282,12 @@ public:
 
 	void stoprender();
 
-	sigc::signal<void,float>	&signal_play() {return signal_play_;}
-	sigc::signal<void>	&signal_pause() {return signal_pause_;}
-	sigc::signal<void,float>	&signal_seek() {return signal_seek_;}
-
 	bool get_loop_flag() const {return b_loop.get_active();}
 	void set_loop_flag(bool b) {return b_loop.set_active(b);}
 
+	virtual void on_show();
+	virtual void on_hide();
+
 protected:
 
 	class ModelColumns : public Gtk::TreeModel::ColumnRecord
@@ -304,16 +307,38 @@ protected:
 
 	ModelColumns factors;
 
-	Gtk::ComboBoxEntry zoom_preview; 
+	Gtk::ComboBoxText zoom_preview;
 	Glib::RefPtr<Gtk::ListStore> factor_refTreeModel;
 	
-
 private:
 
 	Gtk::HBox *toolbar;
-	Gtk::Button *play_pausebutton;
+	Gtk::Button *play_button;
+	Gtk::Button *pause_button;
 	bool on_key_pressed(GdkEventKey*);
 	void on_zoom_entry_activated();
+
+	bool is_time_equal_to_current_frame(const synfig::Time &time);
+
+	JackDial *jackdial;
+	bool jack_enabled;
+	bool jack_is_playing;
+	synfig::Time jack_time;
+	synfig::Time jack_offset;
+	synfig::Time jack_initial_time;
+
+	bool get_jack_enabled() { return jack_enabled; }
+	void set_jack_enabled(bool value);
+
+#ifdef WITH_JACK
+	void toggle_jack_button();
+	void on_jack_offset_changed();
+	Glib::Dispatcher jack_dispatcher;
+	jack_client_t *jack_client;
+	bool jack_synchronizing;
+	void on_jack_sync();
+	static int jack_sync_callback(jack_transport_state_t state, jack_position_t *pos, void *arg);
+#endif
 };
 
 }; // END of namespace studio
