@@ -406,7 +406,7 @@ StateGradient_Context::StateGradient_Context(CanvasView* canvas_view):
 	id_box.pack_start(id_entry, Gtk::PACK_EXPAND_WIDGET);
 
 	// layer (gradient) creation label
-	layer_types_label.set_label(_("Create:"));
+	layer_types_label.set_label(_("Layer Type:"));
 	layer_types_label.set_alignment(Gtk::ALIGN_START, Gtk::ALIGN_CENTER);
 	// layer creation buttons
 	LAYER_CREATION(layer_linear_gradient_togglebutton, toggle_layer_linear_gradient,
