@@ -33,12 +33,13 @@
 
 #include <gtkmm/dialog.h>
 #include <gtkmm/entry.h>
+#include <gdk/gdkkeysyms.h>
 
-#include <synfig/valuenode_animated.h>
-#include <synfig/valuenode_blinecalcvertex.h>
-#include <synfig/valuenode_composite.h>
-#include <synfig/valuenode_const.h>
-#include <synfig/valuenode_dynamiclist.h>
+#include <synfig/valuenodes/valuenode_animated.h>
+#include <synfig/valuenodes/valuenode_blinecalcvertex.h>
+#include <synfig/valuenodes/valuenode_composite.h>
+#include <synfig/valuenodes/valuenode_const.h>
+#include <synfig/valuenodes/valuenode_dynamiclist.h>
 #include <synfigapp/action_system.h>
 
 #include "state_normal.h"
@@ -49,9 +50,9 @@
 #include <synfigapp/action.h>
 #include "event_mouse.h"
 #include "event_layerclick.h"
-#include "toolbox.h"
+#include "event_keyboard.h"
+#include "docks/dock_toolbox.h"
 #include "docks/dialog_tooloptions.h"
-#include <gtkmm/optionmenu.h>
 #include "duck.h"
 #include <synfig/angle.h>
 #include <synfigapp/main.h>
@@ -72,6 +73,18 @@ using namespace studio;
 #define EPSILON	0.0000001
 #endif
 
+#if !GTK_CHECK_VERSION(2, 21, 0)
+#define GDK_KEY_Control_L GDK_Control_L
+#define GDK_KEY_Control_R GDK_Control_R
+#define GDK_KEY_Shift_L GDK_Shift_L
+#define GDK_KEY_Shift_R GDK_Shift_R
+#define GDK_KEY_Alt_L GDK_Alt_L
+#define GDK_KEY_Alt_R GDK_Alt_R
+#define GDK_KEY_Meta_L GDK_Meta_L
+#define GDK_KEY_Meta_R GDK_Meta_R
+#define GDK_KEY_space GDK_space
+#endif
+
 /* === G L O B A L S ======================================================= */
 
 StateNormal studio::state_normal;
@@ -95,6 +108,8 @@ class DuckDrag_Combo : public DuckDrag_Base
 	bool bad_drag;
 	bool move_only;
 
+	bool is_moving;
+
 public:
 	CanvasView* canvas_view_;
 	bool scale;
@@ -117,6 +132,16 @@ class studio::StateNormal_Context : public sigc::trackable
 
 	Gtk::Table options_table;
 
+	bool ctrl_pressed;
+	bool alt_pressed;
+	bool shift_pressed;
+	bool space_pressed;
+
+	void set_ctrl_pressed(bool value);
+	void set_alt_pressed(bool value);
+	void set_shift_pressed(bool value);
+	void set_space_pressed(bool value);
+
 public:
 
 	void refresh_cursor();
@@ -133,6 +158,42 @@ public:
 	void set_constrain_flag(bool x) { if(duck_dragger_ && x!=duck_dragger_->constrain)
 		                                  {duck_dragger_->constrain=x; refresh_cursor();} }
 
+	bool get_alternative_flag()const
+	{
+		return get_canvas_view()
+			&& get_canvas_view()->get_work_area()
+			&& get_canvas_view()->get_work_area()->get_alternative_mode();
+	}
+	void set_alternative_flag(bool x)
+	{
+		if ( get_canvas_view()
+		  && get_canvas_view()->get_work_area()
+		  && get_canvas_view()->get_work_area()->get_alternative_mode() != x )
+		{
+			get_canvas_view()->get_work_area()->set_alternative_mode(x);
+			get_canvas_view()->get_work_area()->queue_draw();
+			refresh_cursor();
+		}
+	}
+
+	bool get_lock_animation_flag()const
+	{
+		return get_canvas_view()
+			&& get_canvas_view()->get_work_area()
+			&& get_canvas_view()->get_work_area()->get_lock_animation_mode();
+	}
+	void set_lock_animation_flag(bool x)
+	{
+		if ( get_canvas_view()
+		  && get_canvas_view()->get_work_area()
+		  && get_canvas_view()->get_work_area()->get_lock_animation_mode() != x )
+		{
+			get_canvas_view()->get_work_area()->set_lock_animation_mode(x);
+			get_canvas_view()->get_work_area()->queue_draw();
+			refresh_cursor();
+		}
+	}
+
 	StateNormal_Context(CanvasView* canvas_view);
 
 	~StateNormal_Context();
@@ -150,6 +211,8 @@ public:
 	Smach::event_result event_mouse_button_down_handler(const Smach::event& x);
 	Smach::event_result event_multiple_ducks_clicked_handler(const Smach::event& x);
 	Smach::event_result event_mouse_motion_handler(const Smach::event& x);
+	Smach::event_result event_key_down_handler(const Smach::event& x);
+	Smach::event_result event_key_up_handler(const Smach::event& x);
 	Smach::event_result event_refresh_tool_options(const Smach::event& x);
 	void refresh_tool_options();
 	Smach::event_result event_layer_click(const Smach::event& x);
@@ -172,6 +235,8 @@ StateNormal::StateNormal():
 	insert(event_def(EVENT_REFRESH_TOOL_OPTIONS,&StateNormal_Context::event_refresh_tool_options));
 	insert(event_def(EVENT_WORKAREA_MOUSE_MOTION,		&StateNormal_Context::event_mouse_motion_handler));
 	insert(event_def(EVENT_WORKAREA_MOUSE_BUTTON_DRAG,	&StateNormal_Context::event_mouse_motion_handler));
+	insert(event_def(EVENT_WORKAREA_KEY_DOWN,&StateNormal_Context::event_key_down_handler));
+	insert(event_def(EVENT_WORKAREA_KEY_UP,&StateNormal_Context::event_key_up_handler));
 	insert(event_def(EVENT_WORKAREA_LAYER_CLICKED,&StateNormal_Context::event_layer_click));
 
 }
@@ -191,6 +256,8 @@ void StateNormal_Context::refresh_cursor()
 	// Change the cursor based on key flags
 	if(get_rotate_flag() && !get_scale_flag())
 	{
+	    //!TODO Do not change the cursor in WorkArea::DragMode mode, but actually not stable enough to catch
+	    //! real DRAGBOX mode (go to DRAGNONE too quick)
 		get_work_area()->set_cursor(Gdk::EXCHANGE);
 		return;
 	}
@@ -204,6 +271,11 @@ void StateNormal_Context::refresh_cursor()
 		get_work_area()->set_cursor(Gdk::CROSSHAIR);
 		return;
 	}
+	if(get_lock_animation_flag())
+	{
+		get_work_area()->set_cursor(Gdk::DRAFT_LARGE);
+		return;
+	}
 
 	// Default cursor for Transform tool
 	get_work_area()->set_cursor(Gdk::ARROW);
@@ -212,15 +284,18 @@ void StateNormal_Context::refresh_cursor()
 
 StateNormal_Context::StateNormal_Context(CanvasView* canvas_view):
 	canvas_view_(canvas_view),
-	duck_dragger_(new DuckDrag_Combo())
+	duck_dragger_(new DuckDrag_Combo()),
+	ctrl_pressed(),
+	alt_pressed(),
+	shift_pressed()
 {
 	duck_dragger_->canvas_view_=get_canvas_view();
 
 	// Set up the tool options dialog
 	options_table.attach(*manage(new Gtk::Label(_("Transform Tool"))),	0, 2, 0, 1, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(*manage(new Gtk::Label(_("Ctrl to rotate"), Gtk::ALIGN_LEFT)),	0, 2, 1, 2, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(*manage(new Gtk::Label(_("Alt to scale"), Gtk::ALIGN_LEFT)),	0, 2, 2, 3, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(*manage(new Gtk::Label(_("Shift to constrain"), Gtk::ALIGN_LEFT)),	0, 2, 3, 4, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(*manage(new Gtk::Label(_("Ctrl to rotate"), Gtk::ALIGN_START)),	0, 2, 1, 2, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(*manage(new Gtk::Label(_("Alt to scale"), Gtk::ALIGN_START)),	0, 2, 2, 3, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(*manage(new Gtk::Label(_("Shift to constrain"), Gtk::ALIGN_START)),	0, 2, 3, 4, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
 
 	options_table.show_all();
 	refresh_tool_options();
@@ -234,7 +309,7 @@ StateNormal_Context::StateNormal_Context(CanvasView* canvas_view):
 //	get_work_area()->set_cursor(Gdk::CROSSHAIR);
 //	get_work_area()->reset_cursor();
 
-	App::toolbox->refresh();
+	App::dock_toolbox->refresh();
 }
 
 void
@@ -255,19 +330,24 @@ StateNormal_Context::~StateNormal_Context()
 
 	App::dialog_tool_options->clear();
 
-	App::toolbox->refresh();
+	App::dock_toolbox->refresh();
 }
 
 DuckDrag_Combo::DuckDrag_Combo():
+	original_mag(),
+	bad_drag(),
+	move_only(),
+	is_moving(false),
+	canvas_view_(NULL),
 	scale(false),
 	rotate(false),
 	constrain(false) // Lock aspect for scale
-{
-}
+{ }
 
 void
 DuckDrag_Combo::begin_duck_drag(Duckmatic* duckmatic, const synfig::Vector& offset)
 {
+	is_moving = false;
 	last_move=Vector(1,1);
 
 	const DuckList selected_ducks(duckmatic->get_selected_ducks());
@@ -440,10 +520,16 @@ DuckDrag_Combo::duck_drag(Duckmatic* duckmatic, const synfig::Vector& vector)
 
 	}
 
+	last_move=vect;
+
+	if((last_move-Vector(1,1)).mag()>0.0001)
+		is_moving = true;
+
+	if (is_moving)
+		duckmatic->signal_edited_selected_ducks(true);
+
 	// then patch up the tangents for the vertices we've moved
 	duckmatic->update_ducks();
-
-	last_move=vect;
 }
 
 bool
@@ -453,7 +539,7 @@ DuckDrag_Combo::end_duck_drag(Duckmatic* duckmatic)
 
 	//synfigapp::Action::PassiveGrouper group(get_canvas_interface()->get_instance().get(),_("Rotate Ducks"));
 
-	if((last_move-Vector(1,1)).mag()>0.0001)
+	if(is_moving)
 	{
 		duckmatic->signal_edited_selected_ducks();
 		return true;
@@ -537,13 +623,130 @@ StateNormal_Context::event_mouse_motion_handler(const Smach::event& x)
 
 	const EventMouse& event(*reinterpret_cast<const EventMouse*>(&x));
 
-	set_rotate_flag(event.modifier&GDK_CONTROL_MASK);
-	set_scale_flag(event.modifier&GDK_MOD1_MASK);
-	set_constrain_flag(event.modifier&GDK_SHIFT_MASK);
+	set_ctrl_pressed(event.modifier&GDK_CONTROL_MASK);
+	set_alt_pressed(event.modifier&GDK_MOD1_MASK);
+	set_shift_pressed(event.modifier&GDK_SHIFT_MASK);
 
 	return Smach::RESULT_OK;
 }
 
+void
+StateNormal_Context::set_ctrl_pressed(bool value)
+{
+	if (ctrl_pressed == value) return;
+	ctrl_pressed = value;
+
+	if (ctrl_pressed)
+	{
+		if (get_canvas_view()->get_work_area()->get_selected_ducks().size() <= 1
+		 /* && get_canvas_view()->get_work_area()->get_selected_duck()->get_value_desc().get_value_type() == synfig::type_transformation */ )
+		{
+			set_rotate_flag(false);
+			set_alternative_flag(true);
+		}
+		else
+		{
+			set_rotate_flag(true);
+			set_alternative_flag(false);
+		}
+	}
+	else
+	{
+		set_alternative_flag(false);
+		set_rotate_flag(false);
+	}
+}
+
+void
+StateNormal_Context::set_alt_pressed(bool value)
+{
+	if (alt_pressed == value) return;
+	alt_pressed = value;
+	set_scale_flag(alt_pressed);
+}
+
+void
+StateNormal_Context::set_shift_pressed(bool value)
+{
+	if (shift_pressed == value) return;
+	shift_pressed = value;
+	set_constrain_flag(shift_pressed);
+}
+
+void
+StateNormal_Context::set_space_pressed(bool value)
+{
+	if (space_pressed == value) return;
+	space_pressed = value;
+	set_lock_animation_flag(space_pressed);
+}
+
+Smach::event_result
+StateNormal_Context::event_key_down_handler(const Smach::event& x)
+{
+	// event.modifier yet not set when ctrl (or alt or shift)
+	// key pressed event handled. So we need to check this keys manually.
+	// We may encountred some cosmetic problems with mouse-cursor image
+	// if user will redefine modifier keys.
+	// Anyway processing of keys Ctrl+Right, Ctrl+Left etc will works fine.
+	// see 'xmodmap' command
+	const EventKeyboard& event(*reinterpret_cast<const EventKeyboard*>(&x));
+	switch(event.keyval)
+	{
+	case GDK_KEY_Control_L:
+	case GDK_KEY_Control_R:
+		set_ctrl_pressed(true);
+		break;
+	case GDK_KEY_Alt_L:
+	case GDK_KEY_Alt_R:
+	case GDK_KEY_Meta_L:
+		set_alt_pressed(true);
+		break;
+	case GDK_KEY_Shift_L:
+	case GDK_KEY_Shift_R:
+		set_shift_pressed(true);
+		break;
+	case GDK_KEY_space:
+		set_space_pressed(true);
+		break;
+	default:
+		set_ctrl_pressed(event.modifier&GDK_CONTROL_MASK);
+		set_alt_pressed(event.modifier&GDK_MOD1_MASK);
+		set_shift_pressed(event.modifier&GDK_SHIFT_MASK);
+		break;
+	}
+	return Smach::RESULT_REJECT;
+}
+
+Smach::event_result
+StateNormal_Context::event_key_up_handler(const Smach::event& x)
+{
+	// see event_key_down_handler for possible problems
+	const EventKeyboard& event(*reinterpret_cast<const EventKeyboard*>(&x));
+	switch(event.keyval)
+	{
+	case GDK_KEY_Control_L:
+	case GDK_KEY_Control_R:
+		set_ctrl_pressed(false);
+		break;
+	case GDK_KEY_Alt_L:
+	case GDK_KEY_Alt_R:
+	case GDK_KEY_Meta_L:
+		set_alt_pressed(false);
+		break;
+	case GDK_KEY_Shift_L:
+	case GDK_KEY_Shift_R:
+		set_shift_pressed(false);
+		break;
+	case GDK_KEY_space:
+		set_space_pressed(false);
+		break;
+	default:
+		break;
+	}
+	return Smach::RESULT_REJECT;
+}
+
 Smach::event_result
 StateNormal_Context::event_layer_click(const Smach::event& x)
 {
@@ -589,7 +792,7 @@ StateNormal_Context::event_layer_click(const Smach::event& x)
 }
 
 Smach::event_result
-StateNormal_Context::event_multiple_ducks_clicked_handler(const Smach::event& /*x*/)
+StateNormal_Context::event_multiple_ducks_clicked_handler(const Smach::event& x)
 {
 	// synfig::info("STATE NORMAL: Received multiple duck click event");
 
@@ -612,7 +815,13 @@ StateNormal_Context::event_multiple_ducks_clicked_handler(const Smach::event& /*
 	Gtk::Menu *menu=manage(new Gtk::Menu());
 	menu->signal_hide().connect(sigc::bind(sigc::ptr_fun(&delete_widget), menu));
 
-	canvas_view_->get_instance()->make_param_menu(menu,canvas_view_->get_canvas(),value_desc_list);
+	const EventMouse& event(*reinterpret_cast<const EventMouse*>(&x));
+	canvas_view_->get_instance()->make_param_menu(
+			menu,
+			canvas_view_->get_canvas(),
+			value_desc_list,
+			event.duck ? event.duck->get_value_desc() : synfigapp::ValueDesc()
+		);
 
 	menu->popup(3,gtk_get_current_event_time());
 
