@@ -34,7 +34,7 @@
 #include <gtkmm/dialog.h>
 #include <gtkmm/entry.h>
 
-#include <synfig/valuenode_dynamiclist.h>
+#include <synfig/valuenodes/valuenode_dynamiclist.h>
 #include <synfigapp/action_system.h>
 
 #include "state_rotate.h"
@@ -46,9 +46,8 @@
 #include <synfigapp/action.h>
 #include "event_mouse.h"
 #include "event_layerclick.h"
-#include "toolbox.h"
+#include "docks/dock_toolbox.h"
 #include "docks/dialog_tooloptions.h"
-#include <gtkmm/optionmenu.h>
 #include "duck.h"
 #include <synfig/angle.h>
 #include <synfigapp/main.h>
@@ -215,7 +214,7 @@ StateRotate_Context::StateRotate_Context(CanvasView* canvas_view):
 	get_work_area()->set_cursor(Gdk::EXCHANGE);
 //	get_work_area()->reset_cursor();
 
-	App::toolbox->refresh();
+	App::dock_toolbox->refresh();
 
 	load_settings();
 	refresh_scale_flag();
@@ -253,16 +252,18 @@ StateRotate_Context::~StateRotate_Context()
 
 	App::dialog_tool_options->clear();
 
-	App::toolbox->refresh();
+	App::dock_toolbox->refresh();
 }
 
 
 
 
-DuckDrag_Rotate::DuckDrag_Rotate()
-{
-	use_magnitude=true;
-}
+DuckDrag_Rotate::DuckDrag_Rotate():
+	original_mag(),
+	bad_drag(),
+	move_only(),
+	use_magnitude(true)
+{ }
 
 void
 DuckDrag_Rotate::begin_duck_drag(Duckmatic* duckmatic, const synfig::Vector& offset)
