@@ -35,9 +35,9 @@
 #include <gtkmm/dialog.h>
 #include <gtkmm/entry.h>
 
-#include <synfig/valuenode_blinecalcvertex.h>
-#include <synfig/valuenode_composite.h>
-#include <synfig/valuenode_dynamiclist.h>
+#include <synfig/valuenodes/valuenode_blinecalcvertex.h>
+#include <synfig/valuenodes/valuenode_composite.h>
+#include <synfig/valuenodes/valuenode_dynamiclist.h>
 #include <synfigapp/action_system.h>
 
 #include "state_smoothmove.h"
@@ -49,9 +49,8 @@
 #include <synfigapp/action.h>
 #include "event_mouse.h"
 #include "event_layerclick.h"
-#include "toolbox.h"
+#include "docks/dock_toolbox.h"
 #include "docks/dialog_tooloptions.h"
-#include <gtkmm/optionmenu.h>
 #include "duck.h"
 #include "onemoment.h"
 #include <synfigapp/main.h>
@@ -110,14 +109,14 @@ class studio::StateSmoothMove_Context : public sigc::trackable
 
 	Gtk::Table options_table;
 
-	Gtk::Adjustment	 adj_radius;
+	Glib::RefPtr<Gtk::Adjustment> adj_radius;
 	Gtk::SpinButton  spin_radius;
 
 	float pressure;
 
 public:
-	float get_radius()const { return adj_radius.get_value(); }
-	void set_radius(float x) { return adj_radius.set_value(x); }
+	float get_radius()const { return adj_radius->get_value(); }
+	void set_radius(float x) { return adj_radius->set_value(x); }
 
 	void refresh_radius() { duck_dragger_->set_radius(get_radius()*pressure); }
 
@@ -192,7 +191,7 @@ StateSmoothMove_Context::StateSmoothMove_Context(CanvasView* canvas_view):
 //	duckmatic_push(get_work_area()),
 	settings(synfigapp::Main::get_selected_input_device()->settings()),
 	duck_dragger_(new DuckDrag_SmoothMove()),
-	adj_radius(1,0,100000,0.01,0.1),
+	adj_radius(Gtk::Adjustment::create(1,0,100000,0.01,0.1)),
 	spin_radius(adj_radius,0.1,3)
 {
 	pressure=1.0f;
@@ -212,7 +211,7 @@ StateSmoothMove_Context::StateSmoothMove_Context(CanvasView* canvas_view):
 	get_work_area()->set_allow_layer_clicks(true);
 	get_work_area()->set_duck_dragger(duck_dragger_);
 
-	App::toolbox->refresh();
+	App::dock_toolbox->refresh();
 
 	get_work_area()->set_cursor(Gdk::FLEUR);
 	//get_work_area()->reset_cursor();
@@ -252,7 +251,7 @@ StateSmoothMove_Context::~StateSmoothMove_Context()
 
 	App::dialog_tool_options->clear();
 
-	App::toolbox->refresh();
+	App::dock_toolbox->refresh();
 }
 
 
@@ -379,14 +378,14 @@ DuckDrag_SmoothMove::end_duck_drag(Duckmatic* duckmatic)
 
 						if (changed) (*iter)->set_point(point);
 
-						if(!(*iter)->signal_edited()(point))
+						if(!(*iter)->signal_edited()(**iter))
 						{
 							throw String("Bad edit");
 						}
 					}
 					else
 					{
-						if(!(*iter)->signal_edited()((*iter)->get_point()))
+						if(!(*iter)->signal_edited()(**iter))
 						{
 							throw String("Bad edit");
 						}
