@@ -36,9 +36,9 @@
 
 #include <ETL/bezier>
 
-#include <synfig/valuenode_dynamiclist.h>
-#include <synfig/valuenode_wplist.h>
-#include <synfig/valuenode_composite.h>
+#include <synfig/valuenodes/valuenode_dynamiclist.h>
+#include <synfig/valuenodes/valuenode_wplist.h>
+#include <synfig/valuenodes/valuenode_composite.h>
 #include <synfigapp/action_system.h>
 
 #include "state_width.h"
@@ -50,10 +50,9 @@
 #include <synfigapp/action.h>
 #include "event_mouse.h"
 #include "event_layerclick.h"
-#include "toolbox.h"
+#include "docks/dock_toolbox.h"
 #include "docks/dialog_tooloptions.h"
 #include "widgets/widget_distance.h"
-#include <gtkmm/optionmenu.h>
 #include "duck.h"
 
 //#include <synfigapp/value_desc.h>
@@ -94,7 +93,7 @@ class studio::StateWidth_Context : public sigc::trackable
 	map<handle<Duck>,Real>	changetable;
 
 	etl::clock	clocktime;
-	Real		lastt;
+	// Real		lastt; // unused
 
 	bool added;
 
@@ -108,7 +107,7 @@ class studio::StateWidth_Context : public sigc::trackable
 	//Toolbox display
 	Gtk::Table options_table;
 
-	Gtk::Adjustment	adj_delta;
+	Glib::RefPtr<Gtk::Adjustment> adj_delta;
 	Gtk::SpinButton	spin_delta;
 
 	Widget_Distance *influence_radius;
@@ -119,8 +118,8 @@ class studio::StateWidth_Context : public sigc::trackable
 
 public:
 
-	Real get_delta()const { return adj_delta.get_value(); }
-	void set_delta(Real f) { adj_delta.set_value(f); }
+	Real get_delta()const { return adj_delta->get_value(); }
+	void set_delta(Real f) { adj_delta->set_value(f); }
 
 	Real get_radius()const { return influence_radius->get_value().get(Distance::SYSTEM_UNITS,get_canvas_view()->get_canvas()->rend_desc());}
 	void set_radius(Distance f) { influence_radius->set_value(f); }
@@ -185,9 +184,9 @@ StateWidth_Context::load_settings()
 			set_delta(6);
 
 		if(settings.get_value("width.radius",value))
-			set_radius(Distance(value.c_str()));
+			set_radius(Distance(atof(value.c_str()), App::distance_system));
 		else
-			set_radius(Distance("60pt"));
+			set_radius(Distance(60, App::distance_system));
 
 		//defaults to false
 		if(settings.get_value("width.relative",value) && value == "1")
@@ -231,7 +230,7 @@ StateWidth_Context::StateWidth_Context(CanvasView* canvas_view):
 
 	settings(synfigapp::Main::get_selected_input_device()->settings()),
 
-	adj_delta(6,0,20,0.01,0.1),
+	adj_delta(Gtk::Adjustment::create(6,0,20,0.01,0.1)),
 	spin_delta(adj_delta,0.01,3),
 
 	check_relative(_("Relative Growth"))
@@ -294,7 +293,7 @@ StateWidth_Context::StateWidth_Context(CanvasView* canvas_view):
 	// Turn the mouse pointer to crosshairs
 	get_work_area()->set_cursor(Gdk::CROSSHAIR);
 
-	App::toolbox->refresh();
+	App::dock_toolbox->refresh();
 }
 
 void
@@ -330,7 +329,7 @@ StateWidth_Context::~StateWidth_Context()
 	// Refresh the work area
 	get_work_area()->queue_draw();
 
-	App::toolbox->refresh();
+	App::dock_toolbox->refresh();
 }
 
 Smach::event_result
@@ -464,7 +463,7 @@ StateWidth_Context::AdjustWidth(handle<Duckmatic::Bezier> c, float t, Real mult,
 				synfigapp::ValueDesc origin_value_desc(iduck_origin->get_value_desc());
 				ValueNode::Handle wpvn(ValueNode::Handle::cast_dynamic(origin_value_desc.get_value_node()));
 				// if the origin duck is widthpoint type and it belongs to a list
-				if(wpvn && wpvn->get_type() == ValueBase::TYPE_WIDTHPOINT && origin_value_desc.parent_is_linkable_value_node())
+				if(wpvn && wpvn->get_type() == type_width_point && origin_value_desc.parent_is_linkable_value_node())
 				{
 					// and if the width point list that it belongs to...
 					ValueNode_WPList::Handle wplist(ValueNode_WPList::Handle::cast_dynamic(origin_value_desc.get_parent_value_node()));
@@ -476,7 +475,7 @@ StateWidth_Context::AdjustWidth(handle<Duckmatic::Bezier> c, float t, Real mult,
 						if(bline && (bline==bezier_bline))
 						{
 							// ... then update the values properly
-							synfig::WidthPoint wpoint((*wpvn)(get_canvas()->get_time()));
+							synfig::WidthPoint wpoint((*wpvn)(get_canvas()->get_time()).get(synfig::WidthPoint()));
 							Real pos(wpoint.get_norm_position(wplist->get_loop()));
 							Real tpos(p1_pos+t*bezier_size);
 							// The factor of 20 can be modified by the user as a preference.
@@ -522,7 +521,7 @@ StateWidth_Context::event_mouse_handler(const Smach::event& x)
 		//if we're dragging get the difference in time between now and then
 		if(event.key == EVENT_WORKAREA_MOUSE_BUTTON_DRAG)
 		{
-			dtime = min(1/15.0,clocktime());
+			dtime = min((float)(1/15.0),(float)(clocktime()));
 		}
 		clocktime.reset();
 
@@ -584,8 +583,7 @@ StateWidth_Context::event_mouse_handler(const Smach::event& x)
 		{
 			//for each duck modify IT!!!
 			ValueDesc desc = i->first->get_value_desc();
-			if(	desc.get_value_type() == ValueBase::TYPE_REAL )
-			{
+			if (desc.get_value_type() == type_real) {
 				Action::Handle action(Action::create("ValueDescSet"));
 				assert(action);
 
@@ -596,6 +594,31 @@ StateWidth_Context::event_mouse_handler(const Smach::event& x)
 				action->set_param("new_value",ValueBase(i->second));
 				action->set_param("time",get_canvas_view()->get_time());
 
+				if(!action->is_ready() || !get_canvas_view()->get_instance()->perform_action(action))
+				{
+					group.cancel();
+					synfig::warning("Changing the width action has failed");
+					return Smach::RESULT_ERROR;
+				}
+			}
+			else
+			if (desc.get_value_type() == type_bline_point
+			 && desc.parent_is_value_desc()
+			 && desc.get_sub_name() == "width")
+			{
+				BLinePoint p;
+				p.set_width(i->second);
+
+				Action::Handle action(Action::create("ValueDescSet"));
+				assert(action);
+
+				action->set_param("canvas",get_canvas());
+				action->set_param("canvas_interface",get_canvas_interface());
+
+				action->set_param("value_desc",desc);
+				action->set_param("new_value",ValueBase(p));
+				action->set_param("time",get_canvas_view()->get_time());
+
 				if(!action->is_ready() || !get_canvas_view()->get_instance()->perform_action(action))
 				{
 					group.cancel();
