@@ -31,6 +31,7 @@
 #	include <config.h>
 #endif
 
+#include "app.h"
 #include "trees/keyframetree.h"
 #include "cellrenderer/cellrenderer_time.h"
 #include <gtkmm/treemodelsort.h>
@@ -110,7 +111,6 @@ KeyframeTree::KeyframeTree()
 		column->set_reorderable();
 		column->set_resizable();
 		column->set_clickable(false);
-		column->set_sort_column(COLUMNID_JUMP); // without this, (JMP) needs a double click?!
 
 		append_column(*column);
 	}
@@ -138,10 +138,15 @@ KeyframeTree::KeyframeTree()
 
 	// Make us more sensitive to several events
 	add_events(Gdk::BUTTON_PRESS_MASK | Gdk::BUTTON_RELEASE_MASK);
+
+	// Listen to the changed selection signal to perform kf synchro thrue canvas interface
+	get_selection()->signal_changed().connect(sigc::mem_fun(*this, &studio::KeyframeTree::on_selection_changed));
+	send_selection = false;
 }
 
 KeyframeTree::~KeyframeTree()
 {
+	keyframeselected.disconnect();
 	if (getenv("SYNFIG_DEBUG_DESTRUCTORS"))
 		synfig::info("KeyframeTree::~KeyframeTree(): Deleted");
 }
@@ -178,6 +183,14 @@ KeyframeTree::set_model(Glib::RefPtr<KeyframeTreeStore> keyframe_tree_store)
 	);
 	cell_renderer_time->property_fps().set_value(keyframe_tree_store_->canvas_interface()->get_canvas()->rend_desc().get_frame_rate());
 	cell_renderer_time_delta->property_fps().set_value(keyframe_tree_store_->canvas_interface()->get_canvas()->rend_desc().get_frame_rate());
+
+	//Listen to kf selection change from canvas interface
+	keyframeselected = keyframe_tree_store_->canvas_interface()->signal_keyframe_selected().connect(
+		sigc::mem_fun(
+			*this,
+			&studio::KeyframeTree::on_keyframe_selected
+		)
+	);
 }
 
 void
@@ -259,27 +272,45 @@ KeyframeTree::on_event(GdkEvent *event)
 {
     switch(event->type)
     {
+	case GDK_KEY_PRESS:
+		{
+			send_selection = true;
+		}
+		break;
 	case GDK_BUTTON_PRESS:
 		{
-			Gtk::TreeModel::Path path;
-			Gtk::TreeViewColumn *column;
-			int cell_x, cell_y;
-			int wx(round_to_int(event->button.x)),wy(round_to_int(event->button.y));
-			//tree_to_widget_coords (,, wx, wy);
-			if(!get_path_at_pos(
-				wx,wy,	// x, y
-				path, // TreeModel::Path&
-				column, //TreeViewColumn*&
-				cell_x,cell_y //int&cell_x,int&cell_y
-				)
-			) break;
-			const Gtk::TreeRow row = *(get_model()->get_iter(path));
-
-			signal_user_click()(event->button.button,row,(ColumnID)column->get_sort_column_id());
-			if((ColumnID)column->get_sort_column_id()==COLUMNID_JUMP)
+			if (event->button.button == 1)
 			{
-				keyframe_tree_store_->canvas_interface()->set_time(row[model.time]);
+				Gtk::TreeModel::Path path;
+				Gtk::TreeViewColumn *column;
+				int cell_x, cell_y;
+				int wx(round_to_int(event->button.x)),wy(round_to_int(event->button.y));
+				//tree_to_widget_coords (,, wx, wy);
+				send_selection = true;
+
+				if(!get_path_at_pos(
+					wx,wy,	// x, y
+					path, // TreeModel::Path&
+					column, //TreeViewColumn*&
+					cell_x,cell_y //int&cell_x,int&cell_y
+					)
+				) break;
+				const Gtk::TreeRow row = *(get_model()->get_iter(path));
+
+				signal_user_click()(event->button.button,row,(ColumnID)column->get_sort_column_id());
+				if (synfig::String(column->get_title ()) == _("Jump"))
+				{
+					keyframe_tree_store_->canvas_interface()->set_time(row[model.time]);
+				}
+			} else if (event->button.button == 3)
+			{
+				Gtk::Menu* menu = dynamic_cast<Gtk::Menu*>(App::ui_manager()->get_widget("/menu-keyframe"));
+				if(menu)
+				{
+					menu->popup(event->button.button,gtk_get_current_event_time());
+				}
 			}
+
 		}
 		break;
 	case GDK_2BUTTON_PRESS:
@@ -310,3 +341,38 @@ KeyframeTree::on_event(GdkEvent *event)
 	}
 	return false;
 }
+
+void
+KeyframeTree::on_selection_changed()
+{
+	//Connected on treeview::selection::changed
+
+	//if(send_selection && has_focus () && get_selection()->count_selected_rows()==1)
+	if(send_selection && get_selection()->count_selected_rows()==1)
+	{
+
+		Keyframe keyframe((*get_selection()->get_selected())[model.keyframe]);
+		if(keyframe && keyframe != selected_kf && keyframe_tree_store_)
+		{
+			selected_kf = keyframe;
+			keyframe_tree_store_->canvas_interface()->signal_keyframe_selected()(keyframe, (void*)this);
+		}
+
+	}
+}
+
+void
+KeyframeTree::on_keyframe_selected(synfig::Keyframe keyframe, void* emitter)
+{
+	Gtk::TreeModel::Path path;
+
+	if((void*)this == emitter)	return;
+
+	if(keyframe && keyframe != selected_kf)
+	{
+		selected_kf = keyframe;
+		send_selection = false;
+		if(keyframe_tree_store_ && keyframe_tree_store_->find_keyframe_path(keyframe,path))
+			set_cursor (path);
+	} else send_selection = true;
+}
