@@ -30,6 +30,8 @@
 #	include <config.h>
 #endif
 
+#include <glibmm/main.h>
+
 #include "layertreestore.h"
 #include "iconcontroller.h"
 #include <gtkmm/button.h>
@@ -38,10 +40,11 @@
 #include <synfigapp/instance.h>
 #include "app.h"
 #include "instance.h"
-#include <synfig/layer_pastecanvas.h>
+#include <synfig/layers/layer_pastecanvas.h>
 #include <synfigapp/action_system.h>
+#include <synfig/context.h>
 
-#include <gtk/gtkversion.h>
+#include <gtk/gtk.h>
 #include <ETL/clock>
 #include "general.h"
 
@@ -74,11 +77,12 @@ LayerTreeStore::LayerTreeStore(etl::loose_handle<synfigapp::CanvasInterface> can
 	queued					(false),
 	canvas_interface_		(canvas_interface_)
 {
-	layer_icon=Gtk::Button().render_icon(Gtk::StockID("synfig-layer"),Gtk::ICON_SIZE_SMALL_TOOLBAR);
+	layer_icon=Gtk::Button().render_icon_pixbuf(Gtk::StockID("synfig-layer"),Gtk::ICON_SIZE_SMALL_TOOLBAR);
 
 	// Connect Signals to Terminals
 	canvas_interface()->signal_layer_status_changed().connect(sigc::mem_fun(*this,&studio::LayerTreeStore::on_layer_status_changed));
 	canvas_interface()->signal_layer_exclude_from_rendering_changed().connect(sigc::mem_fun(*this,&studio::LayerTreeStore::on_layer_exclude_from_rendering_changed));
+	canvas_interface()->signal_layer_z_range_changed().connect(sigc::mem_fun(*this,&studio::LayerTreeStore::on_layer_z_range_changed));
 	canvas_interface()->signal_layer_lowered().connect(sigc::mem_fun(*this,&studio::LayerTreeStore::on_layer_lowered));
 	canvas_interface()->signal_layer_raised().connect(sigc::mem_fun(*this,&studio::LayerTreeStore::on_layer_raised));
 	canvas_interface()->signal_layer_removed().connect(sigc::mem_fun(*this,&studio::LayerTreeStore::on_layer_removed));
@@ -172,7 +176,7 @@ LayerTreeStore::get_value_vfunc (const Gtk::TreeModel::iterator& iter, int colum
 		Glib::Value<float> x;
 		g_value_init(x.gobj(),x.value_type());
 
-		x.set(layer->get_z_depth(canvas_interface()->get_time())*1.0001+layer->get_depth());
+		x.set(layer->get_true_z_depth(canvas_interface()->get_time()));
 
 		g_value_init(value.gobj(),x.value_type());
 		g_value_copy(x.gobj(),value.gobj());
@@ -277,12 +281,51 @@ LayerTreeStore::get_value_vfunc (const Gtk::TreeModel::iterator& iter, int colum
 
 		Glib::Value<Pango::Style> x;
 		g_value_init(x.gobj(),x.value_type());
-
+		//Change style to italic for current layer in treeview in case of excluded from rendering
 		x.set(layer->get_exclude_from_rendering() ? Pango::STYLE_ITALIC : Pango::STYLE_NORMAL);
 
 		g_value_init(value.gobj(),x.value_type());
 		g_value_copy(x.gobj(),value.gobj());
 	}
+	else if(column==model.weight.index())
+	{
+		synfig::Layer::Handle layer((*iter)[model.layer]);
+
+		if(!layer)return;
+
+		Glib::Value<Pango::Weight> x;
+		g_value_init(x.gobj(),x.value_type());
+
+		etl::handle<Layer_PasteCanvas> paste=
+			etl::handle<Layer_PasteCanvas>::cast_dynamic(
+				layer->get_parent_paste_canvas_layer() );
+		if(paste)
+		{
+			etl::handle<synfig::Canvas> sub_canvas=paste->get_param("canvas").get(sub_canvas);
+			if(sub_canvas && !sub_canvas->is_inline())
+			{
+				Gtk::TreeRow row=*iter;
+				if(*row.parent())
+				{
+					paste = etl::handle<Layer_PasteCanvas>::cast_dynamic(
+							Layer::Handle((*row.parent())[model.layer]) );
+				}
+			}
+		}
+		if(paste)
+		{
+			//Change style to bold for current layer in treeview in case of visible in z_depth_visibility
+			synfig::ContextParams cp;
+			paste->apply_z_range_to_params(cp);
+			float visibility=synfig::Context::z_depth_visibility(cp, *layer);
+			x.set(visibility==1.0 && cp.z_range ? Pango::WEIGHT_BOLD : Pango::WEIGHT_NORMAL);
+		}
+		else
+			x.set(Pango::WEIGHT_NORMAL);
+
+		g_value_init(value.gobj(),x.value_type());
+		g_value_copy(x.gobj(),value.gobj());
+	}
 	else if(column==model.icon.index())
 	{
 		synfig::Layer::Handle layer((*iter)[model.layer]);
@@ -488,7 +531,7 @@ LayerTreeStore::row_drop_possible_vfunc (const TreeModel::Path& dest, const Gtk:
 
 		//return true;
 		TreeModel::Path dest_parent(dest);
-		if(!dest_parent.up() || dest.get_depth()==1)
+		if(!dest_parent.up() || dest.size()==1)
 		{
 			//row=(*get_iter(dest));
 			//dest_canvas=(Canvas::Handle)(row[model.canvas]);
@@ -770,7 +813,7 @@ LayerTreeStore::set_row_layer(Gtk::TreeRow &row,synfig::Layer::Handle &handle)
 	{
 		if(iter->get_hidden())
 			continue;
-		if(handle->get_param(iter->get_name()).get_type()!=ValueBase::TYPE_CANVAS)
+		if(handle->get_param(iter->get_name()).get_type()!=type_canvas)
 			continue;
 
 		{
@@ -919,6 +962,22 @@ LayerTreeStore::on_layer_exclude_from_rendering_changed(synfig::Layer::Handle ha
 	}
 }
 
+void
+LayerTreeStore::on_layer_z_range_changed(synfig::Layer::Handle handle,bool /*x*/)
+{
+	// Seems to not work. Need to do something different like call row_changed
+	// for this layer row or all its children.
+	Gtk::TreeModel::Children::iterator iter;
+	if(find_layer_row(handle,iter))
+		(*iter)[model.layer]=handle;
+	else
+	{
+		synfig::warning("Couldn't find layer to be change the z_depth range in layer list. Rebuilding index...");
+		rebuild();
+	}
+}
+
+
 void
 LayerTreeStore::on_layer_lowered(synfig::Layer::Handle layer)
 {
