@@ -51,38 +51,35 @@ using namespace studio;
 
 /* === P R O C E D U R E S ================================================= */
 
-Gdk::Color
-studio::colorconv_synfig2gdk(const synfig::Color &c_)
+synfig::Color
+studio::colorconv_apply_gamma(const synfig::Color &c_)
 {
 	const synfig::Color c(c_.clamped());
-	Gdk::Color ret;
-	ret.set_rgb(
-			256*App::gamma.r_F32_to_U8(c.get_r()),
-			256*App::gamma.g_F32_to_U8(c.get_g()),
-			256*App::gamma.b_F32_to_U8(c.get_b())
-		);
-	return ret;
+	return synfig::Color(
+		App::gamma.r_F32_to_F32(c.get_r()),
+		App::gamma.g_F32_to_F32(c.get_g()),
+		App::gamma.b_F32_to_F32(c.get_b()),
+		c.get_a() );
 }
 
 void
-studio::render_color_to_window(const Glib::RefPtr<Gdk::Drawable>& window,const Gdk::Rectangle& ca,const synfig::Color &color)
+studio::render_color_to_window(const Cairo::RefPtr<Cairo::Context> &cr, const Gdk::Rectangle &ca, const synfig::Color &color)
 {
 	const int height(ca.get_height());
 	const int width(ca.get_width());
 
 	const int square_size(height/2);
 
-	Glib::RefPtr<Gdk::GC> gc(Gdk::GC::create(window));
-
 	if(color.get_alpha()!=1.0)
 	{
 		// In this case we need to render the alpha squares
 
-		const Color bg1(Color::blend(color,Color(0.75, 0.75, 0.75),1.0).clamped());
-		const Color bg2(Color::blend(color,Color(0.5, 0.5, 0.5),1.0).clamped());
-
-		Gdk::Color gdk_c1(colorconv_synfig2gdk(bg1));
-		Gdk::Color gdk_c2(colorconv_synfig2gdk(bg2));
+		const Color bg1(
+			colorconv_apply_gamma(
+				Color::blend(color,Color(0.75, 0.75, 0.75),1.0).clamped() ));
+		const Color bg2(
+			colorconv_apply_gamma(
+				Color::blend(color,Color(0.5, 0.5, 0.5),1.0).clamped() ));
 
 		bool toggle(false);
 		for(int i=0;i<width;i+=square_size)
@@ -91,36 +88,43 @@ studio::render_color_to_window(const Glib::RefPtr<Gdk::Drawable>& window,const G
 
 			if(toggle)
 			{
-				gc->set_rgb_fg_color(gdk_c1);
-				window->draw_rectangle(gc, true, ca.get_x()+i, ca.get_y(), square_width, square_size);
+		        cr->set_source_rgb(bg1.get_r(), bg1.get_g(), bg1.get_b());
+		        cr->rectangle(ca.get_x()+i, ca.get_y(), square_width, square_size);
+		        cr->fill();
 
-				gc->set_rgb_fg_color(gdk_c2);
-				window->draw_rectangle(gc, true, ca.get_x()+i, ca.get_y()+square_size, square_width, square_size);
+		        cr->set_source_rgb(bg2.get_r(), bg2.get_g(), bg2.get_b());
+		        cr->rectangle(ca.get_x()+i, ca.get_y()+square_size, square_width, square_size);
+		        cr->fill();
 				toggle=false;
 			}
 			else
 			{
-				gc->set_rgb_fg_color(gdk_c2);
-				window->draw_rectangle(gc, true, ca.get_x()+i, ca.get_y(), square_width, square_size);
+		        cr->set_source_rgb(bg2.get_r(), bg2.get_g(), bg2.get_b());
+		        cr->rectangle(ca.get_x()+i, ca.get_y(), square_width, square_size);
+		        cr->fill();
 
-				gc->set_rgb_fg_color(gdk_c1);
-				window->draw_rectangle(gc, true, ca.get_x()+i, ca.get_y()+square_size, square_width, square_size);
+		        cr->set_source_rgb(bg1.get_r(), bg1.get_g(), bg1.get_b());
+		        cr->rectangle(ca.get_x()+i, ca.get_y()+square_size, square_width, square_size);
+		        cr->fill();
 				toggle=true;
 			}
 		}
 	}
 	else
 	{
-		// In this case we have a solid color to use
-		Gdk::Color gdk_c1(colorconv_synfig2gdk(color));
-
-		gc->set_rgb_fg_color(gdk_c1);
-		window->draw_rectangle(gc, true, ca.get_x(), ca.get_y(), width-1, height-1);
+		synfig::Color c = colorconv_apply_gamma(color);
+        cr->set_source_rgb(c.get_r(), c.get_g(), c.get_b());
+        cr->rectangle(ca.get_x(), ca.get_y(), width-1, height-1);
+        cr->fill();
 	}
-	gc->set_rgb_fg_color(Gdk::Color("#ffffff"));
-	window->draw_rectangle(gc, false, ca.get_x()+1, ca.get_y()+1, width-3, height-3);
-	gc->set_rgb_fg_color(Gdk::Color("#000000"));
-	window->draw_rectangle(gc, false, ca.get_x(), ca.get_y(), width-1, height-1);
+
+	cr->set_source_rgb(1.0, 1.0, 1.0);
+    cr->rectangle(ca.get_x()+1, ca.get_y()+1, width-3, height-3);
+    cr->stroke();
+
+    cr->set_source_rgb(0.0, 0.0, 0.0);
+    cr->rectangle(ca.get_x(), ca.get_y(), width-1, height-1);
+    cr->stroke();
 }
 
 /* === C L A S S E S ======================================================= */
@@ -132,8 +136,6 @@ Widget_Color::Widget_Color()
 {
 	color=Color(0,0,0,0);
 	set_size_request(-1,16);
-
-	signal_expose_event().connect(sigc::mem_fun(*this, &studio::Widget_Color::redraw));
 	add_events(Gdk::BUTTON_PRESS_MASK | Gdk::BUTTON_RELEASE_MASK);
 
 }
@@ -187,16 +189,8 @@ Widget_Color::on_event(GdkEvent *event)
 }
 
 bool
-Widget_Color::redraw(GdkEventExpose */*bleh*/)
+Widget_Color::on_draw(const Cairo::RefPtr<Cairo::Context> &cr)
 {
-	//!Check if the window we want draw is ready
-	Glib::RefPtr<Gdk::Window> window = get_window();
-	if(!window) return true;
-
-	const int h(get_height());
-	const int w(get_width());
-
-	render_color_to_window(window,Gdk::Rectangle(0,0,w,h),color);
-
+	render_color_to_window(cr, Gdk::Rectangle(0,0,get_width(),get_height()), color);
 	return true;
 }
