@@ -36,13 +36,14 @@
 #include <gtkmm/editable.h>
 #include <gtkmm/entry.h>
 #include <gtkmm/eventbox.h>
-#include <gtk/gtkentry.h> /* see XXX below */
+#include <gtk/gtk.h>
 #include "app.h"
 
 
 #include "widgets/widget_vector.h"
 #include "widgets/widget_filename.h"
 #include "widgets/widget_enum.h"
+#include "widgets/widget_sublayer.h"
 #include "widgets/widget_coloredit.h"
 #include "widgets/widget_bonechooser.h"
 #include "widgets/widget_canvaschooser.h"
@@ -73,9 +74,9 @@ using namespace studio;
 Widget_ValueBase::Widget_ValueBase():
 	Glib::ObjectBase	(typeid(Widget_ValueBase)),
 	Gtk::HBox(),
-	real_adjustment(0,-2000000000,2000000000,0.05,0.05,0),
-	integer_adjustment(0,-2000000000,2000000000,1,1,0),
-	angle_adjustment(0,-2000000000,2000000000,1,1,0)
+	real_adjustment(Gtk::Adjustment::create(0,-2000000000,2000000000,0.05,0.05,0)),
+	integer_adjustment(Gtk::Adjustment::create(0,-2000000000,2000000000,1,1,0)),
+	angle_adjustment(Gtk::Adjustment::create(0,-2000000000,2000000000,1,1,0))
 {
 	set_no_show_all();
 
@@ -92,6 +93,9 @@ Widget_ValueBase::Widget_ValueBase():
 	enum_widget=manage(new class Widget_Enum());
 	pack_start(*enum_widget);
 
+	sublayer_widget=manage(new class Widget_Sublayer());
+	pack_start(*sublayer_widget);
+
 	real_widget=manage(new class Gtk::SpinButton(real_adjustment,0.05,DIGITS));
 	pack_start(*real_widget);
 
@@ -129,12 +133,13 @@ Widget_ValueBase::Widget_ValueBase():
 	vector_widget->signal_activate().connect(sigc::mem_fun(*this,&Widget_ValueBase::activate));
 	color_widget->signal_activate().connect(sigc::mem_fun(*this,&Widget_ValueBase::activate));
 	enum_widget->signal_changed().connect(sigc::mem_fun(*this,&Widget_ValueBase::activate));
+	sublayer_widget->signal_changed().connect(sigc::mem_fun(*this,&Widget_ValueBase::activate));
 	real_widget->signal_activate().connect(sigc::mem_fun(*this,&Widget_ValueBase::activate));
 	integer_widget->signal_activate().connect(sigc::mem_fun(*this,&Widget_ValueBase::activate));
 	angle_widget->signal_activate().connect(sigc::mem_fun(*this,&Widget_ValueBase::activate));
 	string_widget->signal_activate().connect(sigc::mem_fun(*this,&Widget_ValueBase::activate));
-	bone_widget->signal_activate().connect(sigc::mem_fun(*this,&Widget_ValueBase::activate));
-	canvas_widget->signal_activate().connect(sigc::mem_fun(*this,&Widget_ValueBase::activate));
+	bone_widget->signal_changed().connect(sigc::mem_fun(*this,&Widget_ValueBase::activate));
+	canvas_widget->signal_changed().connect(sigc::mem_fun(*this,&Widget_ValueBase::activate));
 	filename_widget->signal_activate().connect(sigc::mem_fun(*this,&Widget_ValueBase::activate));
 	time_widget->signal_activate().connect(sigc::mem_fun(*this,&Widget_ValueBase::activate));
 	distance_widget->signal_activate().connect(sigc::mem_fun(*this,&Widget_ValueBase::activate));
@@ -162,7 +167,8 @@ void
 Widget_ValueBase::inside_cellrenderer()
 {
 	string_widget->set_has_frame(false);
-	string_widget->gobj()->is_cell_renderer = true; // XXX
+	// TODO: what is it?
+	//string_widget->gobj()->is_cell_renderer = true; // XXX
 
 	real_widget->set_has_frame(false);
 	//static_cast<Gtk::Entry*>(real_widget)->gobj()->is_cell_renderer = true; // XXX
@@ -195,6 +201,7 @@ Widget_ValueBase::set_sensitive(bool x)
 	bone_widget->set_sensitive(x);
 	canvas_widget->set_sensitive(x);
 	enum_widget->set_sensitive(x);
+	sublayer_widget->set_sensitive(x);
 	angle_widget->set_sensitive(x);
 	filename_widget->set_sensitive(x);
 	time_widget->set_sensitive(x);
@@ -214,6 +221,7 @@ Widget_ValueBase::set_value(const synfig::ValueBase &data)
 	bone_widget->hide();
 	canvas_widget->hide();
 	enum_widget->hide();
+	sublayer_widget->hide();
 	angle_widget->hide();
 	filename_widget->hide();
 	time_widget->hide();
@@ -221,37 +229,44 @@ Widget_ValueBase::set_value(const synfig::ValueBase &data)
 
 	value=data;
 	try{
-	switch(value.get_type())
-	{
-	case ValueBase::TYPE_VECTOR:
-		vector_widget->set_canvas(canvas);
-		vector_widget->set_value(value.get(Vector()));
-		vector_widget->show();
-		break;
-	case ValueBase::TYPE_REAL:
-		if(( child_param_desc.get_is_distance() || param_desc.get_is_distance() )&& canvas)
+		Type &type(value.get_type());
+		if (type == type_vector)
 		{
-			Distance dist(value.get(Real()),Distance::SYSTEM_UNITS);
-			dist.convert(App::distance_system,canvas->rend_desc());
-			distance_widget->set_value(dist);
-			distance_widget->show();
+			vector_widget->set_canvas(canvas);
+			vector_widget->set_value(value.get(Vector()));
+			vector_widget->show();
 		}
 		else
+		if (type == type_real)
 		{
-			real_widget->set_value(value.get(Real()));
-			real_widget->show();
+			if(( child_param_desc.get_is_distance() || param_desc.get_is_distance() )&& canvas)
+			{
+				Distance dist(value.get(Real()),Distance::SYSTEM_UNITS);
+				dist.convert(App::distance_system,canvas->rend_desc());
+				distance_widget->set_value(dist);
+				distance_widget->show();
+			}
+			else
+			{
+				real_widget->set_value(value.get(Real()));
+				real_widget->show();
+			}
 		}
-		break;
-	case ValueBase::TYPE_TIME:
-		if(canvas)time_widget->set_fps(canvas->rend_desc().get_frame_rate());
-		time_widget->set_value(value.get(Time()));
-		time_widget->show();
-		break;
-	case ValueBase::TYPE_ANGLE:
-		angle_widget->set_value(Angle::deg(value.get(Angle())).get());
-		angle_widget->show();
-		break;
-	case ValueBase::TYPE_INTEGER:
+		else
+		if (type == type_time)
+		{
+			if(canvas)time_widget->set_fps(canvas->rend_desc().get_frame_rate());
+			time_widget->set_value(value.get(Time()));
+			time_widget->show();
+		}
+		else
+		if (type == type_angle)
+		{
+			angle_widget->set_value(Angle::deg(value.get(Angle())).get());
+			angle_widget->show();
+		}
+		else
+		if (type == type_integer)
 		{
 			String child_param_hint(child_param_desc.get_hint());
 			String param_hint(param_desc.get_hint());
@@ -270,85 +285,100 @@ Widget_ValueBase::set_value(const synfig::ValueBase &data)
 				enum_widget->show();
 			}
 		}
-		break;
-	case ValueBase::TYPE_VALUENODE_BONE:
-		assert(canvas);
-		bone_widget->set_parent_canvas(canvas);
-		bone_widget->set_value_desc(get_value_desc());
-		bone_widget->set_value(value.get(etl::loose_handle<synfig::ValueNode_Bone>()));
-		bone_widget->show();
-		break;
-	case ValueBase::TYPE_CANVAS:
-		assert(canvas);
-		canvas_widget->set_parent_canvas(canvas);
-		canvas_widget->set_value(value.get(etl::loose_handle<synfig::Canvas>()));
-		canvas_widget->show();
-		break;
-	case ValueBase::TYPE_BOOL:
-		bool_widget->set_active(value.get(bool()));
-		bool_widget->show();
-		break;
-	case ValueBase::TYPE_STRING:
-		if(child_param_desc.get_hint()!="filename" && param_desc.get_hint()!="filename")
+		else
+		if (type == type_bone_valuenode)
 		{
-			string_widget->set_text(value.get(string()));
-			string_widget->show();
+			assert(canvas);
+			bone_widget->set_parent_canvas(canvas);
+			bone_widget->set_value_desc(get_value_desc());
+			bone_widget->set_value(value.get(etl::loose_handle<synfig::ValueNode_Bone>()));
+			bone_widget->show();
+		}
+		else
+		if (type == type_canvas)
+		{
+			assert(canvas);
+			canvas_widget->set_parent_canvas(canvas);
+			canvas_widget->set_value(value.get(etl::loose_handle<synfig::Canvas>()));
+			canvas_widget->show();
+		}
+		else
+		if (type == type_bool)
+		{
+			bool_widget->set_active(value.get(bool()));
+			bool_widget->show();
+		}
+		else
+		if (type == type_string)
+		{
+			if(child_param_desc.get_hint()=="filename" || param_desc.get_hint()=="filename")
+			{
+				filename_widget->set_value(value.get(string()));
+				filename_widget->show();
+			}
+			else if(child_param_desc.get_hint()=="sublayer_name" || param_desc.get_hint()=="sublayer_name")
+			{
+				sublayer_widget->set_value_desc(value_desc);
+				sublayer_widget->set_value(value.get(string()));
+				sublayer_widget->show();
+			}
+			else
+			{
+				string_widget->set_text(value.get(string()));
+				string_widget->show();
+			}
+		}
+		else
+		if (type == type_color)
+		{
+			color_widget->set_value(value.get(synfig::Color()));
+			color_widget->show();
+	/*
+				Gdk::Color gdkcolor;
+				synfig::Color color=value.get(synfig::Color());
+				gdkcolor.set_rgb_p(color.get_r(),color.get_g(),color.get_b());
+				color_widget->set_current_color(gdkcolor);
+				color_widget->set_has_opacity_control(true);
+				color_widget->set_current_alpha((unsigned short)(color.get_a()*65535.0));
+				color_widget->show();
+	*/
 		}
 		else
 		{
-			filename_widget->set_value(value.get(string()));
-			filename_widget->show();
+			label->show();
 		}
-		break;
-	case ValueBase::TYPE_COLOR:
-        {
-		color_widget->set_value(value.get(synfig::Color()));
-		color_widget->show();
-/*
-			Gdk::Color gdkcolor;
-			synfig::Color color=value.get(synfig::Color());
-			gdkcolor.set_rgb_p(color.get_r(),color.get_g(),color.get_b());
-			color_widget->set_current_color(gdkcolor);
-			color_widget->set_has_opacity_control(true);
-			color_widget->set_current_alpha((unsigned short)(color.get_a()*65535.0));
-			color_widget->show();
-*/
-		}
-		break;
-	default:
-		label->show();
-		break;
-	}
 	}catch(...) { synfig::error(__FILE__":%d: Caught something that was thrown",__LINE__); }
 }
 
 const synfig::ValueBase &
 Widget_ValueBase::get_value()
 {
-	switch(value.get_type())
-	{
-	case ValueBase::TYPE_VECTOR:
+	Type &type(value.get_type());
+	if (type == type_vector)
 		value=vector_widget->get_value();
-		break;
-	case ValueBase::TYPE_REAL:
+	else
+	if (type == type_real)
+	{
 		if((child_param_desc.get_is_distance() || param_desc.get_is_distance()) && canvas)
 			value=distance_widget->get_value().units(canvas->rend_desc());
 		else
 			value=real_widget->get_value();
-		break;
-	case ValueBase::TYPE_TIME:
+	}
+	else
+	if (type == type_time)
 		value=time_widget->get_value();
-		break;
-	case ValueBase::TYPE_ANGLE:
+	else
+	if (type == type_angle)
 		value=Angle::deg(angle_widget->get_value());
-		break;
-	case ValueBase::TYPE_VALUENODE_BONE:
+	else
+	if (type == type_bone_valuenode)
 		value=bone_widget->get_value();
-		break;
-	case ValueBase::TYPE_CANVAS:
+	else
+	if (type == type_canvas)
 		value=canvas_widget->get_value();
-		break;
-	case ValueBase::TYPE_INTEGER:
+	else
+	if (type == type_integer)
+	{
 		if(child_param_desc.get_hint()!="enum" && param_desc.get_hint()!="enum")
 		{
 			value=integer_widget->get_value_as_int();
@@ -357,39 +387,40 @@ Widget_ValueBase::get_value()
 		{
 			value=enum_widget->get_value();
 		}
-
-		break;
-	case ValueBase::TYPE_BOOL:
+	}
+	else
+	if (type == type_bool)
 		value=bool_widget->get_active();
-		break;
-	case ValueBase::TYPE_STRING:
-		if(param_desc.get_hint()!="filename")
-		{
-			value=string(string_widget->get_text());
-		}
-		else
+	else
+	if (type == type_string)
+	{
+		if(param_desc.get_hint()=="filename")
 		{
 			value=string(filename_widget->get_value());
 		}
-		break;
-	case ValueBase::TYPE_COLOR:
-        {
-			value=color_widget->get_value();
-/*
-			Gdk::Color gdkcolor;
-			synfig::Color color;
-			gdkcolor=color_widget->get_current_color();
-			color.set_r(gdkcolor.get_red_p());
-            color.set_g(gdkcolor.get_green_p());
-            color.set_b(gdkcolor.get_blue_p());
-			color.set_a(color_widget->get_current_alpha()/65535.0);
-
-			value=color;
-*/
+		else if(param_desc.get_hint()=="sublayer_name") {
+			value=string(sublayer_widget->get_value());
 		}
-		break;
-	default:
-		break;
+		else
+		{
+			value=string(string_widget->get_text());
+		}
+	}
+	else
+	if (type == type_color)
+	{
+		value=color_widget->get_value();
+/*
+		Gdk::Color gdkcolor;
+		synfig::Color color;
+		gdkcolor=color_widget->get_current_color();
+		color.set_r(gdkcolor.get_red_p());
+		color.set_g(gdkcolor.get_green_p());
+		color.set_b(gdkcolor.get_blue_p());
+		color.set_a(color_widget->get_current_alpha()/65535.0);
+
+		value=color;
+*/
 	}
 
 	return value;
@@ -399,30 +430,32 @@ Widget_ValueBase::get_value()
 void
 Widget_ValueBase::on_grab_focus()
 {
-	switch(value.get_type())
-	{
-	case ValueBase::TYPE_VECTOR:
+	Type &type(value.get_type());
+	if (type == type_vector)
 		vector_widget->grab_focus();
-		break;
-	case ValueBase::TYPE_REAL:
+	else
+	if (type == type_real)
+	{
 		if(param_desc.get_is_distance()&& canvas)
 			distance_widget->grab_focus();
 		else
 			real_widget->grab_focus();
-		break;
-	case ValueBase::TYPE_TIME:
+	}
+	else
+	if (type == type_time)
 		time_widget->grab_focus();
-		break;
-	case ValueBase::TYPE_ANGLE:
+	else
+	if (type == type_angle)
 		angle_widget->grab_focus();
-		break;
-	case ValueBase::TYPE_VALUENODE_BONE:
+	else
+	if (type == type_bone_valuenode)
 		bone_widget->grab_focus();
-		break;
-	case ValueBase::TYPE_CANVAS:
+	else
+	if (type == type_canvas)
 		canvas_widget->grab_focus();
-		break;
-	case ValueBase::TYPE_INTEGER:
+	else
+	if (type == type_integer)
+	{
 		if(child_param_desc.get_hint()!="enum" && param_desc.get_hint()!="enum")
 		{
 			integer_widget->grab_focus();
@@ -431,70 +464,71 @@ Widget_ValueBase::on_grab_focus()
 		{
 			enum_widget->grab_focus();
 		}
-
-		break;
-	case ValueBase::TYPE_BOOL:
+	}
+	else
+	if (type == type_bool)
 		bool_widget->grab_focus();
-		break;
-	case ValueBase::TYPE_STRING:
-		if(param_desc.get_hint()!="filename")
-		{
-			string_widget->grab_focus();
-		}
-		else
+	else
+	if (type == type_string)
+	{
+		if(param_desc.get_hint()=="filename")
 		{
 			filename_widget->grab_focus();
 		}
-		break;
-	case ValueBase::TYPE_COLOR:
-        {
-			color_widget->grab_focus();
+		else if(param_desc.get_hint()=="sublayer_name") {
+			sublayer_widget->grab_focus();
+		}
+		else
+		{
+			string_widget->grab_focus();
 		}
-		break;
-	default:
-		break;
 	}
+	else
+	if (type == type_color)
+		color_widget->grab_focus();
 }
 
 /*
 Glib::SignalProxy0<void>
 Widget_ValueBase::signal_activate()
 {
-	switch(value.get_type())
-	{
-	case ValueBase::TYPE_VECTOR:
+	Type &type(value.get_type());
+	if (type == type_vector)
 		return vector_widget->signal_activate();
-		break;
-	case ValueBase::TYPE_REAL:
+	else
+	if (type == type_real)
+	{
 		if(param_desc.get_is_distance()&& canvas)
 			return distance_widget->signal_activate();
 		else
 			return real_widget->signal_activate();
-
-		break;
-	case ValueBase::TYPE_TIME:
+	}
+	else
+	if (type == type_time)
 		return time_widget->signal_activate();
-		break;
-	case ValueBase::TYPE_ANGLE:
+	else
+	if (type == type_angle)
 		return angle_widget->signal_activate();
-		break;
-	case ValueBase::TYPE_VALUENODE_BONE:
+	else
+	if (type == type_bone_valuenode)
 		return bone_widget->signal_activate();
-		break;
-	case ValueBase::TYPE_CANVAS:
+	else
+	if (type == type_canvas)
 		return canvas_widget->signal_activate();
-		break;
-	case ValueBase::TYPE_INTEGER:
+	else
+	if (type == type_integer)
+	{
 		if(param_desc.get_hint()!="enum")
 			return integer_widget->signal_activate();
 		else
 			return enum_widget->signal_activate();
-
-		break;
-	case ValueBase::TYPE_BOOL:
+	}
+	else
+	if (type == type_bool)
 		return string_widget->signal_activate();
-		break;
-	case ValueBase::TYPE_STRING:
+	else
+	if (type == type_string)
+	{
 		if(param_desc.get_hint()!="filename")
 		{
 			return string_widget->signal_activate();
@@ -503,15 +537,11 @@ Widget_ValueBase::signal_activate()
 		{
 			return filename_widget->signal_activate();
 		}
-		break;
-	case ValueBase::TYPE_COLOR:
-        {
-			return color_widget->signal_activate();
-		}
-		break;
-	default:
-		return string_widget->signal_activate();
-		break;
 	}
+	else
+	if (type == type_color)
+		return color_widget->signal_activate();
+
+	return string_widget->signal_activate();
 }
 */
