@@ -28,7 +28,6 @@
 /* === H E A D E R S ======================================================= */
 
 //#include <gtk/gtk.h>
-//#include <gtkmm/ruler.h>
 //#include <gtkmm/arrow.h>
 //#include <gtkmm/image.h>
 //#include <gdkmm/pixbufloader.h>
@@ -48,7 +47,7 @@
 #include <gtkmm/checkbutton.h>
 
 //#include <gtkmm/colorselection.h>
-#include <gtkmm/optionmenu.h>
+#include <gtkmm/combobox.h>
 
 //#include <synfig/synfig.h>
 #include <synfig/paramdesc.h>
@@ -70,6 +69,7 @@ class Widget_Color;
 class Widget_ColorEdit;
 class Widget_CanvasChooser;
 class Widget_Enum;
+class Widget_Sublayer;
 class Widget_Filename;
 class Widget_Vector;
 class Widget_Time;
@@ -82,11 +82,11 @@ class Widget_ValueBase : public Gtk::HBox
 
 	Widget_Vector *vector_widget;
 	Gtk::SpinButton *real_widget;
-	Gtk::Adjustment real_adjustment;
+	Glib::RefPtr<Gtk::Adjustment> real_adjustment;
 	Gtk::SpinButton *integer_widget;
-	Gtk::Adjustment integer_adjustment;
+	Glib::RefPtr<Gtk::Adjustment> integer_adjustment;
 	Gtk::SpinButton *angle_widget;
-	Gtk::Adjustment angle_adjustment;
+	Glib::RefPtr<Gtk::Adjustment> angle_adjustment;
 
 	Gtk::CheckButton *bool_widget;
 	//Gtk::ColorSelection *color_widget;
@@ -94,6 +94,7 @@ class Widget_ValueBase : public Gtk::HBox
 	Widget_ColorEdit *color_widget;
 	Widget_CanvasChooser *canvas_widget;
 	Widget_Enum *enum_widget;
+	Widget_Sublayer *sublayer_widget;
 	Widget_Filename *filename_widget;
 	Widget_Time *time_widget;
 	Gtk::Entry *string_widget;
