@@ -1,6 +1,7 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file renderer_bbox.cpp
-**	\brief Template File
+**  \brief Renderer_BBox classe is used to render in the workarea the bouding box
+** of the selected layer(s)
 **
 **	$Id$
 **
@@ -68,7 +69,7 @@ Renderer_BBox::get_bbox()
 
 void
 Renderer_BBox::render_vfunc(
-	const Glib::RefPtr<Gdk::Drawable>& drawable,
+	const Glib::RefPtr<Gdk::Window>& drawable,
 	const Gdk::Rectangle& /*expose_area*/
 )
 {
