@@ -40,9 +40,9 @@
 #include <ETL/misc>
 #include "widgets/widget_color.h"
 #include <synfig/distance.h>
-#include <synfig/valuenode_wplist.h>
-#include <synfig/valuenode_bline.h>
-#include <synfig/valuenode_composite.h>
+#include <synfig/valuenodes/valuenode_wplist.h>
+#include <synfig/valuenodes/valuenode_bline.h>
+#include <synfig/valuenodes/valuenode_composite.h>
 #include "app.h"
 
 #include "general.h"
@@ -83,13 +83,14 @@ struct ScreenDuck
 	bool selected;
 	bool hover;
 	Real width;
+	bool has_alternative;
 
-	ScreenDuck():width(0) { }
+	ScreenDuck(): selected(), hover(), width(0), has_alternative(false) { }
 };
 
 void
 Renderer_Ducks::render_vfunc(
-	const Glib::RefPtr<Gdk::Drawable>& drawable,
+	const Glib::RefPtr<Gdk::Window>& drawable,
 	const Gdk::Rectangle& /*expose_area*/
 )
 {
@@ -101,6 +102,7 @@ Renderer_Ducks::render_vfunc(
 	const float pw(get_pw()),ph(get_ph());
 
 	const bool solid_lines(get_work_area()->solid_lines);
+	bool alternative = get_work_area()->get_alternative_mode();
 
 	const std::list<etl::handle<Duckmatic::Bezier> >& bezier_list(get_work_area()->bezier_list());
 	const std::list<handle<Duckmatic::Stroke> >& stroke_list(get_work_area()->stroke_list());
@@ -119,19 +121,14 @@ Renderer_Ducks::render_vfunc(
 
 		std::list<synfig::Point>::iterator iter2;
 		for(iter2=(*iter)->stroke_data->begin();iter2!=(*iter)->stroke_data->end();++iter2)
-		{
-			cr->line_to(
-				((*iter2)[0]-window_start[0])/pw,
-				((*iter2)[1]-window_start[1])/ph
-				);
-		}
+			if (!iter2->is_nan_or_inf())
+				cr->line_to(
+					((*iter2)[0]-window_start[0])/pw,
+					((*iter2)[1]-window_start[1])/ph );
 
 		cr->set_line_width(1.0);
-		cr->set_source_rgb(
-			colorconv_synfig2gdk((*iter)->color).get_red_p(),
-			colorconv_synfig2gdk((*iter)->color).get_green_p(),
-			colorconv_synfig2gdk((*iter)->color).get_blue_p()
-			);
+		synfig::Color c = colorconv_apply_gamma((*iter)->color);
+		cr->set_source_rgb(c.get_r(), c.get_g(), c.get_b());
 		cr->stroke();
 
 		cr->restore();
@@ -146,6 +143,12 @@ Renderer_Ducks::render_vfunc(
 		Point p2((*iter)->p2->get_trans_point()-window_start);
 		Point c1((*iter)->c1->get_trans_point()-window_start);
 		Point c2((*iter)->c2->get_trans_point()-window_start);
+		if (p1.is_nan_or_inf()
+		 || p2.is_nan_or_inf()
+		 || c1.is_nan_or_inf()
+		 || c2.is_nan_or_inf() )
+			continue;
+
 		p1[0]/=pw;p1[1]/=ph;
 		p2[0]/=pw;p2[1]/=ph;
 		c1[0]/=pw;c1[1]/=ph;
@@ -204,6 +207,8 @@ Renderer_Ducks::render_vfunc(
 
 		Point sub_trans_point((*iter)->get_sub_trans_point());
 		Point sub_trans_origin((*iter)->get_sub_trans_origin());
+		if (sub_trans_point.is_nan_or_inf() || sub_trans_origin.is_nan_or_inf())
+			continue;
 
 		if (App::restrict_radius_ducks &&
 			(*iter)->is_radius())
@@ -214,28 +219,17 @@ Renderer_Ducks::render_vfunc(
 				sub_trans_point[1] = sub_trans_origin[1];
 		}
 
-		if ((*iter)->is_linear())
-		{
-			Point sub_trans_offset(sub_trans_point - sub_trans_origin);
-			Angle constrained_angle((*iter)->get_linear_angle());
-			Angle difference(Angle::tan(sub_trans_offset[1], sub_trans_offset[0])-constrained_angle);
-			Real length(Angle::cos(difference).get()*sub_trans_offset.mag());
-			if (length < 0) length = 0;
-			sub_trans_point[0] = sub_trans_origin[0] + length * Angle::cos(constrained_angle).get();
-			sub_trans_point[1] = sub_trans_origin[1] + length * Angle::sin(constrained_angle).get();
-		}
-
 		Point point((*iter)->get_transform_stack().perform(sub_trans_point));
 		Point origin((*iter)->get_transform_stack().perform(sub_trans_origin));
 
 		point[0]=(point[0]-window_start[0])/pw;
 		point[1]=(point[1]-window_start[1])/ph;
 
-		bool has_connect(false);
-		if((*iter)->get_tangent() || (*iter)->get_type()&Duck::TYPE_ANGLE)
-		{
-			has_connect=true;
-		}
+		bool has_connect = (*iter)->get_tangent()
+		                || ((*iter)->get_type()&( Duck::TYPE_ANGLE
+		                					   | Duck::TYPE_SKEW
+		        		                       | Duck::TYPE_SCALE_X
+		        		                       | Duck::TYPE_SCALE_Y ));
 		if((*iter)->get_connect_duck())
 		{
 			has_connect=true;
@@ -245,6 +239,9 @@ Renderer_Ducks::render_vfunc(
 		origin[0]=(origin[0]-window_start[0])/pw;
 		origin[1]=(origin[1]-window_start[1])/ph;
 
+		if (point.is_nan_or_inf() || origin.is_nan_or_inf())
+			continue;
+
 		bool selected(get_work_area()->duck_is_selected(*iter));
 		bool hover(*iter==hover_duck || (*iter)->get_hover());
 
@@ -280,14 +277,59 @@ Renderer_Ducks::render_vfunc(
 			boxpoint[1]=(boxpoint[1]-window_start[1])/ph;
 			Point tl(min(point[0],boxpoint[0]),min(point[1],boxpoint[1]));
 
+			if (!boxpoint.is_nan_or_inf() && !tl.is_nan_or_inf())
+			{
+				cr->save();
+
+				cr->rectangle(
+					round_to_int(tl[0]),
+					round_to_int(tl[1]),
+					round_to_int(abs(boxpoint[0]-point[0])),
+					round_to_int(abs(boxpoint[1]-point[1]))
+					);
+
+				// Solid white box
+				cr->set_line_width(1.0);
+				cr->set_source_rgb(1,1,1); //DUCK_COLOR_BOX_1
+				cr->stroke_preserve();
+
+				// Dashes
+				cr->set_source_rgb(0,0,0); //DUCK_COLOR_BOX_2
+				std::valarray<double> dashes(2);
+				dashes[0]=5.0;
+				dashes[1]=5.0;
+				cr->set_dash(dashes, 0);
+				cr->stroke();
+
+				cr->restore();
+			}
+		}
+
+		if((*iter)->is_axes_tracks())
+		{
+			Point pos((*iter)->get_point());
+			Point points[] = {
+				(*iter)->get_sub_trans_origin(),
+				(*iter)->get_sub_trans_point(Point(pos[0],0)),
+				(*iter)->get_sub_trans_point(),
+				(*iter)->get_sub_trans_point(Point(0,pos[1])),
+				(*iter)->get_sub_trans_origin()
+			};
+
 			cr->save();
 
-			cr->rectangle(
-				round_to_int(tl[0]),
-				round_to_int(tl[1]),
-				round_to_int(abs(boxpoint[0]-point[0])),
-				round_to_int(abs(boxpoint[1]-point[1]))
-				);
+			bool first = true;
+			for(int i = 0; i < 5; i++) {
+				Point p((*iter)->get_transform_stack().perform(points[i]));
+				p[0] = (p[0]-window_start[0])/pw;
+				p[1] = (p[1]-window_start[1])/ph;
+				if (!p.is_nan_or_inf()) {
+					if (first)
+						{ first = false; cr->move_to(p[0], p[1]); }
+					else
+						cr->line_to(p[0], p[1]);
+				}
+			}
 
 			// Solid white box
 			cr->set_line_width(1.0);
@@ -309,8 +351,9 @@ Renderer_Ducks::render_vfunc(
 		screen_duck.pos=point;
 		screen_duck.selected=selected;
 		screen_duck.hover=hover;
+		screen_duck.has_alternative=(*iter)->get_alternative_value_desc().is_valid();
 
-		if(!(*iter)->get_editable())
+		if(!(*iter)->get_editable(alternative))
 			screen_duck.color=(DUCK_COLOR_NOT_EDITABLE);
 		else if((*iter)->get_tangent())
 			if(0){
@@ -321,7 +364,7 @@ Renderer_Ducks::render_vfunc(
 				synfig::Canvas::Handle canvas_h(get_work_area()->get_canvas());
 				synfig::Time time(canvas_h?canvas_h->get_time():synfig::Time(0));
 				// Retrieve the split value of the bline point.
-				synfigapp::ValueDesc& v_d((*iter)->get_value_desc());
+				const synfigapp::ValueDesc& v_d((*iter)->get_value_desc());
 				synfig::LinkableValueNode::Handle parent;
 				if(v_d.parent_is_linkable_value_node())
 				{
@@ -346,10 +389,16 @@ Renderer_Ducks::render_vfunc(
 				// All tangents are the same color
 				screen_duck.color=((*iter)->get_scalar()<0 ? DUCK_COLOR_TANGENT_1 : DUCK_COLOR_TANGENT_1);
 			}
+		else if((*iter)->get_type()&Duck::TYPE_SKEW)
+			screen_duck.color=DUCK_COLOR_TANGENT_2;
 		else if((*iter)->get_type()&Duck::TYPE_VERTEX)
 			screen_duck.color=DUCK_COLOR_VERTEX;
+		else if((*iter)->get_type()&Duck::TYPE_SCALE)
+			screen_duck.color=DUCK_COLOR_VERTEX;
 		else if((*iter)->get_type()&Duck::TYPE_RADIUS)
 			screen_duck.color=((*iter)->is_linear() ? DUCK_COLOR_LINEAR : DUCK_COLOR_RADIUS);
+		else if((*iter)->get_type()&Duck::TYPE_SCALE_X || (*iter)->get_type()&Duck::TYPE_SCALE_Y)
+			screen_duck.color=DUCK_COLOR_TANGENT_1;
 		else if((*iter)->get_type()&Duck::TYPE_WIDTH)
 			screen_duck.color=DUCK_COLOR_WIDTH;
 		else if((*iter)->get_type()&Duck::TYPE_ANGLE)
@@ -533,7 +582,7 @@ Renderer_Ducks::render_vfunc(
 									break;
 								}
 							}
-						WidthPoint wp((*wpoint_composite)(time));
+						WidthPoint wp((*wpoint_composite)(time).get(WidthPoint()));
 						if(wplistloop)
 						{
 							// The wplist is looped. This may require a position parameter
@@ -597,12 +646,12 @@ Renderer_Ducks::render_vfunc(
 
 	}
 
-
 	for(;screen_duck_list.size();screen_duck_list.pop_front())
 	{
 		Gdk::Color color(screen_duck_list.front().color);
 		double radius = 4;
 		double outline = 1;
+		bool duck_alternative = alternative && screen_duck_list.front().has_alternative;
 
 		// Draw the hovered duck last (on top of everything)
 		if(screen_duck_list.front().hover && !screen_duck_list.back().hover && screen_duck_list.size()>1)
@@ -634,15 +683,16 @@ Renderer_Ducks::render_vfunc(
 			M_PI*2
 			);
 
-		cr->set_source_rgb(
+		cr->set_source_rgba(
 			color.get_red_p(),
 			color.get_green_p(),
-			color.get_blue_p()
+			color.get_blue_p(),
+			duck_alternative ? 0.5 : 1.0
 			);
 		cr->fill_preserve();
 
 		cr->set_line_width(outline);
-		cr->set_source_rgb(0,0,0); //DUCK_COLOR_OUTLINE
+		cr->set_source_rgba(0,0,0,1); //DUCK_COLOR_OUTLINE
 		cr->stroke();
 
 		cr->restore();
