@@ -73,7 +73,7 @@ class Renderer_Ducks : public studio::WorkAreaRenderer
 public:
 	~Renderer_Ducks();
 
-	void render_vfunc(const Glib::RefPtr<Gdk::Drawable>& drawable,const Gdk::Rectangle& expose_area	);
+	void render_vfunc(const Glib::RefPtr<Gdk::Window>& drawable,const Gdk::Rectangle& expose_area	);
 
 protected:
 //	bool get_enabled_vfunc()const;
