@@ -53,8 +53,8 @@ using namespace studio;
 
 /* === M E T H O D S ======================================================= */
 
-Renderer_Guides::Renderer_Guides():
-	dragging(false)
+Renderer_Guides::Renderer_Guides()//:
+	//dragging(false)
 {
 
 }
@@ -188,7 +188,7 @@ Renderer_Guides::event_vfunc(GdkEvent* event)
 
 void
 Renderer_Guides::render_vfunc(
-	const Glib::RefPtr<Gdk::Drawable>& drawable,
+	const Glib::RefPtr<Gdk::Window>& drawable,
 	const Gdk::Rectangle& /*expose_area*/
 )
 {
@@ -197,8 +197,8 @@ Renderer_Guides::render_vfunc(
 		return;
 
 
-	int drawable_w,drawable_h;
-	drawable->get_size(drawable_w,drawable_h);
+	int drawable_w = drawable->get_width();
+	int drawable_h = drawable->get_height();
 
 	Cairo::RefPtr<Cairo::Context> cr = drawable->create_cairo_context();
 
@@ -206,6 +206,8 @@ Renderer_Guides::render_vfunc(
 	const synfig::Vector::value_type window_starty(get_work_area()->get_window_tl()[1]);
 	const float pw(get_pw()),ph(get_ph());
 
+	synfig::Color guides_color(get_work_area()->get_guides_color());
+
 	// Draw out the guides
 	{
 		Duckmatic::GuideList::const_iterator iter;
@@ -226,10 +228,11 @@ Renderer_Guides::render_vfunc(
 		{
 			const float x((*iter-window_startx)/pw);
 
+			//!TODO Remove hardcoded hightlight/selected guide color
 			if(iter==get_work_area()->curr_guide)
 				cr->set_source_rgb(1.0,111.0/255.0,111.0/255.0);
 			else
-				cr->set_source_rgb(111.0/255.0,111.0/255.0,1.0);
+				cr->set_source_rgb(guides_color.get_r(),guides_color.get_g(),guides_color.get_b());
 
 			cr->move_to(
 				x,
@@ -245,11 +248,11 @@ Renderer_Guides::render_vfunc(
 		for(iter=get_guide_list_y().begin();iter!=get_guide_list_y().end();++iter)
 		{
 			const float y((*iter-window_starty)/ph);
-
+            //!TODO Remove hardcoded hightlight/selected guide color
 			if(iter==get_work_area()->curr_guide)
 				cr->set_source_rgb(1.0,111.0/255.0,111.0/255.0);
 			else
-				cr->set_source_rgb(111.0/255.0,111.0/255.0,1.0);
+				cr->set_source_rgb(guides_color.get_r(),guides_color.get_g(),guides_color.get_b());
 
 			cr->move_to(
 				0,
