@@ -48,7 +48,7 @@ public:
 
 	synfig::Vector get_grid_size()const;
 
-	void render_vfunc(const Glib::RefPtr<Gdk::Drawable>& drawable,const Gdk::Rectangle& expose_area	);
+	void render_vfunc(const Glib::RefPtr<Gdk::Window>& drawable,const Gdk::Rectangle& expose_area	);
 
 protected:
 	bool get_enabled_vfunc()const;
