@@ -39,7 +39,10 @@
 #include "actions/layerraise.h"
 #include "actions/layerlower.h"
 #include "actions/layeradd.h"
+#include "actions/layeraddframe.h"
 #include "actions/layeractivate.h"
+#include "actions/layercopy.h"
+#include "actions/layerfit.h"
 #include "actions/layermakebline.h"
 #include "actions/layerparamset.h"
 #include "actions/layerparamsetstatic.h"
@@ -47,9 +50,14 @@
 #include "actions/layerparamconnect.h"
 #include "actions/layerparamdisconnect.h"
 #include "actions/layerencapsulate.h"
+#include "actions/layerencapsulateswitch.h"
 #include "actions/layerduplicate.h"
 #include "actions/layersetdesc.h"
 #include "actions/layersetexcludefromrendering.h"
+#include "actions/layerzdepthrangeset.h"
+#include "actions/layerembed.h"
+#include "actions/layerextract.h"
+#include "actions/layerresetpose.h"
 
 #include "actions/valuenodeconstset.h"
 #include "actions/valuenodeconstsetstatic.h"
@@ -84,6 +92,10 @@
 #include "actions/valuedesclink.h"
 #include "actions/valuedescblinelink.h"
 #include "actions/valuedescremovesmart.h"
+#include "actions/valuedescbonelink.h"
+#include "actions/valuedescskeletonlink.h"
+#include "actions/valuedesccreatechildbone.h"
+#include "actions/valuedescresetpose.h"
 
 #include "actions/waypointadd.h"
 #include "actions/waypointset.h"
@@ -178,6 +190,7 @@ Action::Main::Main()
 	ADD_ACTION(Action::LayerLower);
 	ADD_ACTION(Action::LayerAdd);
 	ADD_ACTION(Action::LayerActivate);
+	ADD_ACTION(Action::LayerFit);
 	ADD_ACTION(Action::LayerMakeOutline);
 	ADD_ACTION(Action::LayerMakeAdvancedOutline);
 	ADD_ACTION(Action::LayerMakeRegion);
@@ -187,10 +200,17 @@ Action::Main::Main()
 	ADD_ACTION(Action::LayerParamConnect);
 	ADD_ACTION(Action::LayerParamDisconnect);
 	ADD_ACTION(Action::LayerEncapsulate);
+	ADD_ACTION(Action::LayerEncapsulateSwitch);
 	ADD_ACTION(Action::LayerDuplicate);
 	ADD_ACTION(Action::LayerSetDesc);
+	ADD_ACTION(Action::LayerZDepthRangeSet);
+	ADD_ACTION(Action::LayerEmbed);
+	ADD_ACTION(Action::LayerExtract);
 	ADD_ACTION(Action::LayerSetExcludeFromRenderingOn);
 	ADD_ACTION(Action::LayerSetExcludeFromRenderingOff);
+	ADD_ACTION(Action::LayerAddFrame);
+	ADD_ACTION(Action::LayerCopy);
+	ADD_ACTION(Action::LayerResetPose);
 
 	ADD_ACTION(Action::ValueNodeConstSet);
 	ADD_ACTION(Action::ValueNodeConstSetStatic);
@@ -202,6 +222,7 @@ Action::Main::Main()
 	ADD_ACTION(Action::ValueNodeDynamicListInsert);
 	ADD_ACTION(Action::ValueNodeDynamicListRemove);
 	ADD_ACTION(Action::ValueNodeDynamicListInsertSmart);
+	ADD_ACTION(Action::ValueNodeDynamicListInsertSmartKeepShape);
 	ADD_ACTION(Action::ValueNodeDynamicListRemoveSmart);
 	ADD_ACTION(Action::ValueNodeDynamicListLoop);
 	ADD_ACTION(Action::ValueNodeDynamicListUnLoop);
@@ -226,6 +247,10 @@ Action::Main::Main()
 	ADD_ACTION(Action::ValueDescLinkOpposite);
 	ADD_ACTION(Action::ValueDescBLineLink);
 	ADD_ACTION(Action::ValueDescRemoveSmart);
+	ADD_ACTION(Action::ValueDescBoneLink);
+	ADD_ACTION(Action::ValueDescSkeletonLink);
+	ADD_ACTION(Action::ValueDescCreateChildBone);
+	ADD_ACTION(Action::ValueDescResetPose);
 
 	ADD_ACTION(Action::WaypointAdd);
 	ADD_ACTION(Action::WaypointSet);
@@ -263,7 +288,11 @@ Action::Main::Main()
 	ADD_ACTION(Action::EditModeSet);
 
 	ADD_ACTION(Action::BLinePointTangentMerge);
+	ADD_ACTION(Action::BLinePointTangentMergeRadius);
+	ADD_ACTION(Action::BLinePointTangentMergeAngle);
 	ADD_ACTION(Action::BLinePointTangentSplit);
+	ADD_ACTION(Action::BLinePointTangentSplitRadius);
+	ADD_ACTION(Action::BLinePointTangentSplitAngle);
 
 	ADD_ACTION(Action::GradientSet);
 	ADD_ACTION(Action::ColorSetFromOC);
@@ -282,7 +311,6 @@ Action::Main::Main()
 Action::Main::~Main()
 {
 	delete book_;
-
 }
 
 
