@@ -42,7 +42,7 @@
 #include <synfigapp/canvasinterface.h>
 
 #include <synfigapp/general.h>
-#include <synfig/valuenode_radialcomposite.h>
+#include <synfig/valuenodes/valuenode_radialcomposite.h>
 
 #endif
 
