@@ -32,8 +32,8 @@
 
 #include "keyframeset.h"
 #include <synfigapp/canvasinterface.h>
-#include <synfig/valuenode_dynamiclist.h>
-#include <synfig/valuenode_animated.h>
+#include <synfig/valuenodes/valuenode_dynamiclist.h>
+#include <synfig/valuenodes/valuenode_animated.h>
 #include "activepointsetsmart.h"
 #include "waypointsetsmart.h"
 #include <synfigapp/main.h>
