@@ -31,8 +31,8 @@
 
 #include "keyframewaypointset.h"
 #include <synfigapp/canvasinterface.h>
-#include <synfig/valuenode_dynamiclist.h>
-#include <synfig/valuenode_animated.h>
+#include <synfig/valuenodes/valuenode_dynamiclist.h>
+#include <synfig/valuenodes/valuenode_animated.h>
 #include "activepointsetsmart.h"
 #include "waypointsetsmart.h"
 
@@ -165,6 +165,10 @@ Action::KeyframeWaypointSet::process_value_desc(const synfigapp::ValueDesc& valu
 				waypoint.set_time(keyframe.get_time());
 				waypoint.set_value((*value_node)(keyframe.get_time()));
 			}
+
+			keyframe.apply_model(waypoint_model);
+			*get_canvas()->keyframe_list().find(keyframe)=keyframe;
+
 			waypoint.apply_model(waypoint_model);
 
 			action->set_param("waypoint",waypoint);
