@@ -64,6 +64,7 @@ ACTION_SET_CVS_ID(Action::LayerEncapsulate,"$Id$");
 
 Action::LayerEncapsulate::LayerEncapsulate()
 {
+    children_lock=false;
 }
 
 synfig::String
@@ -82,6 +83,11 @@ Action::LayerEncapsulate::get_param_vocab()
 		.set_desc(_("Layer to be grouped"))
 		.set_supports_multiple()
 	);
+	ret.push_back(ParamDesc("description",Param::TYPE_STRING)
+		.set_local_name(_("Description"))
+		.set_desc(_("Description of new switch"))
+		.set_optional()
+	);
 
 	return ret;
 }
@@ -98,7 +104,16 @@ Action::LayerEncapsulate::set_param(const synfig::String& name, const Action::Pa
 	if(name=="layer" && param.get_type()==Param::TYPE_LAYER)
 	{
 		layers.push_back(param.get_layer());
-
+		return true;
+	}
+	if(name=="description" && param.get_type()==Param::TYPE_STRING)
+	{
+		description = param.get_string();
+		return true;
+	}
+        if(name=="children_lock" && param.get_type()==Param::TYPE_BOOL)
+	{
+		children_lock = param.get_bool();
 		return true;
 	}
 
@@ -144,9 +159,12 @@ Action::LayerEncapsulate::prepare()
 	if(!child_canvas)
 		child_canvas=Canvas::create_inline(get_canvas());
 
-	Layer::Handle new_layer(Layer::create("PasteCanvas"));
+	Layer::Handle new_layer(Layer::create("group"));
 
+	if (!description.empty()) new_layer->set_description(description);
 	new_layer->set_param("canvas",child_canvas);
+        
+        new_layer->set_param("children_lock",children_lock);
 
 	int target_depth(lowest_depth());
 
