@@ -56,16 +56,16 @@ ACTION_SET_CVS_ID(Action::LayerMove,"$Id$");
 
 /* === G L O B A L S ======================================================= */
 
-static const int nindex=-1;
+// static const int nindex=-1;
 
 /* === P R O C E D U R E S ================================================= */
 
 /* === M E T H O D S ======================================================= */
 
 Action::LayerMove::LayerMove():
-	new_index(0xdeadbeef)
-{
-}
+	old_index(),
+	new_index(0xdeadbeef) // Dead beef? LOL
+{ }
 
 synfig::String
 Action::LayerMove::get_local_name()const
