@@ -60,9 +60,9 @@ ACTION_SET_CVS_ID(Action::LayerParamUnSetStatic,"$Id$");
 
 /* === M E T H O D S ======================================================= */
 
-Action::LayerParamUnSetStatic::LayerParamUnSetStatic()
-{
-}
+Action::LayerParamUnSetStatic::LayerParamUnSetStatic():
+	old_static_value()
+{ }
 
 Action::ParamVocab
 Action::LayerParamUnSetStatic::get_param_vocab()
@@ -84,7 +84,7 @@ Action::LayerParamUnSetStatic::is_candidate(const ParamList &x)
 
 	ValueDesc value_desc(x.find("value_desc")->second.get_value_desc());
 
-	if(!value_desc.parent_is_layer_param())
+	if(!value_desc.parent_is_layer())
 		return false;
 
 	synfig::ValueBase parameter;
@@ -103,7 +103,7 @@ Action::LayerParamUnSetStatic::is_candidate(const ParamList &x)
 	//! Retrieves the current parameter
 	parameter = _layer->get_param(_param_name);
 	//! Check that the parameter is not a inline canvas
-	if(parameter.get_type()==ValueBase::TYPE_CANVAS && parameter.get(Canvas::Handle()))
+	if(parameter.get_type()==type_canvas && parameter.get(Canvas::Handle()))
 		if(parameter.get(Canvas::Handle())->is_inline())
 			return false;
 	//! Check if it is not static
@@ -121,7 +121,7 @@ Action::LayerParamUnSetStatic::set_param(const synfig::String& name, const Actio
 	if(!layer && name=="value_desc" && param.get_type()==Param::TYPE_VALUEDESC)
 	{
 		ValueDesc value_desc(param.get_value_desc());
-		if(!value_desc.parent_is_layer_param())
+		if(!value_desc.parent_is_layer())
 			return false;
 
 		layer=Layer::Handle::cast_dynamic(value_desc.get_layer());
@@ -135,7 +135,7 @@ Action::LayerParamUnSetStatic::set_param(const synfig::String& name, const Actio
 	{
 		ValueDesc value_desc(param.get_value_desc());
 
-		if(!value_desc.parent_is_layer_param())
+		if(!value_desc.parent_is_layer())
 			return false;
 
 		param_name=value_desc.get_param_name();
