@@ -56,7 +56,7 @@ ACTION_SET_CVS_ID(Action::LayerSetDesc,"$Id$");
 
 /* === G L O B A L S ======================================================= */
 
-static const int nindex=-1;
+// static const int nindex=-1;
 
 /* === P R O C E D U R E S ================================================= */
 
@@ -83,13 +83,14 @@ Action::LayerSetDesc::get_param_vocab()
 
 	ret.push_back(ParamDesc("layer",Param::TYPE_LAYER)
 		.set_local_name(_("Layer"))
-		.set_desc(_("Layer to be moved"))
+		.set_desc(_("Layer to be described"))
 	);
 
 	ret.push_back(ParamDesc("new_description",Param::TYPE_STRING)
 		.set_local_name(_("New Description"))
 		.set_local_name(_("Enter a new description for this layer"))
 		.set_user_supplied()
+		.set_value_provided()
 	);
 
 	return ret;
@@ -121,6 +122,18 @@ Action::LayerSetDesc::set_param(const synfig::String& name, const Action::Param
 	return Action::CanvasSpecific::set_param(name,param);
 }
 
+bool
+Action::LayerSetDesc::get_param(const synfig::String& name, Action::Param &param)
+{
+	if(name=="new_description")
+	{
+		param=layer->get_description();
+
+		return true;
+	}
+	return Action::CanvasSpecific::get_param(name,param);
+}
+
 bool
 Action::LayerSetDesc::is_ready()const
 {
