@@ -105,11 +105,17 @@ Action::ValueDescBLineLink::is_candidate(const ParamList &x)
 {
 	ParamList::const_iterator i;
 
-	ValueDesc value_desc(x.find("value_desc")->second.get_value_desc());
-
 	if (!candidate_check(get_param_vocab(),x))
 		return false;
 
+	ValueDesc value_desc(x.find("value_desc")->second.get_value_desc());
+	ValueDesc selected_value_desc(x.find("selected_value_desc")->second.get_value_desc());
+
+	//! if the valuedesc belong to the spline, can't link.
+	if(value_desc.parent_is_value_node() && selected_value_desc.parent_is_value_node() &&
+	        value_desc.get_parent_value_node() == selected_value_desc.get_parent_value_node())
+	    return false;
+
 	return (value_desc.parent_is_value_node() &&
 			// We need a dynamic list.
 			ValueNode_DynamicList::Handle::cast_dynamic(value_desc.get_parent_value_node()));
