@@ -37,9 +37,10 @@
 
 #include "valuedescdisconnect.h"
 #include <synfigapp/canvasinterface.h>
-#include <synfig/valuenode_const.h>
-#include <synfig/valuenode_duplicate.h>
-#include <synfig/valuenode_bone.h>
+#include <synfig/valuenodes/valuenode_const.h>
+#include <synfig/valuenodes/valuenode_composite.h>
+#include <synfig/valuenodes/valuenode_duplicate.h>
+#include <synfig/valuenodes/valuenode_bone.h>
 
 #include <synfigapp/general.h>
 
@@ -114,7 +115,7 @@ Action::ValueDescDisconnect::is_candidate(const ParamList &x)
 	   ValueNode_Bone::Handle::cast_dynamic(value_desc.get_value_node()))
 		return false;
 	// don't allow the Index parameter of the Duplicate layer to be disconnected
-	if(value_desc.parent_is_layer_param() && value_desc.get_layer()->get_name() == "duplicate" && value_desc.get_param_name() == "index")
+	if(value_desc.parent_is_layer() && value_desc.get_layer()->get_name() == "duplicate" && value_desc.get_param_name() == "index")
 		return false;
 	if(!value_desc.parent_is_canvas() && value_desc.is_value_node() && value_desc.get_value_node()->rcount()>1)
 		return true;
@@ -125,7 +126,7 @@ Action::ValueDescDisconnect::is_candidate(const ParamList &x)
 	// don't allow Duplicate ValueNodes in the Children dialog to be disconnected
 	if(value_desc.is_value_node() &&
 	   ValueNode_Duplicate::Handle::cast_dynamic(value_desc.get_value_node()) &&
-	   !value_desc.parent_is_layer_param() &&
+	   !value_desc.parent_is_layer() &&
 	   !value_desc.parent_is_value_node())
 		return false;
 	return true;
@@ -164,6 +165,26 @@ Action::ValueDescDisconnect::prepare()
 {
 	clear();
 
+	if(value_desc.get_value_type() == type_transformation)
+	{
+		ValueNode::Handle src_value_node;
+		src_value_node=ValueNode_Composite::create((*value_desc.get_value_node())(time));
+
+		Action::Handle action(ValueNodeReplace::create());
+
+		action->set_param("canvas",get_canvas());
+		action->set_param("canvas_interface",get_canvas_interface());
+		action->set_param("src",src_value_node);
+		action->set_param("dest",value_desc.get_value_node());
+
+		assert(action->is_ready());
+		if(!action->is_ready())
+			throw Error(Error::TYPE_NOTREADY);
+
+		add_action_front(action);
+		return;
+	}
+	else
 	if(value_desc.parent_is_canvas())
 	{
 		ValueNode::Handle src_value_node;
@@ -220,7 +241,7 @@ Action::ValueDescDisconnect::prepare()
 		return;
 	}
 	else
-	if(value_desc.parent_is_layer_param())
+	if(value_desc.parent_is_layer())
 	{
 		Action::Handle action(LayerParamDisconnect::create());
 
