@@ -29,8 +29,8 @@
 
 #include <synfigapp/action.h>
 #include <synfig/activepoint.h>
-#include <synfig/valuenode_dynamiclist.h>
-#include <synfig/valuenode_bline.h>
+#include <synfig/valuenodes/valuenode_dynamiclist.h>
+#include <synfig/valuenodes/valuenode_bline.h>
 
 /* === M A C R O S ========================================================= */
 
