@@ -2,7 +2,7 @@
 /*!	\file valuenodedynamiclistremove.cpp
 **	\brief Template File
 **
-**	$Id: valuenodedynamiclistremove.cpp 2098 2008-10-14 21:00:21Z genete $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -46,13 +46,13 @@ using namespace Action;
 /* === M A C R O S ========================================================= */
 
 ACTION_INIT(Action::ValueNodeDynamicListRemove);
-ACTION_SET_NAME(Action::ValueNodeDynamicListRemove,"value_node_dynamic_list_remove");
+ACTION_SET_NAME(Action::ValueNodeDynamicListRemove,"ValueNodeDynamicListRemove");
 ACTION_SET_LOCAL_NAME(Action::ValueNodeDynamicListRemove,N_("Remove Item"));
 ACTION_SET_TASK(Action::ValueNodeDynamicListRemove,"remove");
 ACTION_SET_CATEGORY(Action::ValueNodeDynamicListRemove,Action::CATEGORY_VALUEDESC|Action::CATEGORY_VALUENODE|Action::CATEGORY_HIDDEN);
 ACTION_SET_PRIORITY(Action::ValueNodeDynamicListRemove,-19);
 ACTION_SET_VERSION(Action::ValueNodeDynamicListRemove,"0.0");
-ACTION_SET_CVS_ID(Action::ValueNodeDynamicListRemove,"$Id: valuenodedynamiclistremove.cpp 2098 2008-10-14 21:00:21Z genete $");
+ACTION_SET_CVS_ID(Action::ValueNodeDynamicListRemove,"$Id$");
 
 /* === G L O B A L S ======================================================= */
 
