@@ -35,17 +35,18 @@
 //#include <iostream>
 
 #include <ETL/clock>
-#include <synfig/valuenode_scale.h>
-#include <synfig/valuenode_timedswap.h>
-#include <synfig/valuenode_composite.h>
-#include <synfig/valuenode_subtract.h>
-#include <synfig/valuenode_linear.h>
-#include <synfig/valuenode_reference.h>
-#include <synfig/valuenode_twotone.h>
-#include <synfig/valuenode_stripes.h>
-#include <synfig/valuenode_bline.h>
-#include <synfig/valuenode_wplist.h>
-#include <synfig/valuenode_dilist.h>
+#include <synfig/valuenodes/valuenode_scale.h>
+#include <synfig/valuenodes/valuenode_timedswap.h>
+#include <synfig/valuenodes/valuenode_composite.h>
+#include <synfig/valuenodes/valuenode_subtract.h>
+#include <synfig/valuenodes/valuenode_linear.h>
+#include <synfig/valuenodes/valuenode_reference.h>
+#include <synfig/valuenodes/valuenode_twotone.h>
+#include <synfig/valuenodes/valuenode_stripes.h>
+#include <synfig/valuenodes/valuenode_bline.h>
+#include <synfig/valuenodes/valuenode_wplist.h>
+#include <synfig/valuenodes/valuenode_dilist.h>
+#include <synfig/pair.h>
 
 #include <synfig/waypoint.h>
 #include <synfig/loadcanvas.h>
@@ -231,16 +232,10 @@ CanvasInterface::apply_layer_param_defaults(synfig::Layer::Handle layer)
 	p.set(synfigapp::Main::get_gradient());
 	layer->set_param("gradient",p);
 	
-	if(name!="zoom")
-	{
-		p=layer->get_param("amount");
-		p.set(synfigapp::Main::get_opacity());
-		layer->set_param("amount",p);
-	}
 	if(synfigapp::Main::get_blend_method() != Color::BLEND_BY_LAYER)
 	{
 		p=layer->get_param("blend_method");
-		p.set(synfigapp::Main::get_blend_method());
+		p.set((int)synfigapp::Main::get_blend_method());
 		layer->set_param("blend_method",p);
 	}
 
@@ -259,25 +254,26 @@ CanvasInterface::apply_layer_param_defaults(synfig::Layer::Handle layer)
 			// into dynamic list valuenodes, unless every element of
 			// the list is a blinepoint, in which case convert it to a
 			// bline
-			if(iter->second.get_type()==ValueBase::TYPE_LIST)
+			if(iter->second.get_type()==type_list)
 			{
 				// check whether it's a list of blinepoints or widthpoints only
 				vector<ValueBase> list(iter->second.get_list());
 				if (list.size())
 				{
 					vector<ValueBase>::iterator iter2 = list.begin();
-					ValueBase::Type type(iter2->get_type());
+					Type &type(iter2->get_type());
 					for (iter2++; iter2 != list.end(); iter2++)
 						if (iter2->get_type() != type)
 							break;
 					if (iter2 == list.end())
 					{
-						if (type == ValueBase::TYPE_BLINEPOINT)
+						if (type == type_bline_point)
 						{
 							value_node=LinkableValueNode::create("bline",iter->second,canvas);
 							ValueNode_BLine::Handle::cast_dynamic(value_node)->set_member_canvas(canvas);
 						}
-						else if (type == ValueBase::TYPE_BONE)
+						else
+						if (type == type_bone_object)
 						{
 							if (getenv("SYNFIG_USE_DYNAMIC_LIST_FOR_BONES"))
 							{
@@ -290,7 +286,22 @@ CanvasInterface::apply_layer_param_defaults(synfig::Layer::Handle layer)
 								ValueNode_StaticList::Handle::cast_dynamic(value_node)->set_member_canvas(canvas);
 							}
 						}
-						else if (type == ValueBase::TYPE_VECTOR)
+						else
+						if (type == types_namespace::TypePair<Bone, Bone>::instance)
+						{
+							if (getenv("SYNFIG_USE_DYNAMIC_LIST_FOR_BONES"))
+							{
+								value_node=LinkableValueNode::create("dynamic_list",iter->second,canvas);
+								ValueNode_DynamicList::Handle::cast_dynamic(value_node)->set_member_canvas(canvas);
+							}
+							else // this is the default
+							{
+								value_node=LinkableValueNode::create("static_list",iter->second,canvas);
+								ValueNode_StaticList::Handle::cast_dynamic(value_node)->set_member_canvas(canvas);
+							}
+						}
+						else
+						if (type == type_vector)
 						{
 							if (getenv("SYNFIG_USE_STATIC_LIST_FOR_VECTORS"))
 							{
@@ -305,7 +316,7 @@ CanvasInterface::apply_layer_param_defaults(synfig::Layer::Handle layer)
 						}
 					}
 					for (iter2 = list.begin(); iter2 != list.end(); iter2++)
-						if (iter2->get_type() != ValueBase::TYPE_WIDTHPOINT)
+						if (iter2->get_type() != type_width_point)
 							break;
 					if (iter2 == list.end())
 					{
@@ -313,7 +324,7 @@ CanvasInterface::apply_layer_param_defaults(synfig::Layer::Handle layer)
 						ValueNode_WPList::Handle::cast_dynamic(value_node)->set_member_canvas(canvas);
 					}
 					for (iter2 = list.begin(); iter2 != list.end(); iter2++)
-						if (iter2->get_type() != ValueBase::TYPE_DASHITEM)
+						if (iter2->get_type() != type_dash_item)
 							break;
 					if (iter2 == list.end())
 					{
@@ -329,8 +340,8 @@ CanvasInterface::apply_layer_param_defaults(synfig::Layer::Handle layer)
 			// 'composite' (other than the types that can be radial
 			// composite) then do so
 			else if(LinkableValueNode::check_type("composite",iter->second.get_type()) &&
-					 (iter->second.get_type()!=ValueBase::TYPE_COLOR &&
-					  iter->second.get_type()!=ValueBase::TYPE_VECTOR))
+					 (iter->second.get_type()!=type_color &&
+					  iter->second.get_type()!=type_vector))
 				value_node=LinkableValueNode::create("composite",iter->second,canvas);
 
 			if(value_node)
@@ -375,10 +386,10 @@ CanvasInterface::add_layer_to(synfig::String name, synfig::Canvas::Handle canvas
 		}
 
 	layer->set_canvas(canvas);
-
+	
 	// Apply some defaults
 	apply_layer_param_defaults(layer);
-
+	
 	// Action to add the layer
 	Action::Handle 	action(Action::LayerAdd::create());
 
@@ -521,13 +532,13 @@ CanvasInterface::generate_param_list(const ValueDesc &value_desc)
 		// because by the time the handle is destructed the canvas
 		// will no longer be inline.  So let's not propogate that
 		// ValueBase any further than here.
-		if (value_desc.get_value_type() == ValueBase::TYPE_CANVAS)
+		if (value_desc.get_value_type() == type_canvas)
 			param_list.add("value",Canvas::LooseHandle(value_desc.get_value().get(Canvas::LooseHandle())));
 		else
 			param_list.add("value",value_desc.get_value());
 	}
 
-	if(value_desc.parent_is_layer_param())
+	if(value_desc.parent_is_layer())
 	{
 		param_list.add("parent_layer",value_desc.get_layer());
 		param_list.add("parent_layer_param",value_desc.get_param_name());
@@ -669,13 +680,13 @@ CanvasInterface::jump_to_prev_keyframe()
 bool
 CanvasInterface::import(const synfig::String &filename, synfig::String &errors, synfig::String &warnings, bool resize_image)
 {
-	Action::PassiveGrouper group(get_instance().get(),_("Import Image"));
+	Action::PassiveGrouper group(get_instance().get(),_("Import"));
 
 	synfig::info("Attempting to import "+filename);
 
 	if (filename_extension(filename) == "")
 	{
-		get_ui_interface()->error(_("Filename must have an extension!"));
+		get_ui_interface()->error(_("File name must have an extension!"));
 		return false;
 	}
 
@@ -683,8 +694,17 @@ CanvasInterface::import(const synfig::String &filename, synfig::String &errors,
 	if (ext.size()) ext = ext.substr(1); // skip initial '.'
 	std::transform(ext.begin(),ext.end(),ext.begin(),&::tolower);
 
+	if (ext=="wav" || ext=="ogg" || ext=="mp3"){
+		Layer::Handle layer(add_layer_to("sound",get_canvas()));
+		if(!layer)
+			throw String(_("Unable to create \"Sound\" layer"));
+		layer->set_param("filename",ValueBase(filename));
+		signal_layer_new_description()(layer,filename);
+		return true;
+	}
+
 	if(ext=="svg"){//I don't like it, but worse is nothing
-		Layer::Handle _new_layer(add_layer_to("PasteCanvas",get_canvas()));
+		Layer::Handle _new_layer(add_layer_to("group",get_canvas()));
 		Layer::Handle _aux_layer(add_layer_to("svg_layer",get_canvas()));
 		if(_aux_layer){
 			_aux_layer->set_param("filename",ValueBase(filename));
@@ -713,11 +733,11 @@ CanvasInterface::import(const synfig::String &filename, synfig::String &errors,
 	// If this is a SIF file, then we need to do things slightly differently
 	if(ext=="sif" || ext=="sifz")try
 	{
-		Canvas::Handle outside_canvas(synfig::open_canvas(filename, errors, warnings));
+		Canvas::Handle outside_canvas(synfig::open_canvas_as(get_canvas()->get_identifier().file_system->get_identifier(filename), filename, errors, warnings));
 		if(!outside_canvas)
 			throw String(_("Unable to open this composition")) + ":\n\n" + errors;
 
-		Layer::Handle layer(add_layer_to("PasteCanvas",get_canvas()));
+		Layer::Handle layer(add_layer_to("group",get_canvas()));
 		if(!layer)
 			throw String(_("Unable to create \"Group\" layer"));
 		if(!layer->set_param("canvas",ValueBase(outside_canvas)))
@@ -759,7 +779,7 @@ CanvasInterface::import(const synfig::String &filename, synfig::String &errors,
 		h=layer->get_param("_height").get(int());
 		if(w&&h)
 		{
-			Vector x, size=ValueBase(get_canvas()->rend_desc().get_br()-get_canvas()->rend_desc().get_tl());
+			Vector x, size = get_canvas()->rend_desc().get_br()-get_canvas()->rend_desc().get_tl();
 
 			// vector from top left of canvas to bottom right
 			if (resize_image)
@@ -803,6 +823,19 @@ CanvasInterface::import(const synfig::String &filename, synfig::String &errors,
 		layer->set_description(basename(filename));
 		signal_layer_new_description()(layer,filename);
 
+		// add imported layer into switch
+		Action::Handle action(Action::create("LayerEncapsulateSwitch"));
+		assert(action);
+		if(!action) return false;
+		action->set_param("canvas",get_canvas());
+		action->set_param("canvas_interface",etl::loose_handle<CanvasInterface>(this));
+		action->set_param("layer",layer);
+		action->set_param("description",layer->get_description());
+		if(!action->is_ready())
+			{ get_ui_interface()->error(_("Action Not Ready")); return false; }
+		if(!get_instance()->perform_action(action))
+			{ get_ui_interface()->error(_("Action Failed.")); return false; }
+
 		return true;
 	}
 	catch(...)
@@ -817,7 +850,7 @@ CanvasInterface::import(const synfig::String &filename, synfig::String &errors,
 void
 CanvasInterface::waypoint_duplicate(synfigapp::ValueDesc value_desc,synfig::Waypoint waypoint)
 {
-	ValueNode::Handle value_node();
+	//ValueNode::Handle value_node();
 	waypoint_duplicate(value_desc.get_value_node(), waypoint);
 }
 
@@ -846,7 +879,7 @@ CanvasInterface::waypoint_duplicate(ValueNode::Handle value_node,synfig::Waypoin
 void
 CanvasInterface::waypoint_remove(synfigapp::ValueDesc value_desc,synfig::Waypoint waypoint)
 {
-	ValueNode::Handle value_node();
+	//ValueNode::Handle value_node();
 	waypoint_remove(value_desc.get_value_node(), waypoint);
 }
 
@@ -923,7 +956,7 @@ CanvasInterface::auto_export(const ValueDesc& /*value_desc*/)
 }
 
 bool
-CanvasInterface::change_value(synfigapp::ValueDesc value_desc,synfig::ValueBase new_value)
+CanvasInterface::change_value(synfigapp::ValueDesc value_desc,synfig::ValueBase new_value,bool lock_animation)
 {
 	ValueBase old_value;
 	old_value = value_desc.get_value(get_time());
@@ -968,6 +1001,7 @@ CanvasInterface::change_value(synfigapp::ValueDesc value_desc,synfig::ValueBase
 	action->set_param("time",get_time());
 	action->set_param("value_desc",value_desc);
 	action->set_param("new_value",new_value);
+	if (lock_animation) action->set_param("lock_animation", lock_animation);
 
 	return get_instance()->perform_action(action);
 }
@@ -1031,7 +1065,7 @@ _process_value_desc(const synfigapp::ValueDesc& value_desc,std::vector<synfigapp
 {
 	int ret(0);
 
-	if(value_desc.get_value_type()==ValueBase::TYPE_CANVAS)
+	if(value_desc.get_value_type()==type_canvas)
 	{
 		Canvas::Handle canvas;
 		canvas=value_desc.get_value().get(canvas);
