@@ -81,6 +81,7 @@ private:
 	sigc::signal<void,synfig::Layer::Handle> signal_layer_removed_;
 	sigc::signal<void,synfig::Layer::Handle,bool> signal_layer_status_changed_;
 	sigc::signal<void,synfig::Layer::Handle,bool> signal_layer_exclude_from_rendering_changed_;
+	sigc::signal<void,synfig::Layer::Handle,bool> signal_layer_z_range_changed_;
 	sigc::signal<void,synfig::Layer::Handle,synfig::String> signal_layer_new_description_;
 	sigc::signal<void,synfig::Canvas::Handle> signal_canvas_added_;
 	sigc::signal<void,synfig::Canvas::Handle> signal_canvas_removed_;
@@ -92,6 +93,8 @@ private:
 	sigc::signal<void,synfig::Keyframe> signal_keyframe_added_;
 	sigc::signal<void,synfig::Keyframe> signal_keyframe_removed_;
 	sigc::signal<void,synfig::Keyframe> signal_keyframe_changed_;
+	sigc::signal<void,synfig::Keyframe,void*> signal_keyframe_selected_;
+	sigc::signal<void> signal_keyframe_properties_;
 
 	sigc::signal<void> signal_id_changed_;
 
@@ -129,6 +132,9 @@ public:	// Signal Interface
 	//! Signal called when the layer's "exclude from rendering" flag has changed.
 	sigc::signal<void,synfig::Layer::Handle,bool>& signal_layer_exclude_from_rendering_changed() { return signal_layer_exclude_from_rendering_changed_; }
 
+	//! Signal called when the layer's zdepth range has changed. This layer has to be Layer_PasteCanvas
+	sigc::signal<void,synfig::Layer::Handle,bool>& signal_layer_z_range_changed() { return signal_layer_z_range_changed_; }
+
 	//! Signal called when a canvas has been added.
 	sigc::signal<void,etl::handle<synfig::Canvas> >& signal_canvas_added() { return signal_canvas_added_; }
 
@@ -176,11 +182,17 @@ public:	// Signal Interface
 	//! Signal called whenever the RendDesc changes
 	sigc::signal<void>& signal_rend_desc_changed() { return signal_rend_desc_changed_; }
 
+	//! Signal called when a keyframe is added
 	sigc::signal<void,synfig::Keyframe>& signal_keyframe_added() { return signal_keyframe_added_; }
-
+	//! Signal called when a keyframe is removed
 	sigc::signal<void,synfig::Keyframe>& signal_keyframe_removed() { return signal_keyframe_removed_; }
-
+	//! Signal called when a keyframe is changed
 	sigc::signal<void,synfig::Keyframe>& signal_keyframe_changed() { return signal_keyframe_changed_; }
+	//! Signal called when a keyframe is selected
+	/*!	Second parameter (void*) hold 'this*' of the signal emiter class (to prevent endless loop)*/
+	sigc::signal<void,synfig::Keyframe,void*>& signal_keyframe_selected() { return signal_keyframe_selected_; }
+	//! Signal called when the properties dialog of the selected keyframe must be shown
+	sigc::signal<void>& signal_keyframe_properties() { return signal_keyframe_properties_; }
 
 public:
 
@@ -290,7 +302,7 @@ public:
 	void waypoint_remove(synfigapp::ValueDesc value_desc,synfig::Waypoint waypoint);
 	void waypoint_remove(synfig::ValueNode::Handle value_node,synfig::Waypoint waypoint);
 
-	bool change_value(synfigapp::ValueDesc value_desc,synfig::ValueBase new_value);
+	bool change_value(synfigapp::ValueDesc value_desc,synfig::ValueBase new_value,bool lock_animation = false);
 
 
 	int find_important_value_descs(std::vector<synfigapp::ValueDesc>& out);
