@@ -224,7 +224,7 @@ Settings::save_to_file(const synfig::String& filename)const
 	rename(filename.c_str(),old_file.c_str());
 	if(rename(tmp_filename.c_str(),filename.c_str())!=0)
 	{
-		rename(old_file.c_str(),tmp_filename.c_str());
+		rename(old_file.c_str(),filename.c_str());
 		return false;
 	}
 	remove(old_file.c_str());
